"""

CRT1 specification So far based on Australia only.

Since 2023 Australia reports in the CRT (common reporting tables) format which is
similar but not identical to CRF. Some tables are different and it is more
consistent in using sector titles etc. Thus it needs a special specification.

Currently not all tables are included. Extend if you need all country
specific items in categories XXXXX

Tables included:

* **Energy:** 'Table1', 'Table1.A(a)s1', 'Table1.A(a)s2', 'Table1.A(a)s3',
  'Table1.A(a)s4', 'Table1.B.1', 'Table1.B.2', 'Table1.C',
* **Industrial processes:** 'Table2(I), 'Table2(II)',
* **Agriculture:** 'Table3', 'Table3.A', 'Table3.B(a)', 'Table3.B(b)', 'Table3.C', 'Table3.D',
* **LULUCF:**  'Table4',
* **Waste:**  'Table5',
* **Summary:** 'Summary1'

Missing tables are:

* **Energy:** 'Table1.A(b)', 'Table1.A(c)', 'Table1.A(d)', 'Table1.D'
* **Industrial processes:** 'Table2(I).A-H', 'Table2(II)B-Hs1', 'Table2(II)B-Hs2',
* **Agriculture:** 'Table3.E', 'Table3.F', 'Table3.G-I',
* **LULUCF**: All tables except Table4
* **Waste**:  'Table5.A', 'Table5.B', 'Table5.C', 'Table5.D'
* **Summary:** 'Summary2', 'Summary3', 'Flex_summary',
* **other:** 'Table6', 'Table7', 'Table8s1', 'Table8s2',
  'Table9', 'Table10s1', 'Table10s2', 'Table10s3', 'Table10s4', 'Table10s5',
  'Table10s6'



TODO:
 * Add missing tables
 * Add activity data

"""

from .util import unit_info

gwp_to_use = "AR5GWP100"

CRT1 = {
    # Table1 instead of 1s1 and 1s2
    "Table1": {
        "status": "tested",
        "table": {
            "firstrow": 8,
            "lastrow": 61,
            "header": ["entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": [
                "",
                "nan",
                '(1) "Total GHG emissions" does not include NOX, ' "CO, NMVOC and SOX.",
            ],
            "unit_info": unit_info["industry"],
        },
        "sector_mapping": [
            ["Total Energy", ["1"]],
            ["1.A. Fuel combustion activities (sectoral approach)", ["1.A"]],
            ["1.A.1. Energy industries", ["1.A.1"]],
            ["1.A.1.a. Public electricity and heat production", ["1.A.1.a"]],
            ["1.A.1.b. Petroleum refining", ["1.A.1.b"]],
            [
                "1.A.1.c. Manufacture of solid fuels and other energy industries",
                ["1.A.1.c"],
            ],
            ["1.A.2. Manufacturing industries and construction", ["1.A.2"]],
            ["1.A.2.a. Iron and steel", ["1.A.2.a"]],
            ["1.A.2.b. Non-ferrous metals", ["1.A.2.b"]],
            ["1.A.2.c. Chemicals", ["1.A.2.c"]],
            ["1.A.2.d. Pulp, paper and print", ["1.A.2.d"]],
            ["1.A.2.e. Food processing, beverages and tobacco", ["1.A.2.e"]],
            ["1.A.2.f. Non-metallic minerals", ["1.A.2.f"]],
            ["1.A.2.g. Other", ["1.A.2.g"]],
            ["1.A.3. Transport", ["1.A.3"]],
            ["1.A.3.a. Domestic aviation", ["1.A.3.a"]],
            ["1.A.3.b. Road transportation", ["1.A.3.b"]],
            ["1.A.3.c. Railways", ["1.A.3.c"]],
            ["1.A.3.d. Domestic navigation", ["1.A.3.d"]],
            ["1.A.3.e. Other transportation", ["1.A.3.e"]],
            ["1.A.4. Other sectors", ["1.A.4"]],
            ["1.A.4.a. Commercial/institutional", ["1.A.4.a"]],
            ["1.A.4.b. Residential", ["1.A.4.b"]],
            ["1.A.4.c. Agriculture/forestry/fishing", ["1.A.4.c"]],
            ["1.A.5. Other", ["1.A.5"]],
            ["1.A.5.a. Stationary", ["1.A.5.a"]],
            ["1.A.5.b. Mobile", ["1.A.5.b"]],
            ["1.B. Fugitive emissions from fuels", ["1.B"]],
            ["1.B.1. Solid fuels", ["1.B.1"]],
            ["1.B.1.a. Coal mining and handling", ["1.B.1.a"]],
            ["1.B.1.b. Fuel transformation", ["1.B.1.b"]],
            ["1.B.1.c. Other", ["1.B.1.c"]],
            [
                "1.B.2. Oil and natural gas and other emissions from energy production",
                ["1.B.2"],
            ],
            ["1.B.2.a. Oil", ["1.B.2.a"]],
            ["1.B.2.b. Natural gas", ["1.B.2.b"]],
            ["1.B.2.c. Venting and flaring", ["1.B.2.c"]],
            ["1.B.2.d. Other", ["1.B.2.d"]],
            ["1.C. CO2 Transport and storage", ["1.C"]],
            ["1.C.1. Transport of CO2", ["1.C.1"]],
            ["1.C.2. Injection and storage", ["1.C.2"]],
            ["1.C.3. Other", ["1.C.3"]],
            ["1.D. Memo items: (3)", ["\\IGNORE"]],
            ["1.D.1. International bunkers", ["M.Memo.Int"]],
            ["1.D.1.a. Aviation", ["M.Memo.Int.Avi"]],
            ["1.D.1.b.Navigation", ["M.Memo.Int.Mar"]],
            ["1.D.2. Multilateral operations", ["M.Memo.Mult"]],
            ["1.D.3. CO2 emissions from biomass", ["M.Memo.Bio"]],
            ["1.D.4. CO2 captured", ["M.Memo.CO2Cap"]],
            ["1.D.4.a. For domestic storage", ["M.Memo.CO2Cap.Dom"]],
            ["1.D.4.b. For storage in other countries", ["M.Memo.CO2Cap.Exp"]],
        ],
        "entity_mapping": {
            "NOX": "NOx",
            "Total GHG emissions (1)": f"KYOTOGHG ({gwp_to_use})",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table1.A(a)s1": {
        "status": "tested",
        "table": {
            "firstrow": 7,
            "lastrow": 88,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category", "class"],
            "cols_to_ignore": [
                "AGGREGATE ACTIVITY DATA Consumption",
                "AGGREGATE ACTIVITY DATA Consumption",
                "IMPLIED EMISSION FACTORS CO2 (1)",
                "IMPLIED EMISSION FACTORS CH4",
                "IMPLIED EMISSION FACTORS N2O",
                "AMOUNT CAPTURED (4) CO2",
            ],
            "stop_cats": [
                "",
                "nan",
                "Note: Minimum level of aggregation is needed to protect "
                "confidential business and military information, where it "
                "would identify particular entity's/entities' "
                "confidential data.",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["1.A. Fuel combustion", ["1.A", "Total"], 0],
            ["Liquid fuels", ["1.A", "Liquid"], 1],
            ["Solid fuels", ["1.A", "Solid"], 1],
            ["Gaseous fuels (6)", ["1.A", "Gaseous"], 1],
            ["Other fossil fuels (7)", ["1.A", "OtherFF"], 1],
            ["Peat (8)", ["1.A", "Peat"], 1],
            ["Biomass (3)", ["1.A", "Biomass"], 1],
            # 1.A.1. Energy industries
            ["1.A.1. Energy industries", ["1.A.1", "Total"], 1],
            ["Liquid fuels", ["1.A.1", "Liquid"], 2],
            ["Solid fuels", ["1.A.1", "Solid"], 2],
            ["Gaseous fuels (6)", ["1.A.1", "Gaseous"], 2],
            ["Other fossil fuels (7)", ["1.A.1", "OtherFF"], 2],
            ["Peat (8)", ["1.A.1", "Peat"], 2],
            ["Biomass (3)", ["1.A.1", "Biomass"], 2],
            # a. Public electricity and heat production
            [
                "1.A.1.a. Public electricity and heat production (9)",
                ["1.A.1.a", "Total"],
                2,
            ],
            ["Liquid fuels", ["1.A.1.a", "Liquid"], 3],
            ["Solid fuels", ["1.A.1.a", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.1.a", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.1.a", "OtherFF"], 3],
            ["Peat (8)", ["1.A.1.a", "Peat"], 3],
            ["Biomass (3)", ["1.A.1.a", "Biomass"], 3],
            ["Drop-down list:", ["\\IGNORE", "\\IGNORE"], 3],  # (empty)
            # 1.A.1.a.i Electricity Generation
            ["1.A.1.a.i. Electricity generation", ["1.A.1.a.i", "Total"], 3],
            ["Liquid fuels", ["1.A.1.a.i", "Liquid"], 4],
            ["Solid fuels", ["1.A.1.a.i", "Solid"], 4],
            ["Gaseous fuels (6)", ["1.A.1.a.i", "Gaseous"], 4],
            ["Other fossil fuels (7)", ["1.A.1.a.i", "OtherFF"], 4],
            ["Peat (8)", ["1.A.1.a.i", "Peat"], 4],
            ["Biomass (3)", ["1.A.1.a.i", "Biomass"], 4],
            # 1.A.1.a.ii Combined heat and power generation
            [
                "1.A.1.a.ii. Combined heat and power generation",
                ["1.A.1.a.ii", "Total"],
                3,
            ],
            ["Liquid fuels", ["1.A.1.a.ii", "Liquid"], 4],
            ["Solid fuels", ["1.A.1.a.ii", "Solid"], 4],
            ["Gaseous fuels (6)", ["1.A.1.a.ii", "Gaseous"], 4],
            ["Other fossil fuels (7)", ["1.A.1.a.ii", "OtherFF"], 4],
            ["Peat (8)", ["1.A.1.a.ii", "Peat"], 4],
            ["Biomass (3)", ["1.A.1.a.ii", "Biomass"], 4],
            # 1.A.1.a.iii heat plants
            ["1.A.1.a.iii. Heat plants", ["1.A.1.a.iii", "Total"], 3],
            ["Liquid fuels", ["1.A.1.a.iii", "Liquid"], 4],
            ["Solid fuels", ["1.A.1.a.iii", "Solid"], 4],
            ["Gaseous fuels (6)", ["1.A.1.a.iii", "Gaseous"], 4],
            ["Other fossil fuels (7)", ["1.A.1.a.iii", "OtherFF"], 4],
            ["Peat (8)", ["1.A.1.a.iii", "Peat"], 4],
            ["Biomass (3)", ["1.A.1.a.iii", "Biomass"], 4],
            # b. Petroleum refining
            ["1.A.1.b. Petroleum refining", ["1.A.1.b", "Total"], 2],
            ["Liquid fuels", ["1.A.1.b", "Liquid"], 3],
            ["Solid fuels", ["1.A.1.b", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.1.b", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.1.b", "OtherFF"], 3],
            ["Peat (8)", ["1.A.1.b", "Peat"], 3],
            ["Biomass (3)", ["1.A.1.b", "Biomass"], 3],
            # c. Manufacture of solid fuels and other energy industries
            [
                "1.A.1.c. Manufacture of solid fuels and other energy industries (10)",
                ["1.A.1.c", "Total"],
                2,
            ],
            ["Liquid fuels", ["1.A.1.c", "Liquid"], 3],
            ["Solid fuels", ["1.A.1.c", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.1.c", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.1.c", "OtherFF"], 3],
            ["Peat (8)", ["1.A.1.c", "Peat"], 3],
            ["Biomass (3)", ["1.A.1.c", "Biomass"], 3],
            ["Drop-down list:", ["\\IGNORE", "\\IGNORE"], 3],  # (empty)
            # 1.A.1.c.i Manufacture of solid fuels
            ["1.A.1.c.i. Manufacture of solid fuels", ["1.A.1.c.i", "Total"], 3],
            ["Liquid fuels", ["1.A.1.c.i", "Liquid"], 4],
            ["Solid fuels", ["1.A.1.c.i", "Solid"], 4],
            ["Gaseous fuels (6)", ["1.A.1.c.i", "Gaseous"], 4],
            ["Other fossil fuels (7)", ["1.A.1.c.i", "OtherFF"], 4],
            ["Peat (8)", ["1.A.1.c.i", "Peat"], 4],
            ["Biomass (3)", ["1.A.1.c.i", "Biomass"], 4],
            # 1.A.1.c.ii Oil and gas extraction
            ["1.A.1.c.ii. Oil and gas extraction", ["1.A.1.c.ii", "Total"], 3],
            ["Liquid fuels", ["1.A.1.c.ii", "Liquid"], 4],
            ["Solid fuels", ["1.A.1.c.ii", "Solid"], 4],
            ["Gaseous fuels (6)", ["1.A.1.c.ii", "Gaseous"], 4],
            ["Other fossil fuels (7)", ["1.A.1.c.ii", "OtherFF"], 4],
            ["Peat (8)", ["1.A.1.c.ii", "Peat"], 4],
            ["Biomass (3)", ["1.A.1.c.ii", "Biomass"], 4],
            # 1.A.1.c.iii Other energy industries
            ["1.A.1.c.iii. Other energy industries", ["1.A.1.c.iii", "Total"], 3],
            ["Liquid fuels", ["1.A.1.c.iii", "Liquid"], 4],
            ["Solid fuels", ["1.A.1.c.iii", "Solid"], 4],
            ["Gaseous fuels (6)", ["1.A.1.c.iii", "Gaseous"], 4],
            ["Other fossil fuels (7)", ["1.A.1.c.iii", "OtherFF"], 4],
            ["Peat (8)", ["1.A.1.c.iii", "Peat"], 4],
            ["Biomass (3)", ["1.A.1.c.iii", "Biomass"], 4],
        ],
        "entity_mapping": {
            "EMISSIONS CH4": "CH4",
            "EMISSIONS CO2 (2,3)": "CO2",
            "EMISSIONS N2O": "N2O",
        },
    },  # tested
    "Table1.A(a)s2": {
        "status": "tested",
        "table": {
            "firstrow": 7,
            "lastrow": 131,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category", "class"],
            "cols_to_ignore": [
                "AGGREGATE ACTIVITY DATA Consumption",
                "AGGREGATE ACTIVITY DATA Consumption",
                "IMPLIED EMISSION FACTORS CO2 (1)",
                "IMPLIED EMISSION FACTORS CH4",
                "IMPLIED EMISSION FACTORS N2O",
                "AMOUNT CAPTURED (4) CO2",
            ],
            "stop_cats": [
                "",
                "nan",
                "Note: Minimum level of aggregation is needed to protect "
                "confidential business and military information, where it "
                "would identify particular entity's/entities' confidential "
                "data.",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["1.A.2 Manufacturing industries and construction", ["1.A.2", "Total"], 0],
            ["Liquid fuels", ["1.A.2", "Liquid"], 1],
            ["Solid fuels", ["1.A.2", "Solid"], 1],
            ["Gaseous fuels (6)", ["1.A.2", "Gaseous"], 1],
            ["Other fossil fuels (7)", ["1.A.2", "OtherFF"], 1],
            ["Peat (8)", ["1.A.2", "Peat"], 1],
            ["Biomass (3)", ["1.A.2", "Biomass"], 1],
            # a. Iron and Steel
            ["1.A.2.a. Iron and steel", ["1.A.2.a", "Total"], 1],
            ["Liquid fuels", ["1.A.2.a", "Liquid"], 2],
            ["Solid fuels", ["1.A.2.a", "Solid"], 2],
            ["Gaseous fuels (6)", ["1.A.2.a", "Gaseous"], 2],
            ["Other fossil fuels (7)", ["1.A.2.a", "OtherFF"], 2],
            ["Peat (8)", ["1.A.2.a", "Peat"], 2],
            ["Biomass (3)", ["1.A.2.a", "Biomass"], 2],
            # b. non-ferrous metals
            ["1.A.2.b. Non-ferrous metals", ["1.A.2.b", "Total"], 1],
            ["Liquid fuels", ["1.A.2.b", "Liquid"], 2],
            ["Solid fuels", ["1.A.2.b", "Solid"], 2],
            ["Gaseous fuels (6)", ["1.A.2.b", "Gaseous"], 2],
            ["Other fossil fuels (7)", ["1.A.2.b", "OtherFF"], 2],
            ["Peat (8)", ["1.A.2.b", "Peat"], 2],
            ["Biomass (3)", ["1.A.2.b", "Biomass"], 2],
            # c. Chemicals
            ["1.A.2.c. Chemicals", ["1.A.2.c", "Total"], 1],
            ["Liquid fuels", ["1.A.2.c", "Liquid"], 2],
            ["Solid fuels", ["1.A.2.c", "Solid"], 2],
            ["Gaseous fuels (6)", ["1.A.2.c", "Gaseous"], 2],
            ["Other fossil fuels (7)", ["1.A.2.c", "OtherFF"], 2],
            ["Peat (8)", ["1.A.2.c", "Peat"], 2],
            ["Biomass (3)", ["1.A.2.c", "Biomass"], 2],
            # d. Pulp paper print
            ["1.A.2.d. Pulp, paper and print", ["1.A.2.d", "Total"], 1],
            ["Liquid fuels", ["1.A.2.d", "Liquid"], 2],
            ["Solid fuels", ["1.A.2.d", "Solid"], 2],
            ["Gaseous fuels (6)", ["1.A.2.d", "Gaseous"], 2],
            ["Other fossil fuels (7)", ["1.A.2.d", "OtherFF"], 2],
            ["Peat (8)", ["1.A.2.d", "Peat"], 2],
            ["Biomass (3)", ["1.A.2.d", "Biomass"], 2],
            # e. Food processing, beverages and tobacco
            [
                "1.A.2.e. Food processing, beverages and tobacco",
                ["1.A.2.e", "Total"],
                1,
            ],
            ["Liquid fuels", ["1.A.2.e", "Liquid"], 2],
            ["Solid fuels", ["1.A.2.e", "Solid"], 2],
            ["Gaseous fuels (6)", ["1.A.2.e", "Gaseous"], 2],
            ["Other fossil fuels (7)", ["1.A.2.e", "OtherFF"], 2],
            ["Peat (8)", ["1.A.2.e", "Peat"], 2],
            ["Biomass (3)", ["1.A.2.e", "Biomass"], 2],
            # f. non-metallic minerals
            ["1.A.2.f. Non-metallic minerals", ["1.A.2.f", "Total"], 1],
            ["Liquid fuels", ["1.A.2.f", "Liquid"], 2],
            ["Solid fuels", ["1.A.2.f", "Solid"], 2],
            ["Gaseous fuels (6)", ["1.A.2.f", "Gaseous"], 2],
            ["Other fossil fuels (7)", ["1.A.2.f", "OtherFF"], 2],
            ["Peat (8)", ["1.A.2.f", "Peat"], 2],
            ["Biomass (3)", ["1.A.2.f", "Biomass"], 2],
            # g. other
            ["\\C!-ECU-CHL\\ 1.A.2.g. Other (11)", ["1.A.2.g", "Total"], 1],
            ["\\C!-ECU-CHL\\ Liquid fuels", ["1.A.2.g", "Liquid"], 2],
            ["\\C!-ECU-CHL\\ Solid fuels", ["1.A.2.g", "Solid"], 2],
            ["\\C!-ECU-CHL\\ Gaseous fuels (6)", ["1.A.2.g", "Gaseous"], 2],
            ["\\C!-ECU-CHL\\ Other fossil fuels (7)", ["1.A.2.g", "OtherFF"], 2],
            ["\\C!-ECU-CHL\\ Peat (8)", ["1.A.2.g", "Peat"], 2],
            ["\\C!-ECU-CHL\\ Biomass (3)", ["1.A.2.g", "Biomass"], 2],
            ["\\C!-ECU-CHL\\ Drop-down list:", ["\\IGNORE", "\\IGNORE"], 2],
            # ["\\C-ECU\\ 1.A.2.g. Other (please specify)(11)", ["1.A.2.g", "Total"], 1],
            [
                "\\C-CHL-ECU\\ 1.A.2.g. Other (please specify) (11)",
                ["1.A.2.g", "Total"],
                1,
            ],
            ["\\C-CHL-ECU\\ Dropdown list", ["\\IGNORE", "\\IGNORE"], 2],
            # 1.A.2.g.i Manufacturing of machinery
            ["1.A.2.g.i. Manufacturing of machinery", ["1.A.2.g.i", "Total"], 2],
            ["Liquid fuels", ["1.A.2.g.i", "Liquid"], 3],
            ["Solid fuels", ["1.A.2.g.i", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.2.g.i", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.2.g.i", "OtherFF"], 3],
            ["Peat (8)", ["1.A.2.g.i", "Peat"], 3],
            ["Biomass (3)", ["1.A.2.g.i", "Biomass"], 3],
            # 1.A.2.g.ii Manufacturing of transport equipment
            [
                "1.A.2.g.ii. Manufacturing of transport equipment",
                ["1.A.2.g.ii", "Total"],
                2,
            ],
            ["Liquid fuels", ["1.A.2.g.ii", "Liquid"], 3],
            ["Solid fuels", ["1.A.2.g.ii", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.2.g.ii", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.2.g.ii", "OtherFF"], 3],
            ["Peat (8)", ["1.A.2.g.ii", "Peat"], 3],
            ["Biomass (3)", ["1.A.2.g.ii", "Biomass"], 3],
            # 1.A.2.g.iii Mining (excluding fuels) and quarrying
            [
                "1.A.2.g.iii. Mining (excluding fuels) and quarrying",
                ["1.A.2.g.iii", "Total"],
                2,
            ],
            ["Liquid fuels", ["1.A.2.g.iii", "Liquid"], 3],
            ["Solid fuels", ["1.A.2.g.iii", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.2.g.iii", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.2.g.iii", "OtherFF"], 3],
            ["Peat (8)", ["1.A.2.g.iii", "Peat"], 3],
            ["Biomass (3)", ["1.A.2.g.iii", "Biomass"], 3],
            # 1.A.2.g.iv Wood and wood products
            ["1.A.2.g.iv. Wood and wood products", ["1.A.2.g.iv", "Total"], 2],
            ["Liquid fuels", ["1.A.2.g.iv", "Liquid"], 3],
            ["Solid Fuels", ["1.A.2.g.iv", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.2.g.iv", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.2.g.iv", "OtherFF"], 3],
            ["Peat (8)", ["1.A.2.g.iv", "Peat"], 3],
            ["Biomass (3)", ["1.A.2.g.iv", "Biomass"], 3],
            # 1.A.2.g.v Construction
            ["1.A.2.g.v. Construction", ["1.A.2.g.v", "Total"], 2],
            ["Liquid fuels", ["1.A.2.g.v", "Liquid"], 3],
            ["Solid fuels", ["1.A.2.g.v", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.2.g.v", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.2.g.v", "OtherFF"], 3],
            ["Peat (8)", ["1.A.2.g.v", "Peat"], 3],
            ["Biomass (3)", ["1.A.2.g.v", "Biomass"], 3],
            # 1.A.2.g.vi Textile and leather
            ["1.A.2.g.vi. Textile and leather", ["1.A.2.g.vi", "Total"], 2],
            ["Liquid fuels", ["1.A.2.g.vi", "Liquid"], 3],
            ["Solid fuels", ["1.A.2.g.vi", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.2.g.vi", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.2.g.vi", "OtherFF"], 3],
            ["Peat (8)", ["1.A.2.g.vi", "Peat"], 3],
            ["Biomass (3)", ["1.A.2.g.vi", "Biomass"], 3],
            # 1.A.2.g.vii Off-road vehicles and other machinery
            [
                "1.A.2.g.vii. Off-road vehicles and other machinery",
                ["1.A.2.g.vii", "Total"],
                2,
            ],
            ["Gasoline", ["1.A.2.g.vii", "Gasoline"], 3],
            ["Diesel oil", ["1.A.2.g.vii", "DieselOil"], 3],
            ["Liquefied petroleum gases (LPG)", ["1.A.2.g.vii", "LPG"], 3],
            ["Other liquid fuels (please specify)", ["1.A.2.g.vii", "OtherLiquid"], 3],
            ["\\C-AUS-CHL-ECU\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-"
                "MAR-NAM-NGA-PAN-PRY-URY\\ "
                "Other liquid fuels [IPCC Software 1.A.3.e.ii]",
                ["1.A.2.g.vii", "OLOther"],
                4,
            ],
            ["\\C-ISL\\ Other", ["1.A.2.g.vii", "OLOther"], 4],
            ["\\C-SGP\\ Residual fuel oil", ["1.A.2.g.vii", "ResFuelOil"], 4],
            [
                "\\C-CAN\\ Biodiesel (5 percent fossil portion)",
                ["1.A.2.g.vii", "OLBiodieselFC"],
                4,
            ],
            [
                "\\C-CAN\\ Lubricating Oil (Two-Stroke Engines)",
                ["1.A.2.g.vii", "Lubricants"],
                4,
            ],
            ["\\C-FIN\\ Gasoil", ["1.A.2.g.vii", "Gasoil"], 4],
            ["\\C-SWE\\ All Liquid Fuels", ["1.A.2.g.vii", "OLOther"], 4],
            ["\\C-COL\\ Crude Oil", ["1.A.2.g.vii", "CrudeOil"], 4],
            ["Gaseous fuels (6)", ["1.A.2.g.vii", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.2.g.vii", "OtherFF"], 3],
            ["Biomass (3)", ["1.A.2.g.vii", "Biomass"], 3],
            # 1.A.2.g.viii Other (please specify)
            ["1.A.2.g.viii. Other (please specify)", ["1.A.2.g.viii", "Total"], 2],
            # ["Liquid fuels", ["1.A.2.g.viii.3", "Liquid"], 4],
            # ["Solid fuels", ["1.A.2.g.viii.3", "Solid"], 4],
            # ["Gaseous fuels (6)", ["1.A.2.g.viii.3", "Gaseous"], 4],
            # ["Other fossil fuels (7)", ["1.A.2.g.viii.3", "OtherFF"], 4],
            # ["Peat (8)", ["1.A.2.g.viii.3", "Peat"], 4],
            # ["Biomass (3)", ["1.A.2.g.viii.3", "Biomass"], 4],
            # other / non-specified (1.A.2.g.viii.1)
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB\\ Non-specified Industry [IPCC Software 1.A.2.m]",
                ["1.A.2.g.viii.1", "Total"],
                3,
            ],
            [
                "\\C-SVN\\ Other manufacturing industries and construction",
                ["1.A.2.g.viii.1", "Total"],
                3,
            ],
            ["\\C-MCO\\ industry", ["1.A.2.g.viii.1", "Total"], 3],
            ["\\C-SVK-GEO\\ Non-specified Industry", ["1.A.2.g.viii.1", "Total"], 3],
            ["\\C-LTU-SRB\\ Non-specified industry", ["1.A.2.g.viii.1", "Total"], 3],
            ["\\C-ARG\\ Unspecified industries", ["1.A.2.g.viii.1", "Total"], 3],
            ["\\C-ISL\\ Other industry", ["1.A.2.g.viii.1", "Total"], 3],
            ["\\C-UKR\\ Oter Industries", ["1.A.2.g.viii.1", "Total"], 3],
            ["\\C-NLD\\ Other Industrial Sectors", ["1.A.2.g.viii.1", "Total"], 3],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB-SVN-MCO-SVK-GEO-LTU-SRB-ARG-ISL-UKR-NLD\\ Liquid fuels",
                ["1.A.2.g.viii.1", "Liquid"],
                4,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB-SVN-MCO-SVK-GEO-LTU-SRB-ARG-ISL-UKR-NLD\\ Solid fuels",
                ["1.A.2.g.viii.1", "Solid"],
                4,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB-SVN-MCO-SVK-GEO-LTU-SRB-ARG-ISL-UKR-NLD\\ Gaseous fuels (6)",
                ["1.A.2.g.viii.1", "Gaseous"],
                4,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB-SVN-MCO-SVK-GEO-LTU-SRB-ARG-ISL-UKR-NLD\\ Other fossil fuels (7)",
                ["1.A.2.g.viii.1", "OtherFF"],
                4,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB-SVN-MCO-SVK-GEO-LTU-SRB-ARG-ISL-UKR-NLD\\ Peat (8)",
                ["1.A.2.g.viii.1", "Peat"],
                4,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB-SVN-MCO-SVK-GEO-LTU-SRB-ARG-ISL-UKR-NLD\\ Biomass (3)",
                ["1.A.2.g.viii.1", "Biomass"],
                4,
            ],
            # all industry (1.A.2.g.viii.2)
            ["\\C-MLT\\ All Industry", ["1.A.2.g.viii.2", "Total"], 3],
            ["\\C-MLT\\ Liquid fuels", ["1.A.2.g.viii.2", "Liquid"], 4],
            ["\\C-MLT\\ Solid fuels", ["1.A.2.g.viii.2", "Solid"], 4],
            ["\\C-MLT\\ Gaseous fuels (6)", ["1.A.2.g.viii.2", "Gaseous"], 4],
            ["\\C-MLT\\ Other fossil fuels (7)", ["1.A.2.g.viii.2", "OtherFF"], 4],
            ["\\C-MLT\\ Peat (8)", ["1.A.2.g.viii.2", "Peat"], 4],
            ["\\C-MLT\\ Biomass (3)", ["1.A.2.g.viii.2", "Biomass"], 4],
            # other manufacturing (1.A.2.g.viii.3)
            [
                "\\C-AUT-DNK-FIN\\ Other manufacturing industries",
                ["1.A.2.g.viii.3", "Total"],
                3,
            ],
            [
                "\\C-AUS-CHL-ECU\\ All Other Manufacturing",
                ["1.A.2.g.viii.3", "Total"],
                3,
            ],
            ["\\C-NOR-CAN\\ Other Manufacturing", ["1.A.2.g.viii.3", "Total"], 3],
            [
                "\\C-AUT-DNK-FIN-AUS-CHL-ECU-NOR-CAN\\ Liquid fuels",
                ["1.A.2.g.viii.3", "Liquid"],
                4,
            ],
            [
                "\\C-AUT-DNK-FIN-AUS-CHL-ECU-NOR-CAN\\ Solid fuels",
                ["1.A.2.g.viii.3", "Solid"],
                4,
            ],
            [
                "\\C-AUT-DNK-FIN-AUS-CHL-ECU-NOR-CAN\\ Gaseous fuels (6)",
                ["1.A.2.g.viii.3", "Gaseous"],
                4,
            ],
            [
                "\\C-AUT-DNK-FIN-AUS-CHL-ECU-NOR-CAN\\ Other fossil fuels (7)",
                ["1.A.2.g.viii.3", "OtherFF"],
                4,
            ],
            [
                "\\C-AUT-DNK-FIN-AUS-CHL-ECU-NOR-CAN\\ Peat (8)",
                ["1.A.2.g.viii.3", "Peat"],
                4,
            ],
            [
                "\\C-AUT-DNK-FIN-AUS-CHL-ECU-NOR-CAN\\ Biomass (3)",
                ["1.A.2.g.viii.3", "Biomass"],
                4,
            ],
            # non-specified (1.A.2.g.viii.4)
            ["\\C-BEL\\ Other non-specified", ["1.A.2.g.viii.4", "Total"], 3],
            ["\\C-CZE\\ Other non_specified", ["1.A.2.g.viii.4", "Total"], 3],
            ["\\C-BRA\\ Not specified", ["1.A.2.g.viii.4", "Total"], 3],
            ["\\C-GHA\\ Non-specified sectors", ["1.A.2.g.viii.4", "Total"], 3],
            ["\\C-CHN\\ other", ["1.A.2.g.viii.4", "Total"], 3],
            ["\\C-RUS\\ Other industries", ["1.A.2.g.viii.4", "Total"], 3],
            ["\\C-DZA-COL-LVA\\ Other", ["1.A.2.g.viii.4", "Total"], 3],
            [
                "\\C-BEL-CZE-BRA-GHA-CHN-RUS-DZA-COL-LVA\\ Liquid fuels",
                ["1.A.2.g.viii.4", "Liquid"],
                4,
            ],
            [
                "\\C-BEL-CZE-BRA-GHA-CHN-RUS-DZA-COL-LVA\\ Solid fuels",
                ["1.A.2.g.viii.4", "Solid"],
                4,
            ],
            [
                "\\C-BEL-CZE-BRA-GHA-CHN-RUS-DZA-COL-LVA\\ Gaseous fuels (6)",
                ["1.A.2.g.viii.4", "Gaseous"],
                4,
            ],
            [
                "\\C-BEL-CZE-BRA-GHA-CHN-RUS-DZA-COL-LVA\\ Other fossil fuels (7)",
                ["1.A.2.g.viii.4", "OtherFF"],
                4,
            ],
            [
                "\\C-BEL-CZE-BRA-GHA-CHN-RUS-DZA-COL-LVA\\ Peat (8)",
                ["1.A.2.g.viii.4", "Peat"],
                4,
            ],
            [
                "\\C-BEL-CZE-BRA-GHA-CHN-RUS-DZA-COL-LVA\\ Biomass (3)",
                ["1.A.2.g.viii.4", "Biomass"],
                4,
            ],
            # Non-CO2 emissions from BFG combustion (1.A.2.g.viii.5)
            [
                "\\C-RUS\\ Non-CO2 emissions from BFG combustion",
                ["1.A.2.g.viii.5", "Total"],
                3,
            ],
            ["\\C-RUS\\ Liquid fuels", ["1.A.2.g.viii.5", "Liquid"], 4],
            ["\\C-RUS\\ Solid fuels", ["1.A.2.g.viii.5", "Solid"], 4],
            ["\\C-RUS\\ Gaseous fuels (6)", ["1.A.2.g.viii.5", "Gaseous"], 4],
            ["\\C-RUS\\ Other fossil fuels (7)", ["1.A.2.g.viii.5", "OtherFF"], 4],
            ["\\C-RUS\\ Peat (8)", ["1.A.2.g.viii.5", "Peat"], 4],
            ["\\C-RUS\\ Biomass (3)", ["1.A.2.g.viii.5", "Biomass"], 4],
            # Rubber (1.A.2.g.vii.6)
            ["\\C-PRT\\ Rubber", ["1.A.2.g.viii.6", "Total"], 3],
            ["\\C-PRT\\ Liquid fuels", ["1.A.2.g.viii.6", "Liquid"], 4],
            ["\\C-PRT\\ Solid fuels", ["1.A.2.g.viii.6", "Solid"], 4],
            ["\\C-PRT\\ Gaseous fuels (6)", ["1.A.2.g.viii.6", "Gaseous"], 4],
            ["\\C-PRT\\ Other fossil fuels (7)", ["1.A.2.g.viii.6", "OtherFF"], 4],
            ["\\C-PRT\\ Peat (8)", ["1.A.2.g.viii.6", "Peat"], 4],
            ["\\C-PRT\\ Biomass (3)", ["1.A.2.g.viii.6", "Biomass"], 4],
            # All stationary combustin within CRF 1.A.2.g (1.A.2.g.viii.7)
            [
                "\\C-SWE\\ All stationary combustin within CRF 1.A.2.g",
                ["1.A.2.g.viii.7", "Total"],
                3,
            ],
            ["\\C-SWE\\ Liquid fuels", ["1.A.2.g.viii.7", "Liquid"], 4],
            ["\\C-SWE\\ Solid fuels", ["1.A.2.g.viii.7", "Solid"], 4],
            ["\\C-SWE\\ Gaseous fuels (6)", ["1.A.2.g.viii.7", "Gaseous"], 4],
            ["\\C-SWE\\ Other fossil fuels (7)", ["1.A.2.g.viii.7", "OtherFF"], 4],
            ["\\C-SWE\\ Peat (8)", ["1.A.2.g.viii.7", "Peat"], 4],
            ["\\C-SWE\\ Biomass (3)", ["1.A.2.g.viii.7", "Biomass"], 4],
            # Placeholder (1.A.2.g.viii.8)
            # Other Boilers and Engines Industry (1.A.2.g.viii.9)
            [
                "\\C-CHE\\ Other Boilers and Engines Industry",
                ["1.A.2.g.viii.9", "Total"],
                3,
            ],
            ["\\C-CHE\\ Liquid fuels", ["1.A.2.g.viii.9", "Liquid"], 4],
            ["\\C-CHE\\ Solid fuels", ["1.A.2.g.viii.9", "Solid"], 4],
            ["\\C-CHE\\ Gaseous fuels (6)", ["1.A.2.g.viii.9", "Gaseous"], 4],
            ["\\C-CHE\\ Other fossil fuels (7)", ["1.A.2.g.viii.9", "OtherFF"], 4],
            ["\\C-CHE\\ Peat (8)", ["1.A.2.g.viii.9", "Peat"], 4],
            ["\\C-CHE\\ Biomass (3)", ["1.A.2.g.viii.9", "Biomass"], 4],
            # Other (1.A.2.g.viii.10)
            ["\\C-ESP-NZL-POL-TUR\\ Other", ["1.A.2.g.viii.10", "Total"], 3],
            ["\\C-HRV\\ other", ["1.A.2.g.viii.10", "Total"], 3],
            ["\\C-SGP\\ Others", ["1.A.2.g.viii.10", "Total"], 3],
            [
                "\\C-ESP-NZL-POL-TUR-HRV-SGP\\ Liquid fuels",
                ["1.A.2.g.viii.10", "Liquid"],
                4,
            ],
            [
                "\\C-ESP-NZL-POL-TUR-HRV-SGP\\ Solid fuels",
                ["1.A.2.g.viii.10", "Solid"],
                4,
            ],
            [
                "\\C-ESP-NZL-POL-TUR-HRV-SGP\\ Gaseous fuels (6)",
                ["1.A.2.g.viii.10", "Gaseous"],
                4,
            ],
            [
                "\\C-ESP-NZL-POL-TUR-HRV-SGP\\ Other fossil fuels (7)",
                ["1.A.2.g.viii.10", "OtherFF"],
                4,
            ],
            ["\\C-ESP-NZL-POL-TUR-HRV-SGP\\ Peat (8)", ["1.A.2.g.viii.10", "Peat"], 4],
            [
                "\\C-ESP-NZL-POL-TUR-HRV-SGP\\ Biomass (3)",
                ["1.A.2.g.viii.10", "Biomass"],
                4,
            ],
            # Construction (1.A.2.g.viii.11)
            ["\\C-RUS\\ Construction", ["1.A.2.g.viii.11", "Total"], 3],
            [  # not a perfect fit
                "\\C-USA\\ Construction, agriculture, and other non-transport vehicles",
                ["1.A.2.g.viii.11", "Total"],
                3,
            ],
            ["\\C-RUS-USA\\ Liquid fuels", ["1.A.2.g.viii.11", "Liquid"], 4],
            ["\\C-RUS-USA\\ Solid fuels", ["1.A.2.g.viii.11", "Solid"], 4],
            ["\\C-RUS-USA\\ Gaseous fuels (6)", ["1.A.2.g.viii.11", "Gaseous"], 4],
            ["\\C-RUS-USA\\ Other fossil fuels (7)", ["1.A.2.g.viii.11", "OtherFF"], 4],
            ["\\C-RUS-USA\\ Peat (8)", ["1.A.2.g.viii.11", "Peat"], 4],
            ["\\C-RUS-USA\\ Biomass (3)", ["1.A.2.g.viii.11", "Biomass"], 4],
            # Off-road - Manufacturing industries and construction- solid fuels
            # [IPCC Software 1.A.3.e.ii] (1.A.2.g.viii.12)
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-"
                "PRY-URY\\ Off-road - Manufacturing industries and construction- "
                "solid fuels [IPCC Software 1.A.3.e.ii]",
                ["1.A.2.g.viii.12", "Total"],
                3,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-"
                "PRY-URY\\ Liquid fuels",
                ["1.A.2.g.viii.12", "Liquid"],
                4,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-"
                "PRY-URY\\ Solid fuels",
                ["1.A.2.g.viii.12", "Solid"],
                4,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-"
                "PRY-URY\\ Gaseous fuels (6)",
                ["1.A.2.g.viii.12", "Gaseous"],
                4,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-"
                "PRY-URY\\ Other fossil fuels (7)",
                ["1.A.2.g.viii.12", "OtherFF"],
                4,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-"
                "PRY-URY\\ Peat (8)",
                ["1.A.2.g.viii.12", "Peat"],
                4,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-PAN-"
                "PRY-URY\\ Biomass (3)",
                ["1.A.2.g.viii.12", "Biomass"],
                4,
            ],
            # Other Transformation Industry (1.A.2.g.viii.13)
            [
                "\\C-PRT\\ Other Transformation Industry",
                ["1.A.2.g.viii.13", "Total"],
                3,
            ],
            ["\\C-PRT\\ Liquid fuels", ["1.A.2.g.viii.13", "Liquid"], 4],
            ["\\C-PRT\\ Solid fuels", ["1.A.2.g.viii.13", "Solid"], 4],
            ["\\C-PRT\\ Gaseous fuels (6)", ["1.A.2.g.viii.13", "Gaseous"], 4],
            ["\\C-PRT\\ Other fossil fuels (7)", ["1.A.2.g.viii.13", "OtherFF"], 4],
            ["\\C-PRT\\ Peat (8)", ["1.A.2.g.viii.13", "Peat"], 4],
            ["\\C-PRT\\ Biomass (3)", ["1.A.2.g.viii.13", "Biomass"], 4],
        ],
        "entity_mapping": {
            "EMISSIONS CH4": "CH4",
            "EMISSIONS CO2 (2,3)": "CO2",
            "EMISSIONS N2O": "N2O",
        },
    },  # tested
    "Table1.A(a)s3": {
        "status": "tested",
        "table": {
            "firstrow": 7,
            "lastrow": 121,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category", "class"],
            "cols_to_ignore": [
                "AGGREGATE ACTIVITY DATA Consumption",
                "AGGREGATE ACTIVITY DATA Consumption",
                "IMPLIED EMISSION FACTORS CO2 (1)",
                "IMPLIED EMISSION FACTORS CH4",
                "IMPLIED EMISSION FACTORS N2O",
            ],
            "stop_cats": [
                "Note: Minimum level of aggregation is needed to protect confidential "
                "business and military information, where it would identify particular "
                "entity's/entities' confidential data."
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["1.A.3 Transport", ["1.A.3", "Total"], 0],
            ["Liquid fuels", ["1.A.3", "Liquid"], 1],
            ["Solid fuels", ["1.A.3", "Solid"], 1],
            ["Gaseous fuels (6)", ["1.A.3", "Gaseous"], 1],
            ["Other fossil fuels (7)", ["1.A.3", "OtherFF"], 1],
            ["Biomass (3)", ["1.A.3", "Biomass"], 1],
            # a. Domestic Aviation
            ["1.A.3.a. Domestic aviation (12)", ["1.A.3.a", "Total"], 1],
            ["Aviation gasoline", ["1.A.3.a", "AvGasoline"], 2],
            ["Jet kerosene", ["1.A.3.a", "JetKerosene"], 2],
            ["Biomass", ["1.A.3.a", "Biomass"], 2],
            ["\\C-CHL\\ Liquid fuels", ["1.A.3.a", "Liquid"], 2],
            ["\\C-CHL\\ Gaseous fuels", ["1.A.3.a", "Gaseous"], 2],
            # b. road Transportation
            ["1.A.3.b. Road transportation (13)", ["1.A.3.b", "Total"], 1],
            ["Gasoline", ["1.A.3.b", "Gasoline"], 2],
            ["Diesel oil", ["1.A.3.b", "DieselOil"], 2],
            ["Liquefied petroleum gases (LPG)", ["1.A.3.b", "LPG"], 2],
            ["\\C!-CHL-ECU\\ Other liquid fuels", ["1.A.3.b", "OtherLiquid"], 2],
            [
                "\\C-CHL-ECU\\ Other liquid fuels (please specify)",
                ["1.A.3.b", "OtherLiquid"],
                2,
            ],
            ["\\C-AUS-CHL-ECU-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 3],
            ["Gaseous fuels (6)", ["1.A.3.b", "Gaseous"], 2],
            ["Biomass (3)", ["1.A.3.b", "Biomass"], 2],
            ["\\C!-CHL-ECU\\ Other fossil fuels (7)", ["1.A.3.b", "OtherFF"], 2],
            [
                "\\C-CHL-ECU\\ Other fossil fuels (please specify) (7)",
                ["1.A.3.b", "OtherFF"],
                2,
            ],
            ["\\C-AUS-ECU\\ Lubricants", ["1.A.3.b", "OFFLubricants"], 3],
            ["\\C-CHL-ECU-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 3],
            # i. Cars
            ["1.A.3.b.i. Cars", ["1.A.3.b.i", "Total"], 2],
            ["Gasoline", ["1.A.3.b.i", "Gasoline"], 3],
            ["Diesel oil", ["1.A.3.b.i", "DieselOil"], 3],
            ["Liquefied petroleum gases (LPG)", ["1.A.3.b.i", "LPG"], 3],
            ["Other liquid fuels (please specify)", ["1.A.3.b.i", "OtherLiquid"], 3],
            ["\\C-AUS-CHL-ECU-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-FRA\\ Other liquid fuels "
                "[IPCC Software 1.A.3.b.i, 1.A.3.b.i.1, 1.A.3.b.i.2]",
                ["1.A.3.b.i", "OLOther"],
                4,
            ],
            ["\\C-RUS\\ Other motor fuels", ["1.A.3.b.i", "OMotorFuel"], 4],
            ["\\C-LVA\\ Lubricant", ["1.A.3.b.i", "Lubricants"], 4],
            ["\\C-UKR\\ Lubricants", ["1.A.3.b.i", "Lubricants"], 4],
            ["\\C-UKR\\ Keroseve", ["1.A.3.b.i", "Kerosene"], 4],
            ["\\C-UKR\\ Other", ["1.A.3.b.i", "OLOther"], 4],
            [
                "\\C-CAN\\ Biodiesel (5 percent fossil portion)",
                ["1.A.3.b.i", "OLBiodieselFC"],
                4,
            ],
            ["\\C-DNK\\ Fossil part of biodiesel", ["1.A.3.b.i", "OLBiodieselFC"], 4],
            ["\\C-USA\\ LNG", ["1.A.3.b.i", "LNG"], 4],
            ["\\C-CHN\\ methanol", ["1.A.3.b.i", "Methanol"], 4],
            ["Gaseous fuels (6)", ["1.A.3.b.i", "Gaseous"], 3],
            ["Biomass (3)", ["1.A.3.b.i", "Biomass"], 3],
            ["Other fossil fuels (please specify)(7)", ["1.A.3.b.i", "OtherFF"], 3],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-FRA\\ Other fossil fuels "
                "[IPCC Software 1.A.3.b.i, 1.A.3.b.i.1, 1.A.3.b.i.2]",
                ["1.A.3.b.i", "OFFOther"],
                4,
            ],
            ["\\C-CHL-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            ["\\C-AUS-ECU\\ Lubricants", ["1.A.3.b.i", "OFFLubricants"], 4],
            ["\\C-AUT\\ FAME fossil part", ["1.A.3.b.i", "OFFBiodieselFC"], 4],
            ["\\C-SVN\\ Fossil part of biofuel", ["1.A.3.b.i", "OFFBiofuelFC"], 4],
            ["\\C-SVK\\ Fossil part of biofuels", ["1.A.3.b.i", "OFFBiofuelFC"], 4],
            ["\\C-CZE\\ fossil part of biofuels", ["1.A.3.b.i", "OFFBiofuelFC"], 4],
            [
                "\\C-BEL\\ Fossil part of biogasoline",
                ["1.A.3.b.i", "OFFBiogasolineFC"],
                4,
            ],
            [
                "\\C-BEL-ESP-LTU-LVA\\ Fossil part of biodiesel",
                ["1.A.3.b.i", "OFFBiodieselFC"],
                4,
            ],
            ["\\C-HRV\\ Fosil part of biodiesel", ["1.A.3.b.i", "OFFBiodieselFC"], 4],
            ["\\C-NOR\\ Biodiesel fossil fraction", ["1.A.3.b.i", "OFFBiodieselFC"], 4],
            [
                "\\C-NZL\\ Biodiesel (fossil fraction)",
                ["1.A.3.b.i", "OFFBiodieselFC"],
                4,
            ],
            ["\\C-POL\\ Other fossil fuels", ["1.A.3.b.i", "OFFOther"], 4],
            ["\\C-COL-UKR\\ Other", ["1.A.3.b.i", "OFFOther"], 4],
            ["\\C-GRC\\ Other fossil fuel", ["1.A.3.b.i", "OFFOther"], 4],
            [
                "\\C-SWE\\ Fossil part of biodiesel and biogasoline",
                ["1.A.3.b.i", "OFFBiofuelFC"],
                4,
            ],
            ["\\C-USA\\ Natural gas", ["1.A.3.b.i", "OFFNaturalGas"], 4],
            # ii. Light duty trucks
            ["1.A.3.b.ii. Light duty trucks", ["1.A.3.b.ii", "Total"], 2],
            ["Gasoline", ["1.A.3.b.ii", "Gasoline"], 3],
            ["Diesel oil", ["1.A.3.b.ii", "DieselOil"], 3],
            ["Liquefied petroleum gases (LPG)", ["1.A.3.b.ii", "LPG"], 3],
            ["Other liquid fuels (please specify)", ["1.A.3.b.ii", "OtherLiquid"], 3],
            ["\\C-AUS-CHL-ECU-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-FRA\\ Other liquid fuels "
                "[IPCC Software 1.A.3.b.ii, 1.A.3.b.ii.1, 1.A.3.b.ii.2]",
                ["1.A.3.b.ii", "OLOther"],
                4,
            ],
            ["\\C-RUS\\ Other motor fuels", ["1.A.3.b.ii", "OMotorFuel"], 4],
            ["\\C-LVA\\ Lubricant", ["1.A.3.b.ii", "Lubricants"], 4],
            ["\\C-UKR\\ Lubricants", ["1.A.3.b.ii", "Lubricants"], 4],
            ["\\C-UKR\\ Kerosene", ["1.A.3.b.ii", "Kerosene"], 4],
            ["\\C-COL-UKR\\ Other", ["1.A.3.b.ii", "OLOther"], 4],
            [
                "\\C-CAN\\ Biodiesel (5 percent fossil portion)",
                ["1.A.3.b.ii", "OLBiodieselFC"],
                4,
            ],
            ["\\C-DNK\\ Fossil part of biodiesel", ["1.A.3.b.ii", "OLBiodieselFC"], 4],
            ["\\C-USA\\ LNG", ["1.A.3.b.ii", "LNG"], 4],
            ["Gaseous fuels (6)", ["1.A.3.b.ii", "Gaseous"], 3],
            ["Biomass (3)", ["1.A.3.b.ii", "Biomass"], 3],
            ["Other fossil fuels (please specify)(7)", ["1.A.3.b.ii", "OtherFF"], 3],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-FRA\\ Other fossil fuels "
                "[IPCC Software 1.A.3.b.ii, 1.A.3.b.ii.1, 1.A.3.b.ii.2]",
                ["1.A.3.b.ii", "OFFOther"],
                4,
            ],
            ["\\C-CHL-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            ["\\C-AUS-ECU\\ Lubricants", ["1.A.3.b.ii", "OFFLubricants"], 4],
            ["\\C-AUT\\ FAME fossil part", ["1.A.3.b.ii", "OFFBiodieselFC"], 4],
            ["\\C-SVN\\ Fossil part of biofuel", ["1.A.3.b.ii", "OFFBiofuelFC"], 4],
            ["\\C-SVK\\ Fossil part of biofuels", ["1.A.3.b.ii", "OFFBiofuelFC"], 4],
            ["\\C-CZE\\ fossil part of biofuels", ["1.A.3.b.ii", "OFFBiofuelFC"], 4],
            [
                "\\C-BEL\\ Fossil part of biogasoline",
                ["1.A.3.b.ii", "OFFBiogasolineFC"],
                4,
            ],
            [
                "\\C-BEL-ESP-LTU-LVA\\ Fossil part of biodiesel",
                ["1.A.3.b.ii", "OFFBiodieselFC"],
                4,
            ],
            ["\\C-HRV\\ Fosil part of biodiesel", ["1.A.3.b.ii", "OFFBiodieselFC"], 4],
            [
                "\\C-NOR\\ Biodiesel fossil fraction",
                ["1.A.3.b.ii", "OFFBiodieselFC"],
                4,
            ],
            [
                "\\C-NZL\\ Biodiesel (fossil fraction)",
                ["1.A.3.b.ii", "OFFBiodieselFC"],
                4,
            ],
            ["\\C-POL\\ Other fossil fuels", ["1.A.3.b.ii", "OFFOther"], 4],
            ["\\C-COL-UKR\\ Other", ["1.A.3.b.ii", "OFFOther"], 4],
            ["\\C-GRC\\ other fossil fuel", ["1.A.3.b.ii", "OFFOther"], 4],
            [
                "\\C-SWE\\ Fossil part of biodiesel and biogasoline",
                ["1.A.3.b.ii", "OFFBiofuelFC"],
                4,
            ],
            # iii. Heavy duty trucks and buses
            ["1.A.3.b.iii. Heavy duty trucks and buses", ["1.A.3.b.iii", "Total"], 2],
            ["Gasoline", ["1.A.3.b.iii", "Gasoline"], 3],
            ["Diesel oil", ["1.A.3.b.iii", "DieselOil"], 3],
            ["Liquefied petroleum gases (LPG)", ["1.A.3.b.iii", "LPG"], 3],
            ["Other liquid fuels (please specify)", ["1.A.3.b.iii", "OtherLiquid"], 3],
            ["\\C-AUS-CHL-ECU-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-FRA\\ Other liquid fuels "
                "[IPCC Software 1.A.3.b.iii]",
                ["1.A.3.b.iii", "OLOther"],
                4,
            ],
            ["\\C-MCO\\ GTL", ["1.A.3.b.iii", "GTL"], 4],
            ["\\C-RUS\\ Other motor fuels", ["1.A.3.b.iii", "OMotorFuel"], 4],
            ["\\C-LVA\\ Lubricant", ["1.A.3.b.iii", "Lubricants"], 4],
            ["\\C-UKR\\ Lubricants", ["1.A.3.b.iii", "Lubricants"], 4],
            ["\\C-UKR\\ Keresone", ["1.A.3.b.iii", "Kerosene"], 4],
            ["\\C-COL-UKR\\ Other", ["1.A.3.b.iii", "OLOther"], 4],
            [
                "\\C-CAN\\ Biodiesel (5 percent fossil portion)",
                ["1.A.3.b.iii", "OLBiodieselFC"],
                4,
            ],
            ["\\C-DNK\\ Fossil part of biodiesel", ["1.A.3.b.iii", "OLBiodieselFC"], 4],
            ["\\C-USA\\ LNG", ["1.A.3.b.iii", "LNG"], 4],
            ["Gaseous fuels (6)", ["1.A.3.b.iii", "Gaseous"], 3],
            ["Biomass (3)", ["1.A.3.b.iii", "Biomass"], 3],
            ["Other fossil fuels (please specify)(7)", ["1.A.3.b.iii", "OtherFF"], 3],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-FRA\\ Other fossil fuels [IPCC Software 1.A.3.b.iii]",
                ["1.A.3.b.iii", "OFFOther"],
                4,
            ],
            ["\\C-CHL-ECU-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            ["\\C-AUS\\ Lubricants", ["1.A.3.b.iii", "OFFLubricants"], 4],
            ["\\C-AUT\\ FAME fossil part", ["1.A.3.b.iii", "OFFBiodieselFC"], 4],
            ["\\C-SVN\\ Fossil part of biofuel", ["1.A.3.b.iii", "OFFBiofuelFC"], 4],
            ["\\C-SVK\\ Fossil part of biofuels", ["1.A.3.b.iii", "OFFBiofuelFC"], 4],
            ["\\C-CZE\\ fossil part of biofuels", ["1.A.3.b.iii", "OFFBiofuelFC"], 4],
            [
                "\\C-BEL\\ Fossil part of biogasoline",
                ["1.A.3.b.iii", "OFFBiogasolineFC"],
                4,
            ],
            [
                "\\C-BEL-ESP-LTU-LVA\\ Fossil part of biodiesel",
                ["1.A.3.b.iii", "OFFBiodieselFC"],
                4,
            ],
            ["\\C-HRV\\ Fosil part of biodiesel", ["1.A.3.b.iii", "OFFBiodieselFC"], 4],
            [
                "\\C-NOR\\ Biodiesel fossil fraction",
                ["1.A.3.b.iii", "OFFBiodieselFC"],
                4,
            ],
            [
                "\\C-NZL\\ Biodiesel (fossil fraction)",
                ["1.A.3.b.iii", "OFFBiodieselFC"],
                4,
            ],
            ["\\C-POL\\ Other fossil fuels", ["1.A.3.b.iii", "OFFOther"], 4],
            ["\\C-COL-UKR\\ Other", ["1.A.3.b.iii", "OFFOther"], 4],
            [
                "\\C-SWE\\ Fossil part of biodiesel and biogasoline",
                ["1.A.3.b.iii", "OFFBiofuelFC"],
                4,
            ],
            # iv. Motorcycles
            ["1.A.3.b.iv. Motorcycles", ["1.A.3.b.iv", "Total"], 2],
            ["Gasoline", ["1.A.3.b.iv", "Gasoline"], 3],
            ["Diesel oil", ["1.A.3.b.iv", "DieselOil"], 3],
            ["Liquefied petroleum gases (LPG)", ["1.A.3.b.iv", "LPG"], 3],
            ["Other liquid fuels (please specify)", ["1.A.3.b.iv", "OtherLiquid"], 3],
            ["\\C-CHL-ECU-AUS-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-FRA\\ Other liquid fuels [IPCC Software 1.A.3.b.iv]",
                ["1.A.3.b.iv", "OLOther"],
                4,
            ],
            [
                "\\C-ESP\\ Lubricants (two-stroke engines)",
                ["1.A.3.b.iv", "Lubricants"],
                4,
            ],
            ["\\C-MCO\\ Lube", ["1.A.3.b.iv", "Lubricants"], 4],
            ["\\C-MLT-SVN-HRV-LIE\\ Lubricants", ["1.A.3.b.iv", "Lubricants"], 4],
            ["\\C-PRT\\ Lubricant Oil", ["1.A.3.b.iv", "Lubricants"], 4],
            ["\\C-LVA\\ Lubricant", ["1.A.3.b.iv", "Lubricants"], 4],
            ["\\C-UKR\\ Lubricants", ["1.A.3.b.iv", "Lubricants"], 4],
            ["\\C-UKR\\ Kerosene", ["1.A.3.b.iv", "Kerosene"], 4],
            ["\\C-RUS\\ Other motor fuels", ["1.A.3.b.iv", "OMotorFuel"], 4],
            ["\\C-COL\\ Other", ["1.A.3.b.iv", "OLOther"], 4],
            ["\\C-UKR\\ Other/", ["1.A.3.b.iv", "OLOther"], 4],
            ["\\C-USA\\ LNG", ["1.A.3.b.iv", "LNG"], 4],
            ["Gaseous fuels (6)", ["1.A.3.b.iv", "Gaseous"], 3],
            ["Biomass (3)", ["1.A.3.b.iv", "Biomass"], 3],
            ["Other fossil fuels (please specify)(7)", ["1.A.3.b.iv", "OtherFF"], 3],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-FRA\\ Other fossil fuels [IPCC Software 1.A.3.b.iv]",
                ["1.A.3.b.iv", "OFFOther"],
                4,
            ],
            ["\\C-CHL-ECU-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            ["\\C-AUS\\ Lubricants", ["1.A.3.b.iv", "OFFLubricants"], 4],
            ["\\C-AUT\\ FAME fossil part", ["1.A.3.b.iv", "OFFBiodieselFC"], 4],
            ["\\C-SVN\\ Fossil part of biofuel", ["1.A.3.b.iv", "OFFBiofuelFC"], 4],
            ["\\C-SVK\\ Fossil part of biofuels", ["1.A.3.b.iv", "OFFBiofuelFC"], 4],
            ["\\C-CZE\\ fossil part of biofuels", ["1.A.3.b.iv", "OFFBiofuelFC"], 4],
            [
                "\\C-BEL\\ Fossil part of biogasoline",
                ["1.A.3.b.iv", "OFFBiogasolineFC"],
                4,
            ],
            ["\\C-BEL\\ Fossil part of biodiesel", ["1.A.3.b.iv", "OFFBiodieselFC"], 4],
            ["\\C-HRV\\ Fosil part of biodiesel", ["1.A.3.b.iv", "OFFBiodieselFC"], 4],
            ["\\C-COL-UKR\\ Other", ["1.A.3.b.iv", "OFFOther"], 4],
            ["\\C-GRC\\ other fossil fuel", ["1.A.3.b.iv", "OFFOther"], 4],
            [
                "\\C-SWE\\ Fossil part of biodiesel and biogasoline",
                ["1.A.3.b.iv", "OFFBiofuelFC"],
                4,
            ],
            # v. Other
            ["1.A.3.b.v. Other (please specify)", ["1.A.3.b.v", "Total"], 2],
            # NA
            ["\\C-AUS-CHL-ECU\\ NA", ["\\IGNORE", "\\IGNORE"], 3],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY\\ Not occurring [IPCC Software]",
                ["\\IGNORE", "\\IGNORE"],
                3,
            ],
            [
                "\\C-AUS-CHL-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY\\ Gasoline",
                ["\\IGNORE", "Gasoline"],
                4,
            ],
            [
                "\\C-AUS-CHL-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY\\ Diesel oil",
                ["\\IGNORE", "DieselOil"],
                4,
            ],
            [
                "\\C-AUS-CHL-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY\\ Liquefied petroleum gases (LPG)",
                ["\\IGNORE", "LPG"],
                4,
            ],
            [
                "\\C-AUS-CHL-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY\\ Other liquid fuels (please specify)",
                ["\\IGNORE", "OtherLiquid"],
                4,
            ],
            ["\\C-AUS-CHL-ECU\\ NA", ["\\IGNORE", "\\IGNORE"], 5],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY\\ Not occurring [IPCC Software]",
                ["\\IGNORE", "\\IGNORE"],
                5,
            ],
            ["\\C-GUY-MDV\\ nan", ["\\IGNORE", "\\IGNORE"], 5],
            [
                "\\C-AUS-CHL-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY\\ Gaseous fuels (6)",
                ["\\IGNORE", "Gaseous"],
                4,
            ],
            [
                "\\C-AUS-CHL-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY\\ Biomass (3)",
                ["\\IGNORE", "Biomass"],
                4,
            ],
            [
                "\\C-AUS-CHL-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY\\ Other fossil fuels (please specify)(7)",
                ["\\IGNORE", "OtherFF"],
                4,
            ],
            ["\\C-AUS-ECU\\ Lubricants", ["\\IGNORE", "OFFLubricants"], 5],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY\\ Not occurring [IPCC Software]",
                ["\\IGNORE", "\\IGNORE"],
                5,
            ],
            ["\\C-GUY-MDV\\ nan", ["\\IGNORE", "\\IGNORE"], 4],
            ["\\C-CHL\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            # Other
            ["\\C-SGP\\ Others", ["1.A.3.b.v.13", "total"], 3],
            ["\\C-COL-ECU-UKR\\ Other", ["1.A.3.b.v.13", "total"], 3],
            ["\\C-SGP-COL-ECU-UKR\\ Gasoline", ["1.A.3.b.v.13", "Gasoline"], 4],
            ["\\C-SGP-COL-ECU-UKR\\ Diesel oil", ["1.A.3.b.v.13", "DieselOil"], 4],
            [
                "\\C-SGP-COL-ECU-UKR\\ Liquefied petroleum gases (LPG)",
                ["1.A.3.b.v.13", "LPG"],
                4,
            ],
            [
                "\\C-SGP-COL-ECU-UKR\\ Other liquid fuels (please specify)",
                ["1.A.3.b.v.13", "OtherLiquid"],
                4,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 5],
            ["\\C-COL-ECU-UKR\\ Other", ["1.A.3.b.v.13", "OLOther"], 5],
            ["\\C-SGP-COL-ECU-UKR\\ Gaseous fuels (6)", ["1.A.3.b.v.13", "Gaseous"], 4],
            ["\\C-SGP-COL-ECU-UKR\\ Biomass (3)", ["1.A.3.b.v.13", "Biomass"], 4],
            [
                "\\C-SGP-COL-ECU-UKR\\ Other fossil fuels (please specify)(7)",
                ["1.A.3.b.v.13", "OtherFF"],
                4,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 5],
            ["\\C-COL-ECU-UKR\\ Other", ["1.A.3.b.v.13", "OFFOther"], 5],
            # evaporative emissions
            ["\\C-ESP\\ Gasoline evaporation", ["1.A.3.b.v.11", "total"], 3],
            ["\\C-USA\\ Evaporative emissions", ["1.A.3.b.v.11", "total"], 3],
            ["\\C-ESP-USA\\ Gasoline", ["1.A.3.b.v.11", "Gasoline"], 4],
            ["\\C-ESP-USA\\ Diesel oil", ["1.A.3.b.v.11", "DieselOil"], 4],
            [
                "\\C-ESP-USA\\ Liquefied petroleum gases (LPG)",
                ["1.A.3.b.v.11", "LPG"],
                4,
            ],
            [
                "\\C-ESP-USA\\ Other liquid fuels (please specify)",
                ["1.A.3.b.v.11", "OtherLiquid"],
                4,
            ],
            ["\\C-ESP\\ nan", ["\\IGNORE", "\\IGNORE"], 5],
            ["\\C-USA\\ LNG", ["1.A.3.b.v.11", "LNG"], 4],
            ["\\C-ESP-USA\\ Gaseous fuels (6)", ["1.A.3.b.v.11", "Gaseous"], 4],
            ["\\C-ESP-USA\\ Biomass (3)", ["1.A.3.b.v.11", "Biomass"], 4],
            [
                "\\C-ESP-USA\\ Other fossil fuels (please specify)(7)",
                ["1.A.3.b.v.11", "OtherFF"],
                4,
            ],
            ["\\C-ESP\\ nan", ["\\IGNORE", "\\IGNORE"], 5],
            # urea based catalysts
            ["\\C-SVK\\ Urea-based catalysts", ["1.A.3.b.v.12", "total"], 3],
            ["\\C-SVK\\ Gasoline", ["1.A.3.b.v.12", "Gasoline"], 4],
            ["\\C-SVK\\ Diesel oil", ["1.A.3.b.v.12", "DieselOil"], 4],
            ["\\C-SVK\\ Liquefied petroleum gases (LPG)", ["1.A.3.b.v.12", "LPG"], 4],
            [
                "\\C-SVK\\ Other liquid fuels (please specify)",
                ["1.A.3.b.v.12", "OtherLiquid"],
                4,
            ],
            ["\\C-SVK\\ Gaseous fuels (6)", ["1.A.3.b.v.12", "Gaseous"], 4],
            ["\\C-SVK\\ Biomass (3)", ["1.A.3.b.v.12", "Biomass"], 4],
            [
                "\\C-SVK\\ Other fossil fuels (please specify)(7)",
                ["1.A.3.b.v.12", "OtherFF"],
                4,
            ],
            # unspecified transportation
            ["\\C-ARG\\ Unspecified transportation", ["1.A.3.b.v.13", "total"], 3],
            ["\\C-ARG\\ Gasoline", ["1.A.3.b.v.13", "Gasoline"], 4],
            ["\\C-ARG\\ Diesel oil", ["1.A.3.b.v.13", "DieselOil"], 4],
            ["\\C-ARG\\ Liquefied petroleum gases (LPG)", ["1.A.3.b.v.13", "LPG"], 4],
            [
                "\\C-ARG\\ Other liquid fuels (please specify)",
                ["1.A.3.b.v.13", "OtherLiquid"],
                4,
            ],
            ["\\C-ARG\\ nan", ["\\IGNORE", "\\IGNORE"], 5],
            ["\\C-ARG\\ Gaseous fuels (6)", ["1.A.3.b.v.13", "Gaseous"], 4],
            ["\\C-ARG\\ Biomass (3)", ["1.A.3.b.v.13", "Biomass"], 4],
            [
                "\\C-ARG\\ Other fossil fuels (please specify)(7)",
                ["1.A.3.b.v.13", "OtherFF"],
                4,
            ],
            ["\\C-ARG\\ nan", ["\\IGNORE", "\\IGNORE"], 5],
            # Lubricant two-stroke
            ["\\C-BEL\\ Lubricant two-stroke", ["1.A.3.b.v.11", "total"], 3],
            ["\\C-BEL\\ Gasoline", ["1.A.3.b.v.11", "Gasoline"], 4],
            ["\\C-BEL\\ Diesel oil", ["1.A.3.b.v.11", "DieselOil"], 4],
            ["\\C-BEL\\ Liquefied petroleum gases (LPG)", ["1.A.3.b.v.11", "LPG"], 4],
            [
                "\\C-BEL\\ Other liquid fuels (please specify)",
                ["1.A.3.b.v.11", "OtherLiquid"],
                4,
            ],
            ["\\C-BEL\\ Lubricant", ["1.A.3.b.v.11", "Lubricants"], 5],
            ["\\C-BEL\\ Gaseous fuels (6)", ["1.A.3.b.v.11", "Gaseous"], 4],
            ["\\C-BEL\\ Biomass (3)", ["1.A.3.b.v.11", "Biomass"], 4],
            [
                "\\C-BEL\\ Other fossil fuels (please specify)(7)",
                ["1.A.3.b.v.11", "OtherFF"],
                4,
            ],
            # c. Railways
            ["1.A.3.c. Railways", ["1.A.3.c", "Total"], 1],
            ["Liquid fuels", ["1.A.3.c", "Liquid"], 2],
            ["Solid fuels", ["1.A.3.c", "Solid"], 2],
            ["Gaseous fuels (6)", ["1.A.3.c", "Gaseous"], 2],
            ["Biomass (3)", ["1.A.3.c", "Biomass"], 2],
            ["Other fossil fuels (please specify)(7)", ["1.A.3.c", "OtherFF"], 2],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-FRA\\ Other fossil fuels [IPCC Software 1.A.3.c]",
                ["1.A.3.c", "OFFOther"],
                3,
            ],
            ["\\C-SGP-CHL\\ NA", ["\\IGNORE", "\\IGNORE"], 3],
            ["\\C-AUS-ECU\\ Lubricants", ["1.A.3.c", "OFFLubricants"], 3],
            ["\\C-AUT\\ FAME fossil part", ["1.A.3.c", "OFFBiodieselFC"], 3],
            [
                "\\C-LTU-LVA\\ Fossil part of biodiesel",
                ["1.A.3.c", "OFFBiodieselFC"],
                3,
            ],
            ["\\C-COL-UKR\\ Other", ["1.A.3.c", "OFFOther"], 3],
            [
                "\\C-SWE\\ Fossil part of biodiesel and biogasoline",
                ["1.A.3.c", "OFFBiofuelFC"],
                3,
            ],
            # d. Domestic navigation
            ["1.A.3.d. Domestic Navigation (12)", ["1.A.3.d", "Total"], 1],
            ["Residual fuel oil", ["1.A.3.d", "ResFuelOil"], 2],
            ["Gas/diesel oil", ["1.A.3.d", "GasDieselOil"], 2],
            ["Gasoline", ["1.A.3.d", "Gasoline"], 2],
            ["Other liquid fuels (please specify)", ["1.A.3.d", "OtherLiquid"], 2],
            ["\\C-AUS-SGP-ECU\\ NA", ["\\IGNORE", "\\IGNORE"], 3],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-FRA\\ Other liquid fuels [IPCC Software 1.A.3.d.ii]",
                ["1.A.3.d", "OLOther"],
                3,
            ],
            ["\\C-RUS\\ Other motor fuels", ["1.A.3.d", "OMotorFuel"], 3],
            ["\\C-HRV-UKR\\ Lubricants", ["1.A.3.d", "Lubricants"], 3],
            ["\\C-CHL\\ Kerosene", ["1.A.3.d", "Kerosene"], 3],
            ["\\C-CHL\\ Liquefied petroleum gases (LPG)", ["1.A.3.d", "LPG"], 3],
            ["\\C-COL\\ Crude Oil", ["1.A.3.d", "CrudeOil"], 3],
            ["\\C-COL\\ Other", ["1.A.3.d", "OLOther"], 3],
            [
                "\\C-CAN\\ Biodiesel (5 percent fossil portion)",
                ["1.A.3.d", "OLBiodieselFC"],
                3,
            ],
            ["\\C-CAN\\ Light Fuel Oil", ["1.A.3.d", "LightFuelOil"], 3],
            ["\\C-CAN\\ Kerosene and stove oil", ["1.A.3.d", "KeroseneStoveOil"], 3],
            ["\\C-FIN\\ Diesel oil", ["1.A.3.d", "OLDiesel"], 3],
            ["Gaseous fuels (6)", ["1.A.3.d", "Gaseous"], 2],
            ["Biomass (3)", ["1.A.3.d", "Biomass"], 2],
            ["Other fossil fuels (please specify)(7)", ["1.A.3.d", "OtherFF"], 2],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-FRA\\ Other fossil fuels [IPCC Software 1.A.3.d.ii]",
                ["1.A.3.d", "OFFOther"],
                3,
            ],
            ["\\C-AUS-CHL-NZL\\ Coal", ["1.A.3.d", "OFFCoal"], 3],
            ["\\C-AUS\\ Lubricants", ["1.A.3.d", "OFFLubricants"], 3],
            ["\\C-SGP-ECU\\ NA", ["\\IGNORE", "\\IGNORE"], 3],
            ["\\C-AUT\\ FAME fossil part", ["1.A.3.d", "OFFBiodieselFC"], 3],
            ["\\C-LTU\\ Fossil part of biodiesel", ["1.A.3.d", "OFFBiodieselFC"], 3],
            ["\\C-COL-UKR\\ Other", ["1.A.3.d", "OFFOther"], 3],
            [
                "\\C-SWE\\ Fossil part of biodiesel and biogasoline",
                ["1.A.3.d", "OFFBiofuelFC"],
                3,
            ],
            # e. other transportation
            # keep details also for top category as it's present
            ["\\C!-CHL-ECU\\ 1.A.3.e. Other transportation", ["1.A.3.e", "Total"], 1],
            [
                "\\C-CHL-ECU\\ 1.A.3.e. Other transportation (please specify)",
                ["1.A.3.e", "Total"],
                1,
            ],
            ["Liquid fuels", ["1.A.3.e", "Liquid"], 2],
            ["Solid fuels", ["1.A.3.e", "Solid"], 2],
            ["Gaseous fuels (6)", ["1.A.3.e", "Gaseous"], 2],
            ["Other fossil fuels (7)", ["1.A.3.e", "OtherFF"], 2],
            ["Biomass (3)", ["1.A.3.e", "Biomass"], 2],
            # i. pipeline
            ["1.A.3.e.i. Pipeline transport", ["1.A.3.e.i", "Total"], 2],
            ["Liquid fuels", ["1.A.3.e.i", "Liquid"], 3],
            ["Solid fuels", ["1.A.3.e.i", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.3.e.i", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.3.e.i", "OtherFF"], 3],
            ["Biomass (3)", ["1.A.3.e.i", "Biomass"], 3],
            # ii other
            ["1.A.3.e.ii. Other (please specify)", ["1.A.3.e.ii", "Total"], 2],
            # Off-road vehicles
            ["\\C-AUS-ECU\\ Off-road vehicles", ["1.A.3.e.ii.1", "Total"], 3],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY\\ Other off-road transportation [IPCC Software 1.A.3.e.ii]",
                ["1.A.3.e.ii.1", "Total"],
                3,
            ],
            ["\\C-GEO\\ Off-road", ["1.A.3.e.ii.1", "Total"], 3],
            ["\\C-CAN\\ Off Road", ["1.A.3.e.ii.1", "Total"], 3],
            [
                "\\C-ISL\\ Other off-road vehicles and machinery",
                ["1.A.3.e.ii.1", "Total"],
                3,
            ],
            ["\\C-LTU\\ Off-road transport", ["1.A.3.e.ii.1", "Total"], 3],
            [
                "\\C-SWE\\ Off-road vehicles and other machinery",
                ["1.A.3.e.ii.1", "Total"],
                3,
            ],
            [
                "\\C-AUS-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-GEO-CAN-ISL-LTU-SWE\\ Gasoline",
                ["1.A.3.e.ii.1", "Gasoline"],
                4,
            ],
            [
                "\\C-AUS-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-GEO-CAN-ISL-LTU-SWE\\ Gas/Diesel oil",
                ["1.A.3.e.ii.1", "DieselOil"],
                4,
            ],
            ["\\C-ECU\\ Diesel oil", ["1.A.3.e.ii.1", "DieselOil"], 4],
            [
                "\\C-AUS-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-GEO-CAN-ISL-LTU-SWE\\ Liquefied petroleum gases (LPG)",
                ["1.A.3.e.ii.1", "LPG"],
                4,
            ],
            [
                "\\C-AUS-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-GEO-CAN-ISL-LTU-SWE\\ Other liquid fuels (please specify)",
                ["1.A.3.e.ii.1", "OtherLiquid"],
                4,
            ],
            ["\\C-AUS-ECU\\ NA", ["\\IGNORE", "\\IGNORE"], 5],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY\\ Other liquid fuels [IPCC Software 1.A.3.e.ii]",
                ["1.A.3.e.ii.1", "OLOther"],
                5,
            ],
            [
                "\\C-CAN\\ Lubricating Oil (Two-Stroke Engines)",
                ["1.A.3.e.ii.1", "Lubricants"],
                5,
            ],
            [
                "\\C-CAN\\ Biodiesel (5 percent fossil portion)",
                ["1.A.3.e.ii.1", "OLBiodieselFC"],
                5,
            ],
            ["\\C-ISL\\ Kerosene", ["1.A.3.e.ii.1", "Kerosene"], 5],
            ["\\C-SWE\\ All Liquid Fuels", ["1.A.3.e.ii.1", "OLOther"], 5],
            ["\\C-GUY-MDV-CAN-SWE\\ nan", ["\\IGNORE", "\\IGNORE"], 5],
            [
                "\\C-AUS-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-GEO-CAN-ISL-LTU-SWE\\ Solid fuels",
                ["1.A.3.e.ii.1", "Solid"],
                4,
            ],
            [
                "\\C-AUS-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-GEO-CAN-ISL-LTU-SWE\\ Gaseous fuels (6)",
                ["1.A.3.e.ii.1", "Gaseous"],
                4,
            ],
            [
                "\\C-AUS-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-GEO-CAN-ISL-LTU-SWE\\ Other fossil fuels (7)",
                ["1.A.3.e.ii.1", "OtherFF"],
                4,
            ],
            [
                "\\C-AUS-ECU-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-GEO-CAN-ISL-LTU-SWE\\ Biomass (3)",
                ["1.A.3.e.ii.1", "Biomass"],
                4,
            ],
            # Airport ground activities
            ["\\C-AUT\\ Airport ground activities", ["1.A.3.e.ii.2", "Total"], 3],
            ["\\C-AUT\\ Gasoline", ["1.A.3.e.ii.2", "Gasoline"], 4],
            ["\\C-AUT\\ Gas/Diesel oil", ["1.A.3.e.ii.2", "DieselOil"], 4],
            ["\\C-AUT\\ Liquefied petroleum gases (LPG)", ["1.A.3.e.ii.2", "LPG"], 4],
            [
                "\\C-AUT\\ Other liquid fuels (please specify)",
                ["1.A.3.e.ii.2", "OtherLiquid"],
                4,
            ],
            ["\\C-AUT\\ Solid fuels", ["1.A.3.e.ii.2", "Solid"], 4],
            ["\\C-AUT\\ Gaseous fuels (6)", ["1.A.3.e.ii.2", "Gaseous"], 4],
            ["\\C-AUT\\ Other fossil fuels (7)", ["1.A.3.e.ii.2", "OtherFF"], 4],
            ["\\C-AUT\\ Biomass (3)", ["1.A.3.e.ii.2", "Biomass"], 4],
            # NA
            ["\\C-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 3],
            ["\\C-SGP\\ Gasoline", ["\\IGNORE", "Gasoline"], 4],
            ["\\C-SGP\\ Gas/Diesel oil", ["\\IGNORE", "DieselOil"], 4],
            ["\\C-SGP\\ Liquefied petroleum gases (LPG)", ["\\IGNORE", "LPG"], 4],
            [
                "\\C-SGP\\ Other liquid fuels (please specify)",
                ["\\IGNORE", "OtherLiquid"],
                4,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 5],
            ["\\C-SGP\\ Solid fuels", ["\\IGNORE", "Solid"], 4],
            ["\\C-SGP\\ Gaseous fuels (6)", ["\\IGNORE", "Gaseous"], 4],
            ["\\C-SGP\\ Other fossil fuels (7)", ["\\IGNORE", "OtherFF"], 4],
            ["\\C-SGP\\ Biomass (3)", ["\\IGNORE", "Biomass"], 4],
            # "Other" and "NA but actually other" (Chile)
            ["\\C-CHL\\ NA", ["1.A.3.e.ii.3", "total"], 3],
            ["\\C-COL-UKR\\ Other", ["1.A.3.e.ii.3", "total"], 3],
            ["\\C-BEL\\ Other non-specified", ["1.A.3.e.ii.3", "total"], 3],
            ["\\C-CHL-COL-UKR-BEL\\ Gasoline", ["1.A.3.e.ii.3", "Gasoline"], 4],
            ["\\C-CHL\\ Diesel oil", ["1.A.3.e.ii.3", "DieselOil"], 4],
            ["\\C-BEL-COL-UKR\\ Gas/Diesel oil", ["1.A.3.e.ii.3", "DieselOil"], 4],
            [
                "\\C-CHL-COL-UKR-BEL\\ Liquefied petroleum gases (LPG)",
                ["1.A.3.e.ii.3", "LPG"],
                4,
            ],
            [
                "\\C-CHL-COL-UKR-BEL\\ Other liquid fuels (please specify)",
                ["1.A.3.e.ii.3", "OtherLiquid"],
                4,
            ],
            ["\\C-CHL\\ NA", ["1.A.3.e.ii.3", "\\IGNORE"], 5],
            ["\\C-COL\\ Other", ["1.A.3.e.ii.3", "OLOther"], 5],
            ["\\C-CHL-COL-UKR-BEL\\ Solid fuels", ["1.A.3.e.ii.3", "Solid"], 4],
            ["\\C-CHL-COL-UKR-BEL\\ Gaseous fuels (6)", ["1.A.3.e.ii.3", "Gaseous"], 4],
            [
                "\\C-CHL-COL-UKR-BEL\\ Other fossil fuels (7)",
                ["1.A.3.e.ii.3", "OtherFF"],
                4,
            ],
            ["\\C-CHL-COL-UKR-BEL\\ Biomass (3)", ["1.A.3.e.ii.3", "Biomass"], 4],
            # non-transportation mobile
            ["\\C-USA\\ Non-transportation mobile", ["1.A.3.e.ii.4", "Total"], 3],
            ["\\C-USA\\ Gasoline", ["1.A.3.e.ii.4", "Gasoline"], 4],
            ["\\C-USA\\ Gas/Diesel oil", ["1.A.3.e.ii.4", "DieselOil"], 4],
            ["\\C-USA\\ Liquefied petroleum gases (LPG)", ["1.A.3.e.ii.4", "LPG"], 4],
            [
                "\\C-USA\\ Other liquid fuels (please specify)",
                ["1.A.3.e.ii.4", "OtherLiquid"],
                4,
            ],
            ["\\C-USA\\ Solid fuels", ["1.A.3.e.ii.4", "Solid"], 4],
            ["\\C-USA\\ Gaseous fuels (6)", ["1.A.3.e.ii.4", "Gaseous"], 4],
            ["\\C-USA\\ Other fossil fuels (7)", ["1.A.3.e.ii.4", "OtherFF"], 4],
            ["\\C-USA\\ Biomass (3)", ["1.A.3.e.ii.4", "Biomass"], 4],
        ],
        "entity_mapping": {
            "EMISSIONS CH4": "CH4",
            "EMISSIONS CO2 (2,3)": "CO2",
            "EMISSIONS N2O": "N2O",
        },
    },  # tested
    "Table1.A(a)s4": {
        "status": "tested",
        "table": {
            "firstrow": 7,
            "lastrow": 128,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category", "class"],
            "cols_to_ignore": [
                "AGGREGATE ACTIVITY DATA Consumption",
                "AGGREGATE ACTIVITY DATA Consumption",
                "IMPLIED EMISSION FACTORS CO2 (1)",
                "IMPLIED EMISSION FACTORS CH4",
                "IMPLIED EMISSION FACTORS N2O",
                "AMOUNT CAPTURED (4) CO2",
            ],
            "stop_cats": [
                "",
                "nan",
                "(1) The IEFs for CO2 are estimated on the basis of gross "
                "emissions, i.e. CO2 emissions plus the absolute amount "
                "captured.",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["1.A.4 Other sectors", ["1.A.4", "Total"], 0],
            ["Liquid fuels", ["1.A.4", "Liquid"], 1],
            ["Solid fuels", ["1.A.4", "Solid"], 1],
            ["Gaseous fuels (6)", ["1.A.4", "Gaseous"], 1],
            ["Other fossil fuels (7)", ["1.A.4", "OtherFF"], 1],
            ["Peat (8)", ["1.A.4", "Peat"], 1],
            ["Biomass(3)", ["1.A.4", "Biomass"], 1],
            # a. Commercial/institutional(12)
            ["1.A.4.a. Commercial/institutional (14)", ["1.A.4.a", "Total"], 1],
            ["Liquid fuels", ["1.A.4.a", "Liquid"], 2],
            ["Solid fuels", ["1.A.4.a", "Solid"], 2],
            ["Gaseous fuels (6)", ["1.A.4.a", "Gaseous"], 2],
            ["Other fossil fuels (7)", ["1.A.4.a", "OtherFF"], 2],
            ["Peat (8)", ["1.A.4.a", "Peat"], 2],
            ["Biomass (3)", ["1.A.4.a", "Biomass"], 2],
            ["Drop-down list:", ["\\IGNORE", "\\IGNORE"], 2],  # (empty)
            # 1.A.4.a.i Stationary combustion
            ["1.A.4.a.i. Stationary combustion", ["1.A.4.a.i", "Total"], 2],
            ["Liquid fuels", ["1.A.4.a.i", "Liquid"], 3],
            ["Solid fuels", ["1.A.4.a.i", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.4.a.i", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.4.a.i", "OtherFF"], 3],
            ["Peat (8)", ["1.A.4.a.i", "Peat"], 3],
            ["Biomass (3)", ["1.A.4.a.i", "Biomass"], 3],
            # 1.A.4.a.ii Off-road vehicles and other machinery
            [
                "1.A.4.a.ii. Off-road vehicles and other machinery",
                ["1.A.4.a.ii", "Total"],
                2,
            ],
            ["Liquid fuels", ["1.A.4.a.ii", "Liquid"], 3],
            ["Solid fuels", ["1.A.4.a.ii", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.4.a.ii", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.4.a.ii", "OtherFF"], 3],
            ["Biomass (3)", ["1.A.4.a.ii", "Biomass"], 3],
            # b. Residential(13)
            ["1.A.4.b. Residential (14)", ["1.A.4.b", "Total"], 1],
            ["Liquid fuels", ["1.A.4.b", "Liquid"], 2],
            ["Solid fuels", ["1.A.4.b", "Solid"], 2],
            ["Gaseous fuels (6)", ["1.A.4.b", "Gaseous"], 2],
            ["Other fossil fuels (7)", ["1.A.4.b", "OtherFF"], 2],
            ["Peat (8)", ["1.A.4.b", "Peat"], 2],
            ["Biomass (3)", ["1.A.4.b", "Biomass"], 2],
            ["Drop-down list:", ["\\IGNORE", "\\IGNORE"], 2],  # (empty)
            # 1.A.4.b.i Stationary combustion
            ["1.A.4.b.i. Stationary combustion", ["1.A.4.b.i", "Total"], 2],
            ["Liquid fuels", ["1.A.4.b.i", "Liquid"], 3],
            ["Solid fuels", ["1.A.4.b.i", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.4.b.i", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.4.b.i", "OtherFF"], 3],
            ["Peat (8)", ["1.A.4.b.i", "Peat"], 3],
            ["Biomass (3)", ["1.A.4.b.i", "Biomass"], 3],
            # 1.A.4.b.ii Off-road vehicles and other machinery
            [
                "1.A.4.b.ii. Off-road vehicles and other machinery",
                ["1.A.4.b.ii", "Total"],
                2,
            ],
            ["Liquid fuels", ["1.A.4.b.ii", "Liquid"], 3],
            ["Solid fuels", ["1.A.4.b.ii", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.4.b.ii", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.4.b.ii", "OtherFF"], 3],
            ["Peat (8)", ["1.A.4.b.ii", "Peat"], 3],
            ["Biomass (3)", ["1.A.4.b.ii", "Biomass"], 3],
            # c. Agriculture/forestry/fishing
            ["1.A.4.c. Agriculture/forestry/fishing", ["1.A.4.c", "Total"], 1],
            ["Liquid fuels", ["1.A.4.c", "Liquid"], 2],
            ["Solid fuels", ["1.A.4.c", "Solid"], 2],
            ["Gaseous fuels (6)", ["1.A.4.c", "Gaseous"], 2],
            ["Other fossil fuels (7)", ["1.A.4.c", "OtherFF"], 2],
            ["Peat (8)", ["1.A.4.c", "Peat"], 2],
            ["Biomass (3)", ["1.A.4.c", "Biomass"], 2],
            # i. Stationary
            ["1.A.4.c.i. Stationary", ["1.A.4.c.i", "Total"], 2],
            ["Liquid fuels", ["1.A.4.c.i", "Liquid"], 3],
            ["Solid fuels", ["1.A.4.c.i", "Solid"], 3],
            ["Gaseous fuels (6)", ["1.A.4.c.i", "Gaseous"], 3],
            ["Other fossil fuels (7)", ["1.A.4.c.i", "OtherFF"], 3],
            ["Peat (8)", ["1.A.4.c.i", "Peat"], 3],
            ["Biomass (3)", ["1.A.4.c.i", "Biomass"], 3],
            # ii. Off-road vehicles and other machinery
            [
                "1.A.4.c.ii. Off-road vehicles and other machinery",
                ["1.A.4.c.ii", "Total"],
                2,
            ],
            ["Gasoline", ["1.A.4.c.ii", "Gasoline"], 3],
            ["Diesel oil", ["1.A.4.c.ii", "DieselOil"], 3],
            ["Liquefied petroleum gases (LPG)", ["1.A.4.c.ii", "LPG"], 3],
            ["Other liquid fuels (please specify)", ["1.A.4.c.ii", "OtherLiquid"], 3],
            ["\\C-AUS-CHL-ECU-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-UZB-FRA\\ Other liquid fuels [IPCC Software 1.A.4.c.ii]",
                ["1.A.4.c.ii", "OLOther"],
                4,
            ],
            ["\\C-RUS\\ Other motor fuels", ["1.A.4.c.ii", "OMotorFuel"], 4],
            ["\\C-NOR\\ Heavy fuel oil", ["1.A.4.c.ii", "HeavyFuelOil"], 4],
            ["\\C-NOR\\ Marine gasoil", ["1.A.4.c.ii", "MarineGasoil"], 4],
            ["\\C-HRV\\ Lubricants", ["1.A.4.c.ii", "Lubricants"], 4],
            ["\\C-HRV\\ Other Kerosene", ["1.A.4.c.ii", "Kerosene"], 4],
            ["\\C-COL-UKR\\ Other", ["1.A.4.c.ii", "OLOther"], 4],
            [
                "\\C-CAN\\ Biodiesel (5 percent fossil portion)",
                ["1.A.4.c.ii", "OLBiodieselFC"],
                4,
            ],
            [
                "\\C-CAN\\ Lubricating Oil (Two-Stroke Engines)",
                ["1.A.4.c.ii", "Lubricants"],
                4,
            ],
            ["\\C-FIN\\ Gasoil", ["1.A.4.c.ii", "Gasoil"], 4],
            ["Gaseous fuels (6)", ["1.A.4.c.ii", "Gaseous"], 3],
            ["Biomass (3)", ["1.A.4.c.ii", "Biomass"], 3],
            ["Other fossil fuels (please specify)(7)", ["1.A.4.c.ii", "OtherFF"], 3],
            ["\\C-AUS-CHL-ECU-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-UZB-FRA\\ Other fossil fuels [IPCC Software 1.A.4.c.ii]",
                ["1.A.4.c.ii", "OFFOther"],
                4,
            ],
            ["\\C-AUT\\ FAME fossil part", ["1.A.4.c.ii", "OFFBiodieselFC"], 4],
            ["\\C-COL-UKR\\ Other", ["1.A.4.c.ii", "OFFOther"], 4],
            ["\\C-LIE\\ Alkylate Gasoline", ["1.A.4.c.ii", "OFFAlkylateGasoline"], 4],
            [
                "\\C-SWE\\ Fossil part of biodiesel and biogasoline",
                ["1.A.4.c.ii", "OFFBiofuelFC"],
                4,
            ],
            # iii. Fishing
            ["1.A.4.c.iii. Fishing", ["1.A.4.c.iii", "Total"], 2],
            ["Residual fuel oil", ["1.A.4.c.iii", "ResFuelOil"], 3],
            ["Gas/diesel oil", ["1.A.4.c.iii", "GasDieselOil"], 3],
            ["Gasoline", ["1.A.4.c.iii", "Gasoline"], 3],
            ["Other liquid fuels (please specify)", ["1.A.4.c.iii", "OtherLiquid"], 3],
            ["\\C-AUS-CHL-ECU-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-UZB-FRA\\ Other liquid fuels [IPCC Software 1.A.4.c.iii]",
                ["1.A.4.c.iii", "OLOther"],
                4,
            ],
            ["\\C-RUS\\ Other motor fuels", ["1.A.4.c.iii", "OMotorFuel"], 4],
            ["\\C-COL-UKR\\ Other", ["1.A.4.c.iii", "OLOther"], 4],
            [
                "\\C-CAN\\ Biodiesel (5 percent fossil portion)",
                ["1.A.4.c.iii", "OLBiodieselFC"],
                4,
            ],
            ["Gaseous fuels (6)", ["1.A.4.c.iii", "Gaseous"], 3],
            ["Biomass(3)", ["1.A.4.c.iii", "Biomass"], 3],
            ["Other fossil fuels (please specify)(7)", ["1.A.4.c.iii", "OtherFF"], 3],
            ["\\C-AUS-CHL-ECU-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 4],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-UZB-FRA\\ Other fossil fuels [IPCC Software 1.A.4.c.iii]",
                ["1.A.4.c.iii", "OFFOther"],
                4,
            ],
            ["\\C-COL-UKR\\ Other", ["1.A.4.c.iii", "OFFOther"], 4],
            [
                "\\C-SWE\\ Fossil part of biodiesel and biogasoline",
                ["1.A.4.c.iii", "OFFBiofuelFC"],
                4,
            ],
            # 1.A.5 Other (Not specified elsewhere)(14)
            ["1.A.5 Other (Not specified elsewhere)(15)", ["1.A.5", "Total"], 0],
            ["Liquid fuels", ["1.A.5", "Liquid"], 1],
            ["Solid fuels", ["1.A.5", "Solid"], 1],
            ["Gaseous fuels (6)", ["1.A.5", "Gaseous"], 1],
            ["Other fossil fuels(7)", ["1.A.5", "OtherFF"], 1],
            ["Peat (8)", ["1.A.5", "Peat"], 1],
            ["Biomass (3)", ["1.A.5", "Biomass"], 1],
            # a. Stationary (please specify)
            ["1.A.5.a. Stationary (please specify)", ["1.A.5.a", "Total"], 1],
            ["\\C-AUS-CHL-ECU-SGP\\ NA", ["\\IGNORE", "\\IGNORE"], 2],
            ["\\C-AUS-CHL-ECU-SGP\\ Liquid fuels", ["\\IGNORE", "Liquid"], 2],
            ["\\C-AUS-CHL-ECU-SGP\\ Solid fuels", ["\\IGNORE", "Solid"], 2],
            ["\\C-AUS-CHL-ECU-SGP\\ Gaseous fuels (6)", ["\\IGNORE", "Gaseous"], 2],
            ["\\C-AUS-CHL-ECU-SGP\\ Other fossil fuels(7)", ["\\IGNORE", "OtherFF"], 2],
            ["\\C-AUS-CHL-ECU-SGP\\ Peat (8)", ["\\IGNORE", "Peat"], 2],
            ["\\C-AUS-CHL-ECU-SGP\\ Biomass (3)", ["\\IGNORE", "Biomass"], 2],
            # Military
            ["\\C-SGP\\ Military activities", ["1.A.5.a.i", "total"], 2],
            ["\\C-NOR\\ Military", ["1.A.5.a.i", "total"], 2],
            ["\\C-SGP-NOR\\ Liquid fuels", ["1.A.5.a.i", "Liquid"], 3],
            ["\\C-SGP-NOR\\ Solid fuels", ["1.A.5.a.i", "Solid"], 3],
            ["\\C-SGP-NOR\\ Gaseous fuels (6)", ["1.A.5.a.i", "Gaseous"], 3],
            ["\\C-SGP-NOR\\ Other fossil fuels(7)", ["1.A.5.a.i", "OtherFF"], 3],
            ["\\C-SGP-NOR\\ Peat (8)", ["1.A.5.a.i", "Peat"], 3],
            ["\\C-SGP-NOR\\ Biomass (3)", ["1.A.5.a.i", "Biomass"], 3],
            # other
            ["\\C-ESP-FIN-SWE\\ Other non-specified", ["1.A.5.a.ii", "total"], 2],
            ["\\C-RUS-SVK-UKR\\ Other", ["1.A.5.a.ii", "total"], 2],
            ["\\C-BRA-GEO\\ Stationary", ["1.A.5.a.ii", "total"], 2],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY\\ Stationary [IPCC Software 1.A.5.a]",
                ["1.A.5.a.ii", "total"],
                2,
            ],
            ["\\C-COL\\ 1.A.5.a. Stationary", ["1.A.5.a.ii", "total"], 2],
            [
                "\\C-ESP-FIN-SWE-RUS-SVK-UKR-BRA-GEO-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-COL\\ Liquid fuels",
                ["1.A.5.a.ii", "Liquid"],
                3,
            ],
            [
                "\\C-ESP-FIN-SWE-RUS-SVK-UKR-BRA-GEO-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-COL\\ Solid fuels",
                ["1.A.5.a.ii", "Solid"],
                3,
            ],
            [
                "\\C-ESP-FIN-SWE-RUS-SVK-UKR-BRA-GEO-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-COL\\ Gaseous fuels (6)",
                ["1.A.5.a.ii", "Gaseous"],
                3,
            ],
            [
                "\\C-ESP-FIN-SWE-RUS-SVK-UKR-BRA-GEO-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-COL\\ Other fossil fuels(7)",
                ["1.A.5.a.ii", "OtherFF"],
                3,
            ],
            [
                "\\C-ESP-FIN-SWE-RUS-SVK-UKR-BRA-GEO-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-COL\\ Peat (8)",
                ["1.A.5.a.ii", "Peat"],
                3,
            ],
            [
                "\\C-ESP-FIN-SWE-RUS-SVK-UKR-BRA-GEO-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-COL\\ Biomass (3)",
                ["1.A.5.a.ii", "Biomass"],
                3,
            ],
            # waste incineration
            ["\\C-USA\\ Incineration of waste", ["1.A.5.a.iv", "Total"], 2],
            ["\\C-USA\\ Liquid fuels", ["1.A.5.a.iv", "Liquid"], 3],
            ["\\C-USA\\ Solid fuels", ["1.A.5.a.iv", "Solid"], 3],
            ["\\C-USA\\ Gaseous fuels (6)", ["1.A.5.a.iv", "Gaseous"], 3],
            ["\\C-USA\\ Other fossil fuels(7)", ["1.A.5.a.iv", "OtherFF"], 3],
            ["\\C-USA\\ Peat (8)", ["1.A.5.a.iv", "Peat"], 3],
            ["\\C-USA\\ Biomass (3)", ["1.A.5.a.iv", "Biomass"], 3],
            # U.S. Territories
            ["\\C-USA\\ U.S. Territories", ["1.A.5.a.v", "Total"], 2],
            ["\\C-USA\\ Liquid fuels", ["1.A.5.a.v", "Liquid"], 3],
            ["\\C-USA\\ Solid fuels", ["1.A.5.a.v", "Solid"], 3],
            ["\\C-USA\\ Gaseous fuels (6)", ["1.A.5.a.v", "Gaseous"], 3],
            ["\\C-USA\\ Other fossil fuels(7)", ["1.A.5.a.v", "OtherFF"], 3],
            ["\\C-USA\\ Peat (8)", ["1.A.5.a.v", "Peat"], 3],
            ["\\C-USA\\ Biomass (3)", ["1.A.5.a.v", "Biomass"], 3],
            # non fuel use
            ["\\C-NOR\\ Non-fuel use", ["1.A.5.a.iii", "total"], 2],
            ["\\C-USA\\ Non-energy use", ["1.A.5.a.iii", "total"], 2],
            ["\\C-NOR-USA\\ Liquid fuels", ["1.A.5.a.iii", "Liquid"], 3],
            ["\\C-NOR-USA\\ Solid fuels", ["1.A.5.a.iii", "Solid"], 3],
            ["\\C-NOR-USA\\ Gaseous fuels (6)", ["1.A.5.a.iii", "Gaseous"], 3],
            ["\\C-NOR-USA\\ Other fossil fuels(7)", ["1.A.5.a.iii", "OtherFF"], 3],
            ["\\C-NOR-USA\\ Peat (8)", ["1.A.5.a.iii", "Peat"], 3],
            ["\\C-NOR-USA\\ Biomass (3)", ["1.A.5.a.iii", "Biomass"], 3],
            # b. Mobile (please specify)
            ["1.A.5.b. Mobile (please specify)", ["1.A.5.b", "Total"], 1],
            # Military
            ["\\C-SGP\\ Military activities", ["1.A.5.b.i", "total"], 2],
            ["\\C-AUT-NOR-CHE-LTU-USA\\ Military", ["1.A.5.b.i", "total"], 2],
            ["\\C-NLD-BEL-DNK-SWE-UKR\\ Military use", ["1.A.5.b.i", "total"], 2],
            ["\\C-SVN\\ Military use of fuel", ["1.A.5.b.i", "total"], 2],
            [
                "\\C-AUT-NOR-CHE-LTU-USA-NLD-BEL-DNK-SWE-UKR-SOR-SGP-SVN\\ Liquid fuels",
                ["1.A.5.b.i", "Liquid"],
                3,
            ],
            [
                "\\C-AUT-NOR-CHE-LTU-USA-NLD-BEL-DNK-SWE-UKR-SOR-SGP-SVN\\ Solid fuels",
                ["1.A.5.b.i", "Solid"],
                3,
            ],
            [
                "\\C-AUT-NOR-CHE-LTU-USA-NLD-BEL-DNK-SWE-UKR-SOR-SGP-SVN\\ Gaseous fuels (6)",
                ["1.A.5.b.i", "Gaseous"],
                3,
            ],
            [
                "\\C-AUT-NOR-CHE-LTU-USA-NLD-BEL-DNK-SWE-UKR-SOR-SGP-SVN\\ Other fossil fuels (7)",
                ["1.A.5.b.i", "OtherFF"],
                3,
            ],
            [
                "\\C-AUT-NOR-CHE-LTU-USA-NLD-BEL-DNK-SWE-UKR-SOR-SGP-SVN\\ Biomass(3)",
                ["1.A.5.b.i", "Biomass"],
                3,
            ],
            # Military Aviation
            ["\\C-PRT\\ Military aviation", ["1.A.5.b.ii", "total"], 2],
            ["\\C-CAN\\ Domestic Military (Aviation)", ["1.A.5.b.ii", "total"], 2],
            ["\\C-HRV\\ Military aviation component", ["1.A.5.b.ii", "total"], 2],
            ["\\C-PRT-CAN-HRV\\ Liquid fuels", ["1.A.5.b.ii", "Liquid"], 3],
            ["\\C-PRT-CAN-HRV\\ Solid fuels", ["1.A.5.b.ii", "Solid"], 3],
            ["\\C-PRT-CAN-HRV\\ Gaseous fuels (6)", ["1.A.5.b.ii", "Gaseous"], 3],
            ["\\C-PRT-CAN-HRV\\ Other fossil fuels (7)", ["1.A.5.b.ii", "OtherFF"], 3],
            ["\\C-PRT-CAN-HRV\\ Biomass(3)", ["1.A.5.b.ii", "Biomass"], 3],
            # military water-borne
            ["\\C-HRV\\ Military water-borne component", ["1.A.5.b.iii", "Total"], 2],
            ["\\C-CAN\\ Military Water-borne Navigation", ["1.A.5.b.iii", "Total"], 2],
            ["\\C-HRV-CAN\\ Liquid fuels", ["1.A.5.b.iii", "Liquid"], 3],
            ["\\C-HRV-CAN\\ Solid fuels", ["1.A.5.b.iii", "Solid"], 3],
            ["\\C-HRV-CAN\\ Gaseous fuels (6)", ["1.A.5.b.iii", "Gaseous"], 3],
            ["\\C-HRV-CAN\\ Other fossil fuels (7)", ["1.A.5.b.iii", "OtherFF"], 3],
            ["\\C-HRV-CAN\\ Biomass(3)", ["1.A.5.b.iii", "Biomass"], 3],
            # Other
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB\\ Other mobile (other) [IPCC Software 1.A.3.b, 1.A.4.c, 1.A.5.b.iii]",
                ["1.A.5.b.iv", "Total"],
                2,
            ],
            ["\\C-ESP-FIN\\ Other non-specified", ["1.A.5.a.iv", "total"], 2],
            ["\\C-MLT\\ Other", ["1.A.5.a.iv", "total"], 2],
            ["\\C-COL\\ 1.A.5.b. Mobile", ["1.A.5.a.iv", "total"], 2],
            ["\\C-CZE\\ iii. Mobile (other)", ["1.A.5.a.iv", "total"], 2],
            ["\\C-GRC\\ mobile", ["1.A.5.a.iv", "total"], 2],
            ["\\C-LVA\\ Mobile", ["1.A.5.a.iv", "total"], 2],
            [
                "\\C-ESP-FIN-GUY-MDV-MLT-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-UZB-COL-CZE-GRC-LVA\\ Liquid fuels",
                ["1.A.5.a.iv", "Liquid"],
                3,
            ],
            [
                "\\C-ESP-FIN-GUY-MDV-MLT-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-UZB-COL-CZE-GRC-LVA\\ Solid fuels",
                ["1.A.5.a.iv", "Solid"],
                3,
            ],
            [
                "\\C-ESP-FIN-GUY-MDV-MLT-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-UZB-COL-CZE-GRC-LVA\\ Gaseous fuels (6)",
                ["1.A.5.a.iv", "Gaseous"],
                3,
            ],
            [
                "\\C-ESP-FIN-GUY-MDV-MLT-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-UZB-COL-CZE-GRC-LVA\\ Other fossil fuels (7)",
                ["1.A.5.a.iv", "OtherFF"],
                3,
            ],
            [
                "\\C-ESP-FIN-GUY-MDV-MLT-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-UZB-COL-CZE-GRC-LVA\\ Biomass(3)",
                ["1.A.5.a.iv", "Biomass"],
                3,
            ],
            # Aviation
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB\\ Other mobile (aviation) [IPCC Software 1.A.3.a.ii, 1.A.5.b.i]",
                ["1.A.5.b.vi", "Total"],
                2,
            ],
            ["\\C-BRA-CHL\\ Aviation", ["1.A.5.b.vi", "Total"], 2],
            ["\\C-CZE\\ i. Mobile (aviation component)", ["1.A.5.b.vi", "Total"], 2],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB-BRA-CHL-CZE\\ Liquid fuels",
                ["1.A.5.b.vi", "Liquid"],
                3,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB-BRA-CHL-CZE\\ Solid fuels",
                ["1.A.5.b.vi", "Solid"],
                3,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB-BRA-CHL-CZE\\ Gaseous fuels (6)",
                ["1.A.5.b.vi", "Gaseous"],
                3,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB-BRA-CHL-CZE\\ Other fossil fuels (7)",
                ["1.A.5.b.vi", "OtherFF"],
                3,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB-BRA-CHL-CZE\\ Biomass(3)",
                ["1.A.5.b.vi", "Biomass"],
                3,
            ],
            # Lubricants used in 2-stroke engines
            [
                "\\C-NOR\\ Lubricants used in 2-stroke engines",
                ["1.A.5.b.vii", "total"],
                2,
            ],
            ["\\C-NOR\\ Liquid fuels", ["1.A.5.b.vii", "Liquid"], 3],
            ["\\C-NOR\\ Solid fuels", ["1.A.5.b.vii", "Solid"], 3],
            ["\\C-NOR\\ Gaseous fuels (6)", ["1.A.5.b.vii", "Gaseous"], 3],
            ["\\C-NOR\\ Other fossil fuels (7)", ["1.A.5.b.vii", "OtherFF"], 3],
            ["\\C-NOR\\ Biomass(3)", ["1.A.5.b.vii", "Biomass"], 3],
            # Recreational crafts
            ["\\C-DNK\\ Recreational crafts", ["1.A.5.b.viii", "Total"], 2],
            ["\\C-DNK\\ Liquid fuels", ["1.A.5.b.vii", "Liquid"], 3],
            ["\\C-DNK\\ Solid fuels", ["1.A.5.b.vii", "Solid"], 3],
            ["\\C-DNK\\ Gaseous fuels (6)", ["1.A.5.b.vii", "Gaseous"], 3],
            ["\\C-DNK\\ Other fossil fuels (7)", ["1.A.5.b.vii", "OtherFF"], 3],
            ["\\C-DNK\\ Biomass(3)", ["1.A.5.b.vii", "Biomass"], 3],
            # Military Jet Kerosene
            ["\\C-SVK\\ Military use Jet Kerosene", ["1.A.5.b.ix", "total"], 2],
            ["\\C-SVK\\ Liquid fuels", ["1.A.5.b.ix", "Liquid"], 3],
            ["\\C-SVK\\ Solid fuels", ["1.A.5.b.ix", "Solid"], 3],
            ["\\C-SVK\\ Gaseous fuels (6)", ["1.A.5.b.ix", "Gaseous"], 3],
            ["\\C-SVK\\ Other fossil fuels (7)", ["1.A.5.b.ix", "OtherFF"], 3],
            ["\\C-SVK\\ Biomass(3)", ["1.A.5.b.ix", "Biomass"], 3],
            # Military Gasoline
            ["\\C-SVK\\ Military Gasoline", ["1.A.5.b.x", "total"], 2],
            ["\\C-SVK\\ Liquid fuels", ["1.A.5.b.x", "Liquid"], 3],
            ["\\C-SVK\\ Solid fuels", ["1.A.5.b.x", "Solid"], 3],
            ["\\C-SVK\\ Gaseous fuels (6)", ["1.A.5.b.x", "Gaseous"], 3],
            ["\\C-SVK\\ Other fossil fuels (7)", ["1.A.5.b.x", "OtherFF"], 3],
            ["\\C-SVK\\ Biomass(3)", ["1.A.5.b.x", "Biomass"], 3],
            # Military Diesel Oil
            ["\\C-SVK\\ Military Diesel Oil", ["1.A.5.b.xi", "total"], 2],
            ["\\C-SVK\\ Liquid fuels", ["1.A.5.b.xi", "Liquid"], 3],
            ["\\C-SVK\\ Solid fuels", ["1.A.5.b.xi", "Solid"], 3],
            ["\\C-SVK\\ Gaseous fuels (6)", ["1.A.5.b.xi", "Gaseous"], 3],
            ["\\C-SVK\\ Other fossil fuels (7)", ["1.A.5.b.xi", "OtherFF"], 3],
            ["\\C-SVK\\ Biomass(3)", ["1.A.5.b.xi", "Biomass"], 3],
            # Military Transport
            ["\\C-AUS-ECU\\ Military Transport", ["1.A.5.b.xii", "Total"], 2],
            ["\\C-AUS-ECU\\ Liquid fuels", ["1.A.5.b.xii", "Liquid"], 3],
            ["\\C-AUS-ECU\\ Solid fuels", ["1.A.5.b.xii", "Solid"], 3],
            ["\\C-AUS-ECU\\ Gaseous fuels (6)", ["1.A.5.b.xii", "Gaseous"], 3],
            ["\\C-AUS-ECU\\ Other fossil fuels (7)", ["1.A.5.b.xii", "OtherFF"], 3],
            ["\\C-AUS-ECU\\ Biomass(3)", ["1.A.5.b.xii", "Biomass"], 3],
            # Other mobile (water-borne)
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB\\ Other mobile (water-borne) [IPCC Software 1.A.5.b.ii]",
                ["1.A.5.b.xiv", "Total"],
                2,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB\\ Liquid fuels",
                ["1.A.5.b.xiv", "Liquid"],
                3,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB\\ Solid fuels",
                ["1.A.5.b.xiv", "Solid"],
                3,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB\\ Gaseous fuels (6)",
                ["1.A.5.b.xiv", "Gaseous"],
                3,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB\\ Other fossil fuels (7)",
                ["1.A.5.b.xiv", "OtherFF"],
                3,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB\\ Biomass(3)",
                ["1.A.5.b.xiv", "Biomass"],
                3,
            ],
            # Other transportation
            ["\\C-RUS\\ Other transportation", ["1.A.5.a.xv", "total"], 2],
            ["\\C-RUS\\ Liquid fuels", ["1.A.5.a.xv", "Liquid"], 3],
            ["\\C-RUS\\ Solid fuels", ["1.A.5.a.xv", "Solid"], 3],
            ["\\C-RUS\\ Gaseous fuels (6)", ["1.A.5.a.xv", "Gaseous"], 3],
            ["\\C-RUS\\ Other fossil fuels (7)", ["1.A.5.a.xv", "OtherFF"], 3],
            ["\\C-RUS\\ Biomass(3)", ["1.A.5.a.xv", "Biomass"], 3],
            # Information Item
            ["Information item: (16)", ["\\IGNORE", "\\IGNORE"], 0],
            [
                "Waste incineration with energy recovery included as:",
                ["\\IGNORE", "\\IGNORE"],
                1,
            ],
            ["Biomass (3)", ["\\IGNORE", "\\IGNORE"], 1],
            ["Fossil fuels (7)", ["\\IGNORE", "\\IGNORE"], 1],
            # PRT, SVK
            ["Biomass(3)", ["\\IGNORE", "\\IGNORE"], 1],
            ["Other fossil fuels (7)", ["\\IGNORE", "\\IGNORE"], 1],
        ],
        "entity_mapping": {
            "EMISSIONS CH4": "CH4",
            "EMISSIONS CO2 (2,3)": "CO2",
            "EMISSIONS N2O": "N2O",
        },
    },  # tested
    "Table1.B.1": {
        "status": "tested",
        "table": {
            "firstrow": 7,
            "lastrow": 34,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA Amount of fuel produced",
                "IMPLIED EMISSION FACTORS CH4 (3)",
                "IMPLIED EMISSION FACTORS CO2",
            ],
            "stop_cats": [
                "",
                "nan",
                "(1) Final CH4 and CO2 emissions after subtracting the amounts of CH4 "
                "and CO2 utilized or recovered.",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["1. B. 1. a. Coal mining and handling", ["1.B.1.a"], 0],
            ["1.B.1.a.i. Underground mines (4)", ["1.B.1.a.i"], 1],
            ["1.B.1.a.i.1. Mining activities", ["1.B.1.a.i.1"], 2],
            ["1.B.1.a.i.2. Post-mining activities", ["1.B.1.a.i.2"], 2],
            [
                "\\C!-CHL-ECU\\ 1.B.1.a.i.3. Abandoned underground mines (number of mines)",
                ["1.B.1.a.i.3"],
                2,
            ],
            [
                "\\C-CHL-ECU\\ 1.B.1.a.i.3. Abandoned underground mines",
                ["1.B.1.a.i.3"],
                2,
            ],
            [
                "1.B.1.a.i.4. Flaring of drained methane or conversion of "
                "methane to CO2 (5)",
                ["1.B.1.a.i.4"],
                2,
            ],
            ["1.B.1.a.i.5. Other (please specify)", ["1.B.1.a.i.5"], 2],
            ["\\C-AUS-SGP-CHL-ECU\\ NA", ["\\IGNORE"], 3],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-FRA\\ Other Underground Coal Mines [IPCC Software 1.B.3]",
                ["1.B.1.a.i.5.a"],
                3,
            ],
            ["1.B.1.a.ii. Surface mines (4)", ["1.B.1.a.ii"], 1],
            ["1.B.1.a.ii.1. Mining activities", ["1.B.1.a.ii.1"], 2],
            ["1.B.1.a.ii.2. Post-mining activities", ["1.B.1.a.ii.2"], 2],
            ["1.B.1.a.ii.3. Other (please specify)", ["1.B.1.a.ii.3"], 2],
            ["\\C-AUS-SGP-CHL-ECU\\ NA", ["\\IGNORE"], 3],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-UZB-FRA\\ Other Surface Coal Mines [IPCC Software 1.B.3]",
                ["1.B.1.a.ii.3.a"],
                3,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-UZB\\ Abandoned surface mines [IPCC Software 1.B.3]",
                ["1.B.1.a.ii.3.b"],
                3,
            ],
            ["1. B. 1. b. Fuel transformation (6)", ["1.B.1.b"], 0],
            ["\\C-AUS-CHL-ECU\\ Drop down list:", ["\\IGNORE"], 1],
            # some of the following items are missing for some countries but as they are
            # present for ost countries we do not specify the countries here
            ["1.B.1.b.i. Charcoal and biochar production (7)", ["1.B.1.b.i"], 1],
            ["1.B.1.b.ii. Coke production", ["1.B.1.b.ii"], 1],
            ["1.B.1.b.iii. Coal to liquids", ["1.B.1.b.iii"], 1],
            ["1.B.1.b.iv. Gas to liquids", ["1.B.1.b.iv"], 1],
            ["1.B.1.b.v. Other (please specify)", ["1.B.1.b.v"], 1],
            ["\\C-AUS-CHL-ECU\\ NA", ["\\IGNORE"], 2],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-"
                "PRY-URY-UZB\\ GHG emissions from other gasification [IPCC Software 1.B.1.c.iv]",
                ["1.B.1.b.v.i"],
                2,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-"
                "PRY-URY-UZB\\ Other fuel transformation [IPCC Software 1.B.3]",
                ["1.B.1.b.v.ii"],
                2,
            ],
            ["\\C-SGP\\ Gasification transformation", ["1.B.1.b.v.i"], 1],
            ["\\C-NOR\\ Solid Fuel transformation", ["1.B.1.b.v.iii"], 1],
            [
                "\\C-KAZ\\ Solid Fuel Transformation (1.B.1.b. by CRF)",
                ["1.B.1.b.v.iii"],
                1,
            ],
            ["1. B. 1. c. Other (please specify) (8)", ["1.B.1.c"], 0],
            ["\\C-AUS-SGP-BRA-CHL-ECU\\ NA", ["\\IGNORE"], 1],
            ["\\C-SWE\\ Flaring of gas", ["1.B.1.c.i"], 1],
            ["\\C-UKR\\ Flaring", ["1.B.1.c.i"], 1],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-UZB\\ Uncontrolled combustion and burning of coal dumps "
                "[IPCC Software 1.B.1.b]",
                ["1.B.1.c.ii"],
                1,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-UZB-FRA\\ Other solid fuels [IPCC Software 1.B.3]",
                ["1.B.1.c.v"],
                1,
            ],
            ["\\C-JPN\\ Uncontrolled combustion", ["1.B.1.c.ii"], 1],
            ["\\C-SVN\\ SO2 scrubbing", ["1.B.1.c.iii"], 1],
            ["\\C-POL\\ Emisson from coke oven gas subsystem", ["1.B.1.c.iv"], 1],
            ["\\C-KAZ\\ Flaring of coke oven gas (1.B.1.c by CRF)", ["1.B.1.c.iv"], 1],
            ["\\C-COL\\ 1.B.1.c. Other", ["1.B.1.c.v"], 0],
            ["\\C-SVK\\ CO2 emissions from Charcoal and biochar", ["1.B.1.c.vi"], 1],
        ],
        "entity_mapping": {
            "EMISSIONS (1) CH4": "CH4 emissions",  # this is necessary because there
            # is an error in the table and the CH4 emissions don't have the removals
            # subtracted which would be correct according to the footnotes
            # TODO: check!!!
            "EMISSIONS (1) CO2": "CO2",  #  emissions",
            "RECOVERY/FLARING (2) CH4": "CH4 removals",
            "RECOVERY/FLARING (2) CO2": "CO2 removals",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table1.B.2": {
        "status": "tested",
        "table": {
            "firstrow": 7,
            "lastrow": 45,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA (1) Description (1)",
                "ACTIVITY DATA (1) Unit (1)",
                "ACTIVITY DATA (1) Value",
                "IMPLIED EMISSION FACTORS CO2 (3)",
                "IMPLIED EMISSION FACTORS CH4",
                "IMPLIED EMISSION FACTORS N2O",
            ],
            "stop_cats": [
                ".",
                "nan",
                "(1) Specify the AD used. Specify the unit of the AD in energy or "
                "volume units (e.g. PJ, 106 m3 and 106 bbl/year).",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["1.B.2.a. Oil (7)", ["1.B.2.a"], 0],
            ["1.B.2.a.i. Exploration", ["1.B.2.a.i"], 1],
            ["1.B.2.a.ii. Production and upgrading (8)", ["1.B.2.a.ii"], 1],
            ["1.B.2.a.iii. Transport", ["1.B.2.a.iii"], 1],
            ["1.B.2.a.iv. Refining/storage", ["1.B.2.a.iv"], 1],
            ["1.B.2.a.v. Distribution of oil products", ["1.B.2.a.v"], 1],
            ["1.B.2.a.vi. Other", ["1.B.2.a.vi"], 1],
            ["\\C-AUS-CHL-ECU\\ Drop down list:", ["\\IGNORE"], 2],
            # the following categories are now present for all countries, but almost all
            # so there is no country filter specified
            ["1.B.2.a.vi.1. Abandoned wells", ["1.B.2.a.vi.1"], 2],
            ["1.B.2.a.vi.2. Other (please specify)", ["1.B.2.a.vi.2"], 2],
            ["\\C-AUS-SGP-CHL-ECU\\ NA", ["\\IGNORE"], 3],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-"
                "PRY-URY-UZB\\ Other fugitive from oil industry "
                "[IPCC Software 1.B.2.a.iii.6]",
                ["1.B.2.a.vi.2.a"],
                3,
            ],
            ["\\C-JPN\\ Accidents", ["1.B.2.a.vi.2.b"], 3],
            ["\\C-CAN\\ Accidents and equipment failures", ["1.B.2.a.vi.2.b"], 3],
            ["\\C-RUS\\ Gas condensate transported", ["1.B.2.a.vi.2.c"], 3],
            [
                "\\C-LTU\\ Hydrogen production at petroleum refinery",
                ["1.B.2.a.vi.2.d"],
                3,
            ],
            ["1.B.2.b. Natural gas", ["1.B.2.b"], 0],
            ["1.B.2.b.i. Exploration", ["1.B.2.b.i"], 1],
            ["1.B.2.b.ii. Production and gathering (8)", ["1.B.2.b.ii"], 1],
            ["1.B.2.b.iii. Processing", ["1.B.2.b.iii"], 1],
            ["1.B.2.b.iv. Transmission and storage", ["1.B.2.b.iv"], 1],
            ["1.B.2.b.v. Distribution", ["1.B.2.b.v"], 1],
            ["1.B.2.b.vi. Other", ["1.B.2.b.vi"], 1],
            ["\\C-AUS-CHL-ECU\\ Drop down list:", ["\\IGNORE"], 2],
            # the following categories are now present for all countries, but almost all
            # so there is no country filter specified
            ["1.B.2.b.vi.1. Gas post-meter", ["1.B.2.b.vi.1"], 2],
            ["1.B.2.b.vi.2. Abandoned wells", ["1.B.2.b.vi.2"], 2],
            ["1.B.2.b.vi.3. Other (please specify)", ["1.B.2.b.vi.3"], 2],
            # # AUS
            # ["LNG Terminals", ["1.B.2.b.vi.3.a"], 3],
            # ["LNG Storage", ["1.B.2.b.vi.3.b"], 3],
            # ["Natural Gas Storage", ["1.B.2.b.vi.3.c"], 3],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-"
                "PRY-URY-UZB\\ Other fugitive from natural gas industry "
                "[IPCC Software 1.B.2.b.iii.6]",
                ["1.B.2.b.vi.3.d"],
                3,
            ],
            ["\\C-SGP-CHL-ECU-BRA\\ NA", ["\\IGNORE"], 3],
            ["\\C-NOR-UKR\\ Other", ["1.B.2.b.vi.3.d"], 3],
            ["\\C-SVK\\ Storage of gas", ["1.B.2.b.vi.3.e"], 3],
            ["\\C-CAN\\ Accidents and equipment failures", ["1.B.2.b.vi.3.f"], 3],
            [
                "\\C-LTU\\ Liquefaction and gasification at LNG terminal",
                ["1.B.2.b.vi.3.g"],
                3,
            ],
            ["1.B.2.c. Venting and flaring", ["1.B.2.c"], 0],
            ["1.B.2.c.i. Venting", ["1.B.2.c-ven"], 1],
            ["1.B.2.c.i.1. Oil", ["1.B.2.c-ven.i"], 2],
            ["1.B.2.c.i.2. Gas", ["1.B.2.c-ven.ii"], 2],
            ["1.B.2.c.i.3. Combined", ["1.B.2.c-ven.iii"], 2],
            ["1.B.2.c.ii. Flaring (9)", ["1.B.2.c-fla"], 1],
            ["1.B.2.c.ii.1. Oil", ["1.B.2.c-fla.i"], 2],
            ["1.B.2.c.ii.2. Gas", ["1.B.2.c-fla.ii"], 2],
            ["1.B.2.c.ii.3. Combined", ["1.B.2.c-fla.iii"], 2],
            ["1.B.2.d. Other (please specify) (10)", ["1.B.2.d"], 0],
            ["\\C-AUS-SGP-CHL-ECU\\ NA", ["\\IGNORE"], 1],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY\\ N2O emissions from Oil and Natural Gas Systems "
                "[IPCC Software 1.B.2]",
                ["1.B.2.d.xii"],
                1,
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-"
                "PAN-PRY-URY-FRA\\ N2O emissions from other Energy Production "
                "[IPCC Software 1.B.3]",
                ["1.B.2.d.xiii"],
                1,
            ],
            ["\\C-ITA\\ Geotherm", ["1.B.2.d.ii"], 1],
            ["\\C-JPN\\ Geothermal generation", ["1.B.2.d.ii"], 1],
            ["\\C-DEU-PRT-NZL-ISL\\ Geothermal", ["1.B.2.d.ii"], 1],
            ["\\C-ITA\\ Flaring in refineries", ["1.B.2.d.v"], 1],
            ["\\C-GRC\\ LPG transport", ["1.B.2.d.vi"], 1],
            ["\\C-FIN\\ Distribution of town gas", ["1.B.2.d.vii"], 1],
            ["\\C-COL\\ 1.B.2.d. Other", ["1.B.2.d.iv"], 1],
            ["\\C-SWE\\ Other non-specified", ["1.B.2.d.iv"], 1],
            ["\\C-UKR\\ Other", ["1.B.2.d.iv"], 1],
            # TODO: RUS (also included in 1.B.2.a.vi.2, double counting)
            ["\\C-RUS\\ Gas condensate transported", ["1.B.2.d.xii"], 1],
        ],
        "entity_mapping": {
            "EMISSIONS CH4 (5)": "CH4",
            "EMISSIONS CO2 (4)": "CO2",  # "CO2 emissions",
            "EMISSIONS N2O": "N2O",
            "RECOVERY (2) CO2": "CO2 removals",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table1.C": {
        "status": "tested",
        "table": {
            "firstrow": 7,
            "lastrow": 29,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA CO2 transported or injected (1)",
                "IMPLIED EMISSION FACTORS CO2",
            ],
            "stop_cats": [
                "",
                "nan",
                "(1) Excluding recycled CO2 for enhanced recovery.",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["1.C.1. Transport of CO2", ["1.C.1"], 0],
            ["1.C.1.a. Pipelines", ["1.C.1.a"], 1],
            ["1.C.1.b. Ships", ["1.C.1.b"], 1],
            ["1.C.1.c. Other (please specify)", ["1.C.1.c"], 1],
            ["\\C-AUS-CHL-ECU-SGP\\ NA", ["\\IGNORE"], 2],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-"
                "PRY-URY-UZB-FRA\\ Other [IPCC Software 1.C.1.c]",
                ["1.C.1.c.i"],
                2,
            ],
            ["\\C-ESP-UKR\\ Other", ["1.C.1.c.i"], 2],
            ["\\C-COL\\ 1.C.1.c. Other", ["1.C.1.c.i"], 2],
            ["1.C.2. Injection and storage (3)", ["1.C.2"], 0],
            ["1.C.2.a. Injection", ["1.C.2.a"], 1],
            ["1.C.2.b. Storage", ["1.C.2.b"], 1],
            ["1.C.3. Other (please specify)", ["1.C.3"], 0],
            ["\\C-AUS-CHL-ECU-SGP\\ NA", ["\\IGNORE"], 1],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GEO-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-"
                "PRY-URY-FRA\\ Other [IPCC Software 1.C.3]",
                ["1.C.3.i"],
                1,
            ],
            ["\\C-ESP-UKR\\ Other", ["1.C.3.i"], 1],
            ["\\C-COL\\ 1.C.3. Other", ["1.C.3.i"], 1],
            ["\\C!-CHL-ECU\\ Information item (kt CO2) (4, 5, 6)", ["\\IGNORE"], 0],
            ["\\C-CHL-ECU\\ Information item (4, 5, 6)", ["\\IGNORE"], 0],
            ["Total amount captured for storage (7)", ["M.Info.A.TACS"], 1],
            ["Total amount of imports for storage (7)", ["M.Info.A.TAIS"], 1],
            ["Total A", ["M.Info.A"], 1],
            ["Total amount of exports for storage", ["M.Info.B.TAES"], 1],
            ["Total amount of CO2 injected at storage sites", ["M.Info.B.TAI"], 1],
            ["CO2 injected for operational usage (8)", ["M.Info.B.IOU"], 1],
            [
                "Total leakage from transport, injection and storage",
                ["M.Info.B.TLTIS"],
                1,
            ],
            ["Total B", ["M.Info.B"], 1],
            ["Difference (A-B)(6)", ["\\IGNORE"], 1],
        ],
        "entity_mapping": {
            "EMISSIONS CO2 (2)": "CO2",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table1.D": {
        "status": "TODO",
        "table": {
            "firstrow": 7,
            "lastrow": 24,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category", "class"],
            "cols_to_ignore": [],
            "stop_cats": ["", "nan"],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [],
        "entity_mapping": [],
        "coords_defaults": {
            "class": "Total",
        },
    },  # TODO
    "Table2(I)": {
        "status": "tested",
        "table": {
            "firstrow": 8,
            "lastrow": 66,
            "header": ["entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": [
                "",
                "nan",
                "(1) Emissions of HFCs, PFCs, unspecified mix of HFCs and PFCs, and "
                "other F-gases are to be expressed in CO2 eq. Data on disaggregated "
                "emissions of HFCs and PFCs are to be provided in table 2(II).",
            ],
            "unit_info": unit_info["industry"],
        },
        "sector_mapping": [
            ["2. Total industrial processes", ["2"], 0],
            ["2.A. Mineral industry", ["2.A"], 1],
            ["2.A.1. Cement production", ["2.A.1"], 2],
            ["2.A.2. Lime production", ["2.A.2"], 2],
            ["2.A.3. Glass production", ["2.A.3"], 2],
            ["2.A.4. Other process uses of carbonates", ["2.A.4"], 2],
            ["2.B. Chemical industry", ["2.B"], 1],
            ["2.B.1. Ammonia production", ["2.B.1"], 2],
            ["2.B.2. Nitric acid production", ["2.B.2"], 2],
            ["2.B.3. Adipic acid production", ["2.B.3"], 2],
            ["2.B.4. Caprolactam, glyoxal and glyoxylic acid production", ["2.B.4"], 2],
            ["2.B.5. Carbide production", ["2.B.5"], 2],
            ["2.B.6. Titanium dioxide production", ["2.B.6"], 2],
            ["2.B.7. Soda ash production", ["2.B.7"], 2],
            ["2.B.8. Petrochemical and carbon black production", ["2.B.8"], 2],
            ["2.B.9. Fluorochemical production", ["2.B.9"], 2],
            ["2.B.10. Other", ["2.B.10"], 2],
            ["2.C. Metal industry", ["2.C"], 1],
            ["2.C.1. Iron and steel production", ["2.C.1"], 2],
            ["2.C.2. Ferroalloys production", ["2.C.2"], 2],
            ["2.C.3. Aluminium production", ["2.C.3"], 2],
            ["2.C.4. Magnesium production", ["2.C.4"], 2],
            ["2.C.5. Lead production", ["2.C.5"], 2],
            ["2.C.6. Zinc production", ["2.C.6"], 2],
            ["2.C.7. Other", ["2.C.7"], 2],
            ["2.D. Non-energy products from fuels and solvent use (4)", ["2.D"], 1],
            ["2.D.1. Lubricant use", ["2.D.1"], 2],
            ["2.D.2. Paraffin wax use", ["2.D.2"], 2],
            ["2.D.3. Other", ["2.D.3"], 2],
            ["2.E. Electronics industry", ["2.E"], 1],
            ["2.E.1. Integrated circuit or semiconductor", ["2.E.1"], 2],
            ["2.E.2. TFT flat panel display", ["2.E.2"], 2],
            ["2.E.3. Photovoltaics", ["2.E.3"], 2],
            ["2.E.4. Heat transfer fluid", ["2.E.4"], 2],
            ["2.E.5. Other", ["2.E.5"], 2],
            ["2.F. Product uses as substitutes for ODS", ["2.F"], 1],
            ["2.F.1. Refrigeration and air conditioning", ["2.F.1"], 2],
            ["2.F.2. Foam blowing agents", ["2.F.2"], 2],
            ["2.F.3. Fire protection", ["2.F.3"], 2],
            ["2.F.4. Aerosols", ["2.F.4"], 2],
            ["2.F.5. Solvents", ["2.F.5"], 2],
            ["2.F.6. Other applications", ["2.F.6"], 2],
            ["2.G. Other product manufacture and use", ["2.G"], 1],
            ["2.G.1. Electrical equipment", ["2.G.1"], 2],
            ["2.G.2. SF6 and PFCs from other product use", ["2.G.2"], 2],
            ["2.G.3. N2O from product uses", ["2.G.3"], 2],
            ["2.G.4. Other", ["2.G.4"], 2],
            ["\\C!-AUS-ECU\\ 2.H. Other (5)", ["2.H"], 1],
            ["\\C-AUS-ECU\\ 2.H. Other (please specify) (5)", ["2.H"], 1],
            ["\\C!-AUS-ECU\\ 2.H.1. Pulp and paper", ["2.H.1"], 2],
            ["\\C!-AUS-ECU\\ 2.H.2. Food and beverages industry", ["2.H.2"], 2],
            ["\\C-AUS-ECU\\ 2.H.2. Food and Beverages Industry", ["2.H.2"], 2],
            ["\\C!-AUS-ECU\\ 2.H.3. Other (please specify)", ["2.H.3"], 2],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-URY-"
                "UZB-FRA\\ Other industrial processes and product use [IPCC Software]",
                ["2.H.3.a"],
                3,
            ],
            ["\\C-COL\\ 2.H.3.Other", ["2.H.3.a"], 3],
            ["\\C-CAN-LTU-UKR\\ Other", ["2.H.3.a"], 3],
            ["\\C-SGP\\ Other processes", ["2.H.3.a"], 3],
            ["\\C-USA\\ Other nonspecified", ["2.H.3.a"], 3],
            ["\\C-ESP\\ Soda ash production (CO emissions)", ["2.H.3.d"], 3],
            ["\\C-ESP\\ Glass production (NMVOC emissions)", ["2.H.3.e"], 3],
            ["\\C-ESP\\ Tobacco", ["2.H.3.b"], 3],
            ["\\C-ESP\\ Fireworks", ["2.H.3.c"], 3],
            [
                "\\C-ESP\\ Titanium dioxide production (NOX and SO2 emissions)",
                ["2.H.3.f"],
                3,
            ],
            [
                "\\C-ESP\\ Flaring in iron and steel producion (N2O emissions)",
                ["2.H.3.g"],
                3,
            ],
            ["\\C-JPN\\ Emissions from Imported Carbonated Gas", ["2.H.3.h"], 3],
            ["\\C-JPN\\ Utilization of Carbonated Gas", ["2.H.3.i"], 3],
            ["\\C-NZL\\ Fibreboard production", ["2.H.3.j"], 3],
            ["\\C-NZL\\ Particleboard Production", ["2.H.3.k"], 3],
            ["\\C-NOR\\ Ore mines", ["2.H.3.l"], 3],
            ["\\C-PRT\\ Carbon electrodes consumption", ["2.H.3.l"], 3],
            ["\\C-PRT\\ Chipboard production", ["2.H.3.k"], 3],
            ["\\C-CHE\\ Blasting and shooting", ["2.H.3.m"], 3],
            ["\\C-BRA\\ NA", ["\\IGNORE"], 3],
            ["\\C-CHL\\ NO", ["\\IGNORE"], 3],
            ["\\C-CZE\\ HFO-1234yf", ["2.H.3.n"], 3],
            ["\\C-CZE\\ HFO-1234ze", ["2.H.3.o"], 3],
            ["\\C-DEU\\ Aggregated confidential data", ["2.H.3.p"], 3],
            [
                "\\C-FIN\\ Grouped confidential data of halocarbons and SF6",
                ["2.H.3.p"],
                3,
            ],
            ["\\C-SWE\\ Batteries Manufacturing", ["2.H.3.q"], 3],
            ["\\C-SWE\\ Mineral wool production", ["2.H.3.r"], 3],
            [
                "\\C-SWE\\ Quarrying and mining of minerals other than coal",
                ["2.H.3.s"],
                3,
            ],
            [
                "\\C-USA\\ 2.F.1.a Refrigeration and air conditioning - "
                "Commercial refrigeration",
                ["2.H.3.t"],
                3,
            ],
            [
                "\\C-USA\\ 2.F.1.d Refrigeration and air conditioning - "
                "Transport refrigeration",
                ["2.H.3.u"],
                3,
            ],
            ["\\C-USA\\ 2.F.2.a Foam blowing agents - Closed cells", ["2.H.3.v"], 3],
            ["\\C-USA\\ 2.F.2.b Foam blowing agents - Open cells", ["2.H.3.w"], 3],
            ["\\C-USA\\ 2.F.3 Fire protection", ["2.H.3.x"], 3],
            [
                "\\C-USA\\ CO2 captured from lime production for use in other process "
                "use of carbonates",
                ["2.H.3.y"],
                3,
            ],
        ],
        "entity_mapping": {
            "HFCs (1)": f"HFCS ({gwp_to_use})",
            "PFCs (1)": f"PFCS ({gwp_to_use})",
            "Unspecified mix of HFCs and PFCs (1)": f"UnspMixOfHFCsPFCs ({gwp_to_use})",
            "Total GHG emissions (2)": f"KYOTOGHG ({gwp_to_use})",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table2(II)": {
        "status": "tested",
        "table": {
            "firstrow": 8,
            "lastrow": 37,  # ignore the totals
            "header": ["entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": [".", "nan", "", "Total emissions (3)"],
            "unit_info": unit_info["fgases"],
        },
        "sector_mapping": [
            [
                "2. Total actual emissions of halocarbons (by chemical), SF6 and NF3",
                ["2"],
            ],
            ["2.B. Chemical industry", ["2.B"]],
            ["2.B.9. Fluorochemical production", ["2.B.9"]],
            ["2.B.9.a. By-product emissions", ["2.B.9.a"]],
            ["2.B.9.b. Fugitive emissions", ["2.B.9.b"]],
            ["2.B.10. Other", ["2.B.10"]],
            ["2.C. Metal industry", ["2.C"]],
            ["2.C.3. Aluminium production", ["2.C.3"]],
            ["2.C.4. Magnesium production", ["2.C.4"]],
            ["2.C.7. Other", ["2.C.7"]],
            ["2.E. Electronics industry", ["2.E"]],
            ["2.E.1. Integrated circuit or semiconductor", ["2.E.1"]],
            ["2.E.2. TFT flat panel display", ["2.E.2"]],
            ["2.E.3. Photovoltaics", ["2.E.3"]],
            ["2.E.4. Heat transfer fluid", ["2.E.4"]],
            ["2.E.5. Other", ["2.E.5"]],
            ["2.F. Product uses as substitutes for ODS", ["2.F"]],
            ["2.F.1. Refrigeration and air conditioning", ["2.F.1"]],
            ["2.F.2. Foam blowing agents", ["2.F.2"]],
            ["2.F.3. Fire protection", ["2.F.3"]],
            ["2.F.4. Aerosols", ["2.F.4"]],
            ["2.F.5. Solvents", ["2.F.5"]],
            ["2.F.6. Other applications", ["2.F.6"]],
            ["2.G. Other product manufacture and use", ["2.G"]],
            ["2.G.1. Electrical equipment", ["2.G.1"]],
            ["2.G.2. SF6 and PFCs from other product use", ["2.G.2"]],
            ["2.G.4. Other", ["2.G.4"]],
            ["2.H. Other", ["2.H"]],
            ["2.H.1 Pulp and paper", ["2.H.1"]],
            ["2.H.2 Food and beverages industry", ["2.H.2"]],
            ["2.H.3 Other (please specify)", ["2.H.3"]],
        ],
        "entity_mapping": {
            #'C3F8': 'C3F8',
            #'C10F18' 'C2F6' 'C4F10' 'C5F12' 'C6F14' 'CF4'
            "HFC-125": "HFC125",
            "HFC-134": "HFC134",
            "HFC-134a": "HFC134a",
            "HFC-143": "HFC143",
            "HFC-143a": "HFC143a",
            "HFC-152": "HFC152",
            "HFC-152a": "HFC152a",
            "HFC-161": "HFC161",
            "HFC-227ea": "HFC227ea",
            "HFC-23": "HFC23",
            "HFC-236cb": "HFC236cb",
            "HFC-236ea": "HFC236ea",
            "HFC-236fa": "HFC236fa",
            "HFC-245ca": "HFC245ca",
            "HFC-245fa": "HFC245fa",
            "HFC-32": "HFC32",
            "HFC-365mfc": "HFC365mfc",
            "HFC-41": "HFC41",
            "HFC-43-10mee": "HFC4310mee",
            "Unspecified mix of HFCs (1)": f"UnspMixOfHFCs ({gwp_to_use})",
            "Unspecified mix of HFCs and PFCs(1)": f"UnspMixOfHFCsPFCs ({gwp_to_use})",
            "Unspecified mix of PFCs (1)": f"UnspMixOfPFCs ({gwp_to_use})",
            "c-C3F6": "cC3F6",
            "c-C4F8": "cC4F8",
            "Total HFCs": f"HFCS ({gwp_to_use})",
            "Total PFCs": f"PFCS ({gwp_to_use})",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table3": {  # Agriculture summary
        "status": "tested",
        "table": {
            "firstrow": 8,
            "lastrow": 48,
            "header": ["entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": [
                "",
                "nan",
                '(1) "Total GHG emissions" does not include NOX, CO, NMVOC and SOX.',
            ],
            "unit_info": unit_info["industry"],
        },
        "sector_mapping": [
            ["3. Total agriculture", ["3"], 0],
            # A. Enteric fermentation
            ["3.A. Enteric fermentation", ["3.A"], 1],
            ["\\C!-CHL\\ 3.A.1. Cattle(3)", ["3.A.1"], 2],
            ["\\C!-CHL\\ Option A:", ["\\IGNORE"], 3],
            ["\\C-AUS\\ 3.A.1.a. Dairy cattle", ["\\IGNORE"], 4],
            ["\\C-AUS\\ 3.A.1.b. Non-dairy cattle", ["\\IGNRE"], 4],
            ["\\C!-AUS-CHL\\ 3.A.1.a. Dairy cattle", ["3.A.1.A.a"], 4],
            ["\\C!-AUS-CHL\\ 3.A.1.b. Non-dairy cattle", ["3.A.1.A.b"], 4],
            ["\\C-CHL\\ Option A:", ["\\IGNORE"], 2],  # 3.A.1 missing
            ["\\C-CHL\\ 3.A.1.a. Dairy cattle", ["3.A.1.A.a"], 3],
            ["\\C-CHL\\ 3.A.1.b. Non-dairy cattle", ["3.A.1.A.b"], 3],
            ["Option B (country-specific):", ["\\IGNORE"], 3],
            ["3.A.1.a. Other", ["3.A.1.B"], 4],
            ["3.A.1.a.i. Mature dairy cattle", ["3.A.1.B.a"], 5],
            ["3.A.1.a.ii. Other mature cattle", ["3.A.1.B.b"], 5],
            ["3.A.1.a.iii. Growing cattle", ["3.A.1.B.c"], 5],
            ["3.A.1.a.iv. Other (please specify)", ["3.A.1.B.d"], 5],
            # Other livestock
            ["3.A.2. Sheep", ["3.A.2"], 2],
            ["3.A.3. Swine", ["3.A.3"], 2],
            ["3.A.4. Other livestock", ["3.A.4"], 2],
            # Manure Management
            ["3.B. Manure management", ["3.B"], 1],
            ["3.B.1. Cattle(3)", ["3.B.1"], 2],
            ["Option A:", ["\\IGNORE"], 3],
            ["\\C-AUS\\ 3.B.1.a. Dairy cattle", ["\\IGNORE"], 4],
            ["\\C-AUS\\ 3.B.1.b. Non-dairy cattle", ["\\IGNORE"], 4],
            ["\\C!-AUS\\ 3.B.1.a. Dairy cattle", ["3.B.1.A.a"], 4],
            ["\\C!-AUS\\ 3.B.1.b. Non-dairy cattle", ["3.B.1.A.b"], 4],
            ["Option B (country-specific):", ["\\IGNORE"], 3],
            ["3.B.1.a. Other", ["3.B.1.B"], 4],
            ["3.B.1.a.i. Mature dairy cattle", ["3.B.1.B.a"], 5],
            ["3.B.1.a.ii. Other mature cattle", ["3.B.1.B.b"], 5],
            ["3.B.1.a.iii. Growing cattle", ["3.B.1.B.c"], 5],
            ["3.B.1.a.iv. Other (please specify)", ["3.B.1.B.d"], 5],
            ["3.B.2. Sheep", ["3.B.2"], 2],
            ["3.B.3. Swine", ["3.B.3"], 2],
            ["3.B.4. Other livestock", ["3.B.4"], 2],
            ["3.B.5. Indirect N2O emissions", ["3.B.5"], 2],
            ["3.C. Rice cultivation", ["3.C"], 1],
            ["3.D. Agricultural soils(4,5)", ["3.D"], 1],
            ["3.D.1. Direct N2O emissions from managed soils", ["3.D.a"], 2],
            ["3.D.1.a. Inorganic N fertilizers", ["3.D.a.1"], 3],
            ["3.D.1.b. Organic N fertilizers", ["3.D.a.2"], 3],
            ["3.D.1.c. Urine and dung deposited by grazing animals", ["3.D.a.3"], 3],
            ["3.D.1.d. Crop residues", ["3.D.a.4"], 3],
            [
                "3.D.1.e. Mineralization/immobilization associated with loss/gain of "
                "soil organic matter",
                ["3.D.a.5"],
                3,
            ],
            ["3.D.1.f. Cultivation of organic soils (i.e. histosols)", ["3.D.a.6"], 3],
            ["3.D.1.g. Other", ["3.D.a.7"], 3],
            ["3.D.2. Indirect N2O Emissions from managed soils", ["3.D.b"], 2],
            ["3.E. Prescribed burning of savannahs", ["3.E"], 1],
            ["3.F. Field burning of agricultural residues", ["3.F"], 1],
            ["3.G. Liming", ["3.G"], 1],
            ["3.H. Urea application", ["3.H"], 1],
            ["3.I. Other carbon-containing fertilizers", ["3.I"], 1],
            ["3.J. Other (please specify)", ["3.J"], 1],
            ["\\C-AUS-BRA-CHL-SGP\\ NA", ["\\IGNORE"], 2],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-GNB-KEN-LBN-MYS-MUS-URY-UZB-FRA\\ "
                "Other sources from agriculture (non-carbon pools) "
                "[IPCC Software 3.C.2 and 3.C.14]",
                ["3.J.2"],
                2,
            ],
            ["\\C-BLR-LTU\\ Other", ["3.J.2"], 2],
            ["\\C-DEU\\ Digestate renewable raw material (storage of N)", ["3.J.6"], 2],
            [
                "\\C-DEU\\ Digestate renewable raw material (atmospheric deposition)",
                ["3.J.7"],
                2,
            ],
            [
                "\\C-DEU\\ Digestate renewable raw material (storage of dry matter)",
                ["3.J.8"],
                2,
            ],
            ["\\C-DEU\\ 3.B NOx Emissions", ["3.J.1"], 2],
            ["\\C-AUT\\ NOx emissions from manure management", ["3.J.1"], 2],
            ["\\C-ESP\\ NOx 3B", ["3.J.1"], 2],
            ["\\C-NOR-DNK-SWE\\ NOx from manure management", ["3.J.1"], 2],
            ["\\C-IRL\\ NOx from Manure Management", ["3.J.1"], 2],
            ["\\C-COL\\ 3.B. NOx_Manure management", ["3.J.1"], 2],
            ["\\C-PRY\\ Total", ["\\IGNORE"], 2],
        ],
        "entity_mapping": {"Total GHG emissions (1)": f"KYOTOGHG ({gwp_to_use})"},
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table3.A": {  # Enteric fermentation
        "status": "tested",
        "table": {
            "firstrow": 7,
            "lastrow": 49,
            "header": ["entity", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Population size (1)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Average gross energy intake (GE)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Average CH4 conversion rate (Ym) (2)",
                "IMPLIED EMISSION FACTORS CH4",
            ],
            "stop_cats": [
                "",
                "nan",
                "(1) Parties are encouraged to provide detailed livestock population "
                "data by animal type and region, if available, in NID, and provide in "
                "the documentation box below a reference to the relevant section. Parties "
                "should use the same animal population statistics to estimate CH4 emissions "
                "from enteric fermentation, CH4 and N2O emissions from manure management, "
                "direct N2O emissions from soil and N2O emissions associated with manure "
                "production, as well as emissions from use of manure as fuel, and "
                "sewage-related emissions reported under the waste sector.",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["3.A.1. Cattle", ["3.A.1"], 0],
            ["Option A:", ["\\IGNORE"], 1],
            # AUS
            ["\\C-AUS\\ 3.A.1.a. Dairy cattle", ["\\IGNORE"], 2],
            ["\\C-AUS\\ 3.A.1.b. Non-dairy cattle", ["\\IGNORE"], 2],
            # other countries
            ["\\C!-AUS\\ 3.A.1.a. Dairy cattle", ["3.A.1.A.a"], 2],
            ["\\C!-AUS\\ 3.A.1.b. Non-dairy cattle", ["3.A.1.A.b"], 2],
            ["Option B (country-specific): (3)", ["\\IGNORE"], 1],
            ["3.A.1.a. Other", ["3.A.1.B"], 2],
            ["Drop-down list:", ["\\IGNORE"], 3],
            ["3.A.1.a.i. Mature dairy cattle", ["3.A.1.B.a"], 3],
            ["3.A.1.a.ii. Other mature cattle", ["3.A.1.B.b"], 3],
            ["3.A.1.a.iii. Growing cattle", ["3.A.1.B.c"], 3],
            ["3.A.1.a.iv. Other (please specify)", ["3.A.1.B.d"], 3],
            ["\\C-AUS\\ Dairy Cattle", ["3.A.1.B.d.AUS-i"], 4],
            ["\\C-AUS\\ Beef Cattle - Pasture", ["3.A.1.B.d.AUS-ii"], 4],
            ["\\C-AUS\\ Beef Cattle - Feedlot", ["3.A.1.C.d.AUS-iii"], 4],
            ["\\C-MLT\\ Bulls", ["3.A.1.B.d.MLT-i"], 4],
            ["\\C-MLT\\ Calves", ["3.A.1.B.d.MLT-ii"], 4],
            ["\\C-POL\\ Bulls (older than 2 years)", ["3.A.1.B.d.POL-i"], 4],
            [
                "\\C-POL\\ Non-dairy Heifers (older than 2 years)",
                ["3.A.1.B.d.POL-ii"],
                4,
            ],
            [
                "\\C-POL\\ Non-dairy Young Cattle (younger than 1 year)",
                ["3.A.1.C.d.POL-iii"],
                4,
            ],
            ["\\C-POL\\ Non-dairy Young Cattle (1-2 years)", ["3.A.1.C.d.POL-iv"], 4],
            ["\\C-POL\\ Dairy Cattle", ["3.A.1.C.d.POL-v"], 4],
            ["\\C-POL\\ Non-dairy Cattle", ["3.A.1.C.d.POL-vi"], 4],
            ["\\C-SVN\\ Non-dairy cattle", ["3.A.1.B.d.SVN-i"], 4],
            ["\\C-SVN\\ Other cows", ["3.A.1.B.d.SVN-ii"], 4],
            ["\\C-CHL\\ Dairy Cattle", ["3.A.1.B.d.CHL-i"], 4],
            ["\\C-CHL\\ Beef cattle", ["3.A.1.B.d.CHL-ii"], 4],
            ["\\C-CHL\\ Heifer", ["3.A.1.B.d.CHL-iii"], 4],
            ["\\C-CHL\\ Beef cattle (> 2 yr)", ["3.A.1.B.d.CHL-iv"], 4],
            ["\\C-CHL\\ Beef cattle (1 - 2 yr)", ["3.A.1.B.d.CHL-v"], 4],
            ["\\C-CHL\\ Calves", ["3.A.1.B.d.CHL-vi"], 4],
            [
                "\\C-COL\\ 3.A.1.a.i. High production dairy cattle",
                ["3.A.1.B.d.COL-i"],
                4,
            ],
            [
                "\\C-COL\\ 3.A.1.a.ii. Low production dairy cattle.",
                ["3.A.1.B.d.COL-ii"],
                4,
            ],
            ["\\C-COL\\ 3.A.1.a.iii. Beef cattle", ["3.A.1.B.d.COL-iii"], 4],
            ["\\C-COL\\ 3.A.1.a.iv. Breeding bulls.", ["3.A.1.B.d.COL-iv"], 4],
            ["\\C-COL\\ 3.A.1.a.v. Pre-weaning calves", ["3.A.1.B.d.COL-v"], 4],
            ["\\C-COL\\ 3.A.1.a.vi. Replacement heifers.", ["3.A.1.B.d.COL-vi"], 4],
            [
                "\\C-COL\\ 3.A.1.a.vii. Beef cattle o Feedlot cattle",
                ["3.A.1.B.d.COL-vii"],
                4,
            ],
            ["\\C-PAN\\ Low-yielding dairy cows", ["3.A.1.B.d.PAN-i"], 4],
            ["\\C-PAN\\ Dairy cattle (doble próposito)", ["3.A.1.B.d.PAN-ii"], 4],
            ["\\C-PAN\\ Young male bull (Novillos)", ["3.A.1.B.d.PAN-iii"], 4],
            ["\\C-PAN\\ Young calves (terneros)", ["3.A.1.B.d.PAN-iv"], 4],
            ["\\C-PAN\\ Bull", ["3.A.1.B.d.PAN-v"], 4],
            ["\\C-USA\\ Dairy cattle", ["3.A.1.B.d.USA-i"], 4],
            ["\\C-USA\\ Non-dairy cattle", ["3.A.1.B.d.USA-ii"], 4],
            ["\\C-USA\\ Dairy cows", ["3.A.1.B.d.USA-iii"], 4],
            ["\\C-USA\\ Heifer feedlot", ["3.A.1.B.d.USA-iv"], 4],
            ["\\C-USA\\ Steer feedlot", ["3.A.1.B.d.USA-v"], 4],
            ["\\C-USA\\ Beef replacements", ["3.A.1.B.d.USA-vi"], 4],
            ["\\C-USA\\ Dairy replacements", ["3.A.1.B.d.USA-vii"], 4],
            ["\\C-USA\\ Beef cows", ["3.A.1.B.d.USA-viii"], 4],
            ["\\C-USA\\ Heifer stocker", ["3.A.1.B.d.USA-ix"], 4],
            ["\\C-USA\\ Steer stocker", ["3.A.1.B.d.USA-x"], 4],
            ["\\C-USA\\ Bulls", ["3.A.1.B.d.USA-xi"], 4],
            ["\\C-USA\\ Dairy calves", ["3.A.1.B.d.USA-xii"], 4],
            ["\\C-USA\\ Beef calves", ["3.A.1.B.d.USA-xiii"], 4],
            ["3.A.2. Sheep", ["3.A.2"], 0],
            ["3.A.2.a. Other (please specify)", ["3.A.2.a"], 1],
            [
                "\\C-AUS-ITA-CHL-SRB-AUT-BLR-CHE-CZE-DNK-ESP-EST-FIN-GRC-HRV-JPN-KAZ-"
                "LIE-LTU-LVA-NOR-NZL-PRT-SVN-SWE-UKR\\ Sheep",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-ARG\\ All sheep", ["\\IGNORE"], 2],
            ["\\C-GHA-CHN\\ sheep", ["\\IGNORE"], 2],
            [
                "\\C-CHL-SRB-AUT-BLR-CHE-CZE-DNK-ESP-EST-FIN-GRC-HRV-JPN-KAZ-LIE-LTU-"
                "LVA-NOR-NZL-PRT-SVN-SWE-UKR\\ Sheep",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-BEL\\ Sheep unspecified", ["\\IGNORE"], 2],
            ["\\C-CAN\\ Sheep and Lamb", ["\\IGNORE"], 2],
            ["\\C-BRA\\ 3.A.2. Sheep", ["\\IGNORE"], 2],
            ["\\C-COL\\ 3.A.2.a.i. Sheep", ["\\IGNORE"], 2],
            ["\\C-ITA-NLD\\ Sheep (2)", ["\\IGNORE"], 2],
            ["\\C-NLD\\ Sheep (8)", ["\\IGNORE"], 2],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-"
                "UZB-FRA\\ All sheep [IPCC Software 3.A.1.c]",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 2],
            ["\\C-MLT\\ Growing Lambs", ["3.A.2.a.MLT-i"], 2],
            ["\\C-MLT\\ Other Mature Ewes", ["3.A.2.a.MLT-ii"], 2],
            ["\\C-MLT\\ Mature Ewes", ["3.A.2.a.MLT-iii"], 2],
            ["\\C-SVK\\ Mature ewes", ["3.A.2.a.SVK-i"], 2],
            ["\\C-SVK\\ Growing lambs", ["3.A.2.a.SVK-ii"], 2],
            ["\\C-SVK\\ Other mature sheeps", ["3.A.2.a.SVK-iii"], 2],
            ["\\C-TUR\\ Domestic sheep", ["3.A.2.a.TUR-i"], 2],
            ["\\C-TUR\\ Merino sheep", ["3.A.2.a.TUR-ii"], 2],
            ["\\C-DZA\\ dairy Sheep", ["3.A.2.a.DZA-i"], 2],
            ["\\C-DZA\\ Other Sheep", ["3.A.2.a.DZA-ii"], 2],
            ["\\C-IRL\\ Ewes Lowland", ["3.A.2.a.IRL-i"], 2],
            ["\\C-IRL\\ Ewes Upland", ["3.A.2.a.IRL-ii"], 2],
            ["\\C-IRL\\ Lambs Lowland", ["3.A.2.a.IRL-iii"], 2],
            ["\\C-IRL\\ Lambs Upland", ["3.A.2.a.IRL-iv"], 2],
            ["\\C-IRL\\ Other Sheep>1yr Lowland", ["3.A.2.a.IRL-v"], 2],
            ["\\C-IRL\\ Other Sheep>1yr Upland", ["3.A.2.a.IRL-vi"], 2],
            ["\\C-IRL\\ Rams Lowland", ["3.A.2.a.IRL-vii"], 2],
            ["\\C-IRL\\ Rams Upland", ["3.A.2.a.IRL-viii"], 2],
            ["\\C-ISL\\ Mature ewes", ["3.A.2.a.ISL-i"], 2],
            ["\\C-ISL\\ Animal for replacement", ["3.A.2.a.ISL-ii"], 2],
            ["\\C-ISL\\ Other mature sheep", ["3.A.2.a.ISL-iii"], 2],
            ["\\C-ISL\\ Lambs", ["3.A.2.a.ISL-iv"], 2],
            ["\\C-USA\\ Sheep", ["3.A.2.a.USA-i"], 2],
            ["\\C-USA\\ Sheep on feed", ["3.A.2.a.USA-ii"], 2],
            ["\\C-USA\\ Sheep not on feed", ["3.A.2.a.USA-iii"], 2],
            ["3.A.3. Swine", ["3.A.3"], 0],
            ["3.A.3.a. Other (please specify)", ["3.A.3.a"], 1],
            ["\\C-AUS-ITA-CAN\\ Swine", ["\\IGNORE"], 2],
            ["\\C-NZL\\ Pigs", ["\\IGNORE"], 2],
            ["\\C-ARG\\ All swine", ["\\IGNORE"], 2],
            [
                "\\C-GHA-SRB-AUT-BLR-CHE-CZE-EST-FIN-GRC-JPN-KAZ-LIE-LTU-LVA-NOR-PRT-"
                "SVN-SWE-TUR-UKR-CHN\\ Swine",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-BEL\\ Swine unspecified", ["\\IGNORE"], 2],
            ["\\C-BRA\\ 3.A.3. Swine", ["\\IGNORE"], 2],
            ["\\C-ITA-NLD\\ Swine (3)", ["\\IGNORE"], 2],
            ["\\C-NLD\\ Swine (7)", ["\\IGNORE"], 2],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-"
                "UZB-FRA\\ All swine [IPCC Software 3.A.1.h]",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 2],
            ["\\C-ESP\\ White swine (finishing/fattening pigs)", ["3.A.3.a.ESP-i"], 2],
            ["\\C-ESP\\ White swine (sows)", ["3.A.3.a.ESP-ii"], 2],
            [
                "\\C-ESP\\ Iberian swine (finishing/fattening pigs)",
                ["3.A.3.a.ESP-iii"],
                2,
            ],
            ["\\C-ESP\\ Iberian swine (sows)", ["3.A.3.a.ESP-iv"], 2],
            ["\\C-MLT\\ Breeding boars", ["3.A.3.a.MLT-i"], 2],
            ["\\C-MLT\\ Breeding females - gilts", ["3.A.3.a.MLT-ii"], 2],
            ["\\C-MLT\\ Breeding female - sows", ["3.A.3.a.MLT-iii"], 2],
            ["\\C-MLT\\ Fattening pigs more than 50kg", ["3.A.3.a.MLT-iv"], 2],
            ["\\C-MLT\\ Young pigs 20-50kg", ["3.A.3.a.MLT-v"], 2],
            ["\\C-MLT\\ Piglets less than 20kg", ["3.A.3.a.MLT-vi"], 2],
            ["\\C-SVK-HRV\\ Breeding swine", ["3.A.3.a.SVK-i"], 2],
            ["\\C-SVK-HRV\\ Market swine", ["3.A.3.a.SVK-ii"], 2],
            ["\\C-CHL\\ Pigs", ["3.A.3.a.CHL-i"], 2],
            ["\\C-CHL\\ Boars", ["3.A.3.a.CHL-ii"], 2],
            ["\\C-CHL\\ Juvenile pigs", ["3.A.3.a.CHL-iii"], 2],
            ["\\C-COL\\ 3.A.3.a.i. swine < 6 months", ["3.A.3.a.COL-i"], 2],
            ["\\C-COL\\ 3.A.3.a.ii. swine > 6 months", ["3.A.3.a.COL-ii"], 2],
            ["\\C-COL\\ 3.A.3.a.iii. Low productivity swine", ["3.A.3.a.COL-iii"], 2],
            ["\\C-DNK\\ Sows", ["3.A.3.a.DNK-i"], 2],
            ["\\C-DNK\\ Fattening pigs", ["3.A.3.a.DNK-ii"], 2],
            ["\\C-DNK\\ Weaners", ["3.A.3.a.DNK-iii"], 2],
            ["\\C-IRL\\ Boars", ["3.A.3.a.IRL-i"], 2],
            ["\\C-IRL\\ Sows in Pig", ["3.A.3.a.IRL-ii"], 2],
            ["\\C-IRL\\ Gilts in Pig", ["3.A.3.a.IRL-iii"], 2],
            ["\\C-IRL\\ Pigs > 20kg", ["3.A.3.a.IRL-iv"], 2],
            ["\\C-IRL\\ Pigs < 20kg", ["3.A.3.a.IRL-v"], 2],
            ["\\C-IRL\\ Other Sows for Breeding", ["3.A.3.a.IRL-vi"], 2],
            ["\\C-IRL\\ Gilts not yet Served", ["3.A.3.a.IRL-vii"], 2],
            ["\\C-ISL\\ Piglets", ["3.A.3.a.ISL-i"], 2],
            ["\\C-ISL\\ Sows", ["3.A.3.a.ISL-ii"], 2],
            ["\\C-USA\\ Swine", ["3.A.3.a.USA-i"], 2],
            ["\\C-USA\\ Market swine less than 50 lb", ["3.A.3.a.USA-ii"], 2],
            ["\\C-USA\\ Market swine 50-119 lb", ["3.A.3.a.USA-iii"], 2],
            ["\\C-USA\\ Market swine 120-179 lb", ["3.A.3.a.USA-iv"], 2],
            ["\\C-USA\\ Market swine greater than 180 lb", ["3.A.3.a.USA-v"], 2],
            ["\\C-USA\\ Breeding swine", ["3.A.3.a.USA-vi"], 2],
            # other livestock
            ["\\C!-AUS-CHL\\ 3.A.4. Other livestock(4)", ["3.A.4"], 0],
            ["\\C-AUS\\ 3.A.4. Other livestock (4)", ["3.A.4"], 0],
            ["\\C-CHL\\ 3.A.4. Other livestock (please specify) (4)", ["3.A.4"], 0],
            ["\\C-AUS-CHL\\ Drop down list:", ["\\IGNORE"], 1],
            ["3.A.4.a. Buffalo", ["3.A.4.a"], 1],
            ["3.A.4.b. Camels", ["3.A.4.b"], 1],
            ["3.A.4.c. Deer", ["3.A.4.c"], 1],
            ["3.A.4.d. Goats", ["3.A.4.d"], 1],
            ["3.A.4.e. Horses", ["3.A.4.e"], 1],
            ["3.A.4.f. Mules and asses", ["3.A.4.f"], 1],
            ["3.A.4.g. Poultry", ["3.A.4.g"], 1],
            ["\\C!-CHL\\ 3.A.4.h. Other", ["3.A.4.h"], 1],
            ["\\C-CHL\\ 3.A.4.h. Other (please specify)", ["3.A.4.h"], 1],
            ["\\C-AUS\\ Drop-down list:", ["\\IGNORE"], 2],
            ["3.A.4.h.i. Rabbit", ["3.A.4.h.i"], 2],
            ["3.A.4.h.ii. Reindeer", ["3.A.4.h.ii"], 2],
            ["3.A.4.h.iii. Ostrich", ["3.A.4.h.iii"], 2],
            ["3.A.4.h.iv. Fur-bearing animals (5)", ["3.A.4.h.iv"], 2],
            ["\\C!-CHL\\ 3.A.4.h.v. Other (please specify)", ["3.A.4.h.v"], 2],
            ["\\C-CHL\\ 3.A.4.h.v. Other (please specity)", ["3.A.4.h.v"], 2],
            ["\\C-AUS\\ Alpacas", ["3.A.4.h.v.1"], 3],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " Alpacas [IPCC Software 3.A.1.j]",
                ["3.A.4.h.v.1"],
                3,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " Llamas [IPCC Software 3.A.1.j]",
                ["3.A.4.h.v.2"],
                3,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " All other species [IPCC Software 3.A.1.j]",
                ["3.A.4.h.v.10"],
                3,
            ],
            ["\\C-SGP\\ Quail", ["3.A.4.h.v.3"], 3],
            ["\\C-ESP\\ Ducks and other poultry", ["3.A.4.h.v.4"], 3],
            ["\\C-ESP\\ Turkeys", ["3.A.4.h.v.5"], 3],
            ["\\C-ESP\\ Broilers", ["3.A.4.h.v.6"], 3],
            ["\\C-CHE\\ Livestock outside agriculture", ["3.A.4.h.v.11"], 3],
            ["\\C-COL\\ 3.A.4.g.i. Laying hens", ["3.A.4.h.v.12"], 3],
            ["\\C-COL\\ 3.A.4.g.ii. broiler chicken", ["3.A.4.h.v.13"], 3],
            ["\\C-CAN\\ Wild Boar", ["3.A.4.h.v.14"], 3],
            ["\\C-CHL\\ Wild boars", ["3.A.4.h.v.14"], 3],
            ["\\C-DNK\\ Pheasants", ["3.A.4.h.v.15"], 3],
            ["\\C-LTU\\ Nutria", ["3.A.4.h.v.16"], 3],
            ["\\C-USA\\ American bison", ["3.A.4.h.v.17"], 3],
            ["\\C-CHL\\ Llamas, alpacas, huarizos", ["3.A.4.h.v.18"], 3],
        ],
        "entity_mapping": {"EMISSIONS CH4": "CH4"},
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table3.B(a)": {  # Manure management CH4
        "status": "tested",
        "table": {
            "firstrow": 6,
            "lastrow": 52,
            "header": ["entity", "entity", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Population size",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Allocation by climate region (1) Cool",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Allocation by climate region (1) Temperate",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Allocation by climate region (1) Warm",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Typical animal mass (average) Warm",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION VS(2) daily excretion (average) Warm",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION CH4 producing potential (Bo) (2) (average) Warm",
                "IMPLIED EMISSION FACTORS CH4 producing potential (Bo) (2) (average) CH4",
            ],
            "stop_cats": [
                "",
                "nan",
                "(1) Climate regions are defined in terms of annual average temperature as "
                "follows: cool = less than 15 °C; temperate = 15–25 °C inclusive; and warm "  # noqa: RUF001
                "= higher than 25 °C (see table 10.17, chap. 10, vol. 4 of the 2006 IPCC "
                "Guidelines).",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["3.B.1. Cattle", ["3.B.1"], 0],
            ["Option A:", ["\\IGNORE"], 1],
            # AUS
            ["\\C-AUS\\ 3.B.1.a. Dairy cattle", ["\\IGNORE"], 2],
            ["\\C-AUS\\ 3.B.1.b. Non-dairy cattle", ["\\IGNORE"], 2],
            # other countries
            ["\\C!-AUS\\ 3.B.1.a. Dairy cattle", ["3.B.1.A.a"], 2],
            ["\\C!-AUS\\ 3.B.1.b. Non-dairy cattle", ["3.B.1.A.b"], 2],
            ["Option B (country-specific): (3)", ["\\IGNORE"], 1],
            ["3.B.1.a. Other", ["3.B.1.B"], 2],
            ["Drop down list:", ["\\IGNORE"], 3],
            ["3.B.1.a.i. Mature dairy cattle", ["3.B.1.B.a"], 3],
            ["3.B.1.a.ii. Other mature cattle", ["3.B.1.B.b"], 3],
            ["3.B.1.a.iii. Growing cattle", ["3.B.1.B.c"], 3],
            ["3.B.1.a.iv. Other (please specify)", ["3.B.1.B.d"], 3],
            ["\\C-AUS\\ Dairy Cattle", ["3.B.1.B.d.AUS-i"], 4],
            ["\\C-AUS\\ Beef Cattle - Pasture", ["3.B.1.B.d.AUS-ii"], 4],
            ["\\C-AUS\\ Beef Cattle - Feedlot", ["3.B.1.C.d.AUS-iii"], 4],
            ["\\C-MLT\\ Bulls", ["3.B.1.B.d.MLT-i"], 4],
            ["\\C-MLT\\ Calves", ["3.B.1.B.d.MLT-ii"], 4],
            ["\\C-POL\\ Bulls (older than 2 years)", ["3.B.1.B.d.POL-i"], 4],
            [
                "\\C-POL\\ Non-dairy Heifers (older than 2 years)",
                ["3.B.1.B.d.POL-ii"],
                4,
            ],
            [
                "\\C-POL\\ Non-dairy Young Cattle (younger than 1 year)",
                ["3.B.1.C.d.POL-iii"],
                4,
            ],
            ["\\C-POL\\ Non-dairy Young Cattle (1-2 years)", ["3.B.1.C.d.POL-iv"], 4],
            ["\\C-POL\\ Dairy Cattle", ["3.B.1.C.d.POL-v"], 4],
            ["\\C-POL\\ Non-dairy Cattle", ["3.B.1.C.d.POL-vi"], 4],
            ["\\C-SVN\\ Non-dairy cattle", ["3.B.1.B.d.SVN-i"], 4],
            ["\\C-SVN\\ Other cows", ["3.B.1.B.d.SVN-ii"], 4],
            ["\\C-CHL\\ Dairy Cattle", ["3.B.1.B.d.CHL-i"], 4],
            ["\\C-CHL\\ Beef cattle", ["3.B.1.B.d.CHL-ii"], 4],
            ["\\C-CHL\\ Heifer", ["3.B.1.B.d.CHL-iii"], 4],
            ["\\C-CHL\\ Beef cattle (> 2 yr)", ["3.B.1.B.d.CHL-iv"], 4],
            ["\\C-CHL\\ Beef cattle (1 - 2 yr)", ["3.B.1.B.d.CHL-v"], 4],
            ["\\C-CHL\\ Calves", ["3.B.1.B.d.CHL-vi"], 4],
            [
                "\\C-COL\\ 3.B.1.a.i. High production dairy cattle",
                ["3.B.1.B.d.COL-i"],
                4,
            ],
            [
                "\\C-COL\\ 3.B.1.a.ii. Low production dairy cattle.",
                ["3.B.1.B.d.COL-ii"],
                4,
            ],
            ["\\C-COL\\ 3.B.1.a.iii. Beef cattle", ["3.B.1.B.d.COL-iii"], 4],
            ["\\C-COL\\ 3.B.1.a.iv. Breeding bulls.", ["3.B.1.B.d.COL-iv"], 4],
            ["\\C-COL\\ 3.B.1.a.v. Pre-weaning calves", ["3.B.1.B.d.COL-v"], 4],
            ["\\C-COL\\ 3.B.1.a.vi. Replacement heifers.", ["3.B.1.B.d.COL-vi"], 4],
            [
                "\\C-COL\\ 3.B.1.a.vii. Beef cattle o Feedlot cattle",
                ["3.B.1.B.d.COL-vii"],
                4,
            ],
            # error in panama tables. Young calves present twice, others shifted
            # ["\\C-PAN\\ High production dairy cows", ["3.B.1.B.d.PAN-i"], 4],
            # ["\\C-PAN\\ Low-yielding dairy cows", ["3.B.1.B.d.PAN-i"], 4],
            # ["\\C-PAN\\ Dairy cattle (doble próposito)", ["3.B.1.B.d.PAN-ii"], 4],
            # ["\\C-PAN\\ Young male bull (Novillos)", ["3.B.1.B.d.PAN-iii"], 4],
            # ["\\C-PAN\\ Young calves (terneros)", ["3.B.1.B.d.PAN-iv"], 4],
            # ["\\C-PAN\\ Bull", ["3.B.1.B.d.PAN-v"], 4],
            ["\\C-PAN\\ High production dairy cows", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Low-yielding dairy cows", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Dairy cattle (doble próposito)", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Young male bull (Novillos)", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Young calves (terneros)", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Bull", ["\\IGNORE"], 4],
            ["\\C-USA\\ Dairy cattle", ["3.B.1.B.d.USA-i"], 4],
            ["\\C-USA\\ Non-dairy cattle", ["3.B.1.B.d.USA-ii"], 4],
            ["\\C-USA\\ Dairy cows", ["3.B.1.B.d.USA-iii"], 4],
            ["\\C-USA\\ Heifer feedlot", ["3.B.1.B.d.USA-iv"], 4],
            ["\\C-USA\\ Steer feedlot", ["3.B.1.B.d.USA-v"], 4],
            ["\\C-USA\\ Beef replacements", ["3.B.1.B.d.USA-vi"], 4],
            ["\\C-USA\\ Dairy replacements", ["3.B.1.B.d.USA-vii"], 4],
            ["\\C-USA\\ Beef cows", ["3.B.1.B.d.USA-viii"], 4],
            ["\\C-USA\\ Heifer stocker", ["3.B.1.B.d.USA-ix"], 4],
            ["\\C-USA\\ Steer stocker", ["3.B.1.B.d.USA-x"], 4],
            ["\\C-USA\\ Bulls", ["3.B.1.B.d.USA-xi"], 4],
            ["\\C-USA\\ Dairy calves", ["3.B.1.B.d.USA-xii"], 4],
            ["\\C-USA\\ Beef calves", ["3.B.1.B.d.USA-xiii"], 4],
            ["3.B.2. Sheep", ["3.B.2"], 0],
            ["3.B.2.a. Other (please specify)", ["3.B.2.a"], 1],
            ["\\C-AUS-ITA\\ Sheep", ["\\IGNORE"], 2],
            ["\\C-ARG\\ All sheep", ["\\IGNORE"], 2],
            ["\\C-GHA-CHN\\ sheep", ["\\IGNORE"], 2],
            [
                "\\C-CHL-COL-PAN-SRB-AUT-BLR-CHE-CZE-DNK-ESP-EST-FIN-GRC-HRV-JPN-KAZ-"
                "LIE-LTU-LVA-NLD-NOR-NZL-PRT-SVN-SWE-UKR\\ Sheep",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-BEL\\ Sheep unspecified", ["\\IGNORE"], 2],
            ["\\C-CAN\\ Sheep and Lamb", ["\\IGNORE"], 2],
            ["\\C-BRA\\ 3.B.2. Sheep", ["\\IGNORE"], 2],
            ["\\C-COL\\ 3.B.2.a.i. Sheep", ["\\IGNORE"], 2],
            ["\\C-ITA-NLD\\ Sheep (2)", ["\\IGNORE"], 2],
            ["\\C-NLD\\ Sheep (8)", ["\\IGNORE"], 2],
            [
                "\\C-AZE-BTN-BRN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-URY-"
                "UZB-FRA\\ All sheep [IPCC Software 3.A.2.c]",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 2],
            ["\\C-MLT\\ Growing Lambs", ["3.B.2.a.MLT-i"], 2],
            ["\\C-MLT\\ Other Mature Ewes", ["3.B.2.a.MLT-ii"], 2],
            ["\\C-MLT\\ Mature Ewes", ["3.B.2.a.MLT-iii"], 2],
            ["\\C-SVK\\ Mature ewes", ["3.B.2.a.SVK-i"], 2],
            ["\\C-SVK\\ Growing lambs", ["3.B.2.a.SVK-ii"], 2],
            ["\\C-SVK\\ Other mature sheeps", ["3.B.2.a.SVK-iii"], 2],
            ["\\C-TUR\\ Domestic sheep", ["3.B.2.a.TUR-i"], 2],
            ["\\C-TUR\\ Merino sheep", ["3.B.2.a.TUR-ii"], 2],
            ["\\C-DZA\\ dairy Sheep", ["3.B.2.a.DZA-i"], 2],
            ["\\C-DZA\\ Other Sheep", ["3.B.2.a.DZA-ii"], 2],
            ["\\C-IRL\\ Ewes Lowland", ["3.B.2.a.IRL-i"], 2],
            ["\\C-IRL\\ Ewes Upland", ["3.B.2.a.IRL-ii"], 2],
            ["\\C-IRL\\ Lambs Lowland", ["3.B.2.a.IRL-iii"], 2],
            ["\\C-IRL\\ Lambs Upland", ["3.B.2.a.IRL-iv"], 2],
            ["\\C-IRL\\ Other Sheep>1yr Lowland", ["3.B.2.a.IRL-v"], 2],
            ["\\C-IRL\\ Other Sheep>1yr Upland", ["3.B.2.a.IRL-vi"], 2],
            ["\\C-IRL\\ Rams Lowland", ["3.B.2.a.IRL-vii"], 2],
            ["\\C-IRL\\ Rams Upland", ["3.B.2.a.IRL-viii"], 2],
            ["\\C-ISL\\ Mature ewes", ["3.B.2.a.ISL-i"], 2],
            ["\\C-ISL\\ Animal for replacement", ["3.B.2.a.ISL-ii"], 2],
            ["\\C-ISL\\ Other mature sheep", ["3.B.2.a.ISL-iii"], 2],
            ["\\C-ISL\\ Lambs", ["3.B.2.a.ISL-iv"], 2],
            ["\\C-USA\\ Sheep", ["3.B.2.a.USA-i"], 2],
            ["\\C-USA\\ Sheep on feed", ["3.B.2.a.USA-ii"], 2],
            ["\\C-USA\\ Sheep not on feed", ["3.B.2.a.USA-iii"], 2],
            ["3.B.3. Swine", ["3.B.3"], 0],
            ["3.B.3.a. Other (please specify)", ["3.B.3.a"], 1],
            ["\\C-AUS-ITA-CAN\\ Swine", ["\\IGNORE"], 2],
            ["\\C-NZL\\ Pigs", ["\\IGNORE"], 2],
            ["\\C-ARG\\ All swine", ["\\IGNORE"], 2],
            [
                "\\C-GHA-PAN-SRB-AUT-BLR-CHE-CZE-EST-FIN-GRC-JPN-KAZ-LIE-LTU-LVA-NLD-"
                "NOR-PRT-SVN-SWE-TUR-UKR-CHN\\ Swine",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-BEL\\ Swine unspecified", ["\\IGNORE"], 2],
            ["\\C-ITA-NLD\\ Swine (3)", ["\\IGNORE"], 2],
            ["\\C-BRA\\ 3.B.3. Swine", ["\\IGNORE"], 2],
            ["\\C-NLD\\ Swine (7)", ["\\IGNORE"], 2],
            [
                "\\C-AZE-BTN-BRN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-URY-"
                "UZB-FRA\\ All swine [IPCC Software 3.A.2.h]",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 2],
            ["\\C-ESP\\ White swine (finishing/fattening pigs)", ["3.B.3.a.ESP-i"], 2],
            ["\\C-ESP\\ White swine (sows)", ["3.B.3.a.ESP-ii"], 2],
            [
                "\\C-ESP\\ Iberian swine (finishing/fattening pigs)",
                ["3.B.3.a.ESP-iii"],
                2,
            ],
            ["\\C-ESP\\ Iberian swine (sows)", ["3.B.3.a.ESP-iv"], 2],
            ["\\C-MLT\\ Breeding boars", ["3.B.3.a.MLT-i"], 2],
            ["\\C-MLT\\ Breeding females - gilts", ["3.B.3.a.MLT-ii"], 2],
            ["\\C-MLT\\ Breeding female - sows", ["3.B.3.a.MLT-iii"], 2],
            ["\\C-MLT\\ Fattening pigs more than 50kg", ["3.B.3.a.MLT-iv"], 2],
            ["\\C-MLT\\ Young pigs 20-50kg", ["3.B.3.a.MLT-v"], 2],
            ["\\C-MLT\\ Piglets less than 20kg", ["3.B.3.a.MLT-vi"], 2],
            ["\\C-SVK-HRV\\ Breeding swine", ["3.B.3.a.SVK-i"], 2],
            ["\\C-SVK-HRV\\ Market swine", ["3.B.3.a.SVK-ii"], 2],
            ["\\C-CHL\\ Pigs", ["3.B.3.a.CHL-i"], 2],
            ["\\C-CHL\\ Boars", ["3.B.3.a.CHL-ii"], 2],
            ["\\C-CHL\\ Juvenile pigs", ["3.B.3.a.CHL-iii"], 2],
            ["\\C-COL\\ 3.B.3.a.i. Swines < 6 month", ["3.B.3.a.COL-i"], 2],
            ["\\C-COL\\ 3.B.3.a.ii. Swines > 6 month", ["3.B.3.a.COL-ii"], 2],
            ["\\C-COL\\ 3.B.3.a.iii. Low productivity swine", ["3.B.3.a.COL-iii"], 2],
            ["\\C-DNK\\ Sows", ["3.B.3.a.DNK-i"], 2],
            ["\\C-DNK\\ Fattening pigs", ["3.B.3.a.DNK-ii"], 2],
            ["\\C-DNK\\ Weaners", ["3.B.3.a.DNK-iii"], 2],
            ["\\C-IRL\\ Boars", ["3.B.3.a.IRL-i"], 2],
            ["\\C-IRL\\ Sows in Pig", ["3.B.3.a.IRL-ii"], 2],
            ["\\C-IRL\\ Gilts in Pig", ["3.B.3.a.IRL-iii"], 2],
            ["\\C-IRL\\ Pigs > 20kg", ["3.B.3.a.IRL-iv"], 2],
            ["\\C-IRL\\ Pigs < 20kg", ["3.B.3.a.IRL-v"], 2],
            ["\\C-IRL\\ Other Sows for Breeding", ["3.B.3.a.IRL-vi"], 2],
            ["\\C-IRL\\ Gilts not yet Served", ["3.B.3.a.IRL-vii"], 2],
            ["\\C-ISL\\ Piglets", ["3.B.3.a.ISL-i"], 2],
            ["\\C-ISL\\ Sows", ["3.B.3.a.ISL-ii"], 2],
            ["\\C-USA\\ Swine", ["3.B.3.a.USA-i"], 2],
            ["\\C-USA\\ Market swine less than 50 lb", ["3.B.3.a.USA-ii"], 2],
            ["\\C-USA\\ Market swine 50-119 lb", ["3.B.3.a.USA-iii"], 2],
            ["\\C-USA\\ Market swine 120-179 lb", ["3.B.3.a.USA-iv"], 2],
            ["\\C-USA\\ Market swine greater than 180 lb", ["3.B.3.a.USA-v"], 2],
            ["\\C-USA\\ Breeding swine", ["3.B.3.a.USA-vi"], 2],
            # other livestock
            # ["\\C!-AUS-CHL\\ 3.B.4. Other livestock(4)", ["3.B.4"], 0],
            # ["\\C-AUS-ARG-AZE-\\ 3.B.4. Other livestock (4)", ["3.B.4"], 0],
            # ["\\C-CHL\\ 3.B.4. Other livestock (please specify) (4)", ["3.B.4"], 0],
            ["3.B.4. Other livestock (4)", ["3.B.4"], 0],
            ["\\C-AUS-CHL\\ Drop-down list:", ["\\IGNORE"], 1],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 1],
            ["3.B.4.a. Buffalo", ["3.B.4.a"], 1],
            ["3.B.4.b. Camels", ["3.B.4.b"], 1],
            ["3.B.4.c. Deer", ["3.B.4.c"], 1],
            ["3.B.4.d. Goats", ["3.B.4.d"], 1],
            ["3.B.4.e. Horses", ["3.B.4.e"], 1],
            ["3.B.4.f. Mules and Asses", ["3.B.4.f"], 1],
            ["3.B.4.g. Poultry", ["3.B.4.g"], 1],
            ["\\C!-CHL\\ 3.B.4.h. Other", ["3.B.4.h"], 1],
            ["\\C-CHL\\ 3.B.4.h. Other (please specify)", ["3.B.4.h"], 1],
            ["\\C-AUS\\ Drop-down list:", ["\\IGNORE"], 2],
            ["3.B.4.h.i. Rabbit", ["3.B.4.h.i"], 2],
            ["3.B.4.h.ii. Reindeer", ["3.B.4.h.ii"], 2],
            ["3.B.4.h.iii. Ostrich", ["3.B.4.h.iii"], 2],
            ["3.B.4.h.iv. Fur-bearing animals (5)", ["3.B.4.h.iv"], 2],
            ["\\C!-CHL\\ 3.B.4.h.v. Other (please specify)", ["3.B.4.h.v"], 2],
            ["\\C-CHL\\ 3.B.4.h.v. Other (please specity)", ["3.B.4.h.v"], 2],
            ["\\C-AUS\\ Alpacas", ["3.B.4.h.v.1"], 3],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " Alpacas [IPCC Software 3.A.2.j]",
                ["3.B.4.h.v.1"],
                3,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " Llamas [IPCC Software 3.A.2.j]",
                ["3.B.4.h.v.2"],
                3,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " All other species [IPCC Software 3.A.2.j]",
                ["3.B.4.h.v.10"],
                3,
            ],
            ["\\C-SGP\\ Quail", ["3.B.4.h.v.3"], 3],
            ["\\C-ESP\\ Ducks and other poultry", ["3.B.4.h.v.4"], 3],
            ["\\C-ESP\\ Turkeys", ["3.B.4.h.v.5"], 3],
            ["\\C-ESP\\ Broilers", ["3.B.4.h.v.6"], 3],
            ["\\C-CHE\\ Livestock outside agriculture", ["3.B.4.h.v.11"], 3],
            ["\\C-COL\\ 3.B.4.g.i. Laying hens", ["3.B.4.h.v.12"], 3],
            ["\\C-COL\\ 3.B.4.g.ii. broiler chicken", ["3.B.4.h.v.13"], 3],
            ["\\C-CAN\\ Wild Boar", ["3.B.4.h.v.14"], 3],
            ["\\C-CHL\\ Wild boars", ["3.B.4.h.v.14"], 3],
            ["\\C-DNK\\ Pheasants", ["3.B.4.h.v.15"], 3],
            ["\\C-LTU\\ Nutria", ["3.B.4.h.v.16"], 3],
            ["\\C-USA\\ American bison", ["3.B.4.h.v.17"], 3],
            ["\\C-CHL\\ Llamas, alpacas, huarizos", ["3.B.4.h.v.18"], 3],
        ],
        "entity_mapping": {
            "EMISSIONS CH4 producing potential (Bo) (2) (average) CH4": "CH4"
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table3.B(b)": {  # Manure management N2O
        "status": "tested",
        "table": {
            "firstrow": 5,
            "lastrow": 48,  # don't read indirect emissions as we have them from
            # Table3 and reading them makes the specification very complicated
            "header": ["entity", "entity", "entity", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Population size (1000s)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion rate "
                "(kg N/ head/yr)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Typical animal mass "
                "(average) (kg/ head)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Anaerobic lagoon",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Liquid system",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Daily spread",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Solid storage",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Pit storage",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Dry lot",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Deep bedding",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Pasture range and paddock (1)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Composting",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Digesters",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Burned for fuel or as waste (2)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Other (3)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Total N excreted Other (3)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Total N volatilised as "
                "NH3, NOX and N2 (4)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION N lost through leaching "
                "and run-off",
                "IMPLIED EMISSION FACTORS Emission factor per animals Direct and run-off",
                "IMPLIED EMISSION FACTORS Emission factor per animals Indirect "
                "Atmospheric deposition",
                "IMPLIED EMISSION FACTORS Emission factor per animals Indirect "
                "Nitrogen leaching and run-off",
                "EMISSIONS N2O Indirect Atmospheric deposition",
                "EMISSIONS N2O Indirect Nitrogen leaching and run-off",
            ],
            "stop_cats": [
                "",
                "nan",
                "(1) Direct and indirect N2O emissions associated with the manure "
                "deposited on agricultural soils or pasture, range and paddock systems "
                "are included under N2O emissions from managed soils (see table "
                "3(III).D-E).",
                "3.B.5. Indirect N2O emissions",
                "Total N handled per MMS (kg N/year)",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["3.B.1. Cattle", ["3.B.1"], 0],
            ["Option A:", ["\\IGNORE"], 1],
            # AUS
            ["\\C-AUS\\ 3.B.1.a. Dairy cattle", ["\\IGNORE"], 2],
            ["\\C-AUS\\ 3.B.1.b. Non-dairy cattle", ["\\IGNORE"], 2],
            # other countries
            ["\\C!-AUS\\ 3.B.1.a. Dairy cattle", ["3.B.1.A.a"], 2],
            ["\\C!-AUS\\ 3.B.1.b. Non-dairy cattle", ["3.B.1.A.b"], 2],
            ["Option B (country-specific): (5)", ["\\IGNORE"], 1],
            ["3.B.1.a. Other", ["3.B.1.B"], 2],
            ["\\C-AUS-ECU\\ Drop-down list", ["\\IGNORE"], 3],
            ["3.B.1.a.i. Mature dairy cattle", ["3.B.1.B.a"], 3],
            ["3.B.1.a.ii. Other mature cattle", ["3.B.1.B.b"], 3],
            ["3.B.1.a.iii. Growing cattle", ["3.B.1.B.c"], 3],
            ["3.B.1.a.iv. Other (please specify)", ["3.B.1.B.d"], 3],
            ["\\C-AUS\\ Dairy Cattle", ["3.B.1.B.d.AUS-i"], 4],
            ["\\C-AUS\\ Beef Cattle - Pasture", ["3.B.1.B.d.AUS-ii"], 4],
            ["\\C-AUS\\ Beef Cattle - Feedlot", ["3.B.1.C.d.AUS-iii"], 4],
            ["\\C-MLT\\ Bulls", ["3.B.1.B.d.MLT-i"], 4],
            ["\\C-MLT\\ Calves", ["3.B.1.B.d.MLT-ii"], 4],
            ["\\C-POL\\ Bulls (older than 2 years)", ["3.B.1.B.d.POL-i"], 4],
            [
                "\\C-POL\\ Non-dairy Heifers (older than 2 years)",
                ["3.B.1.B.d.POL-ii"],
                4,
            ],
            [
                "\\C-POL\\ Non-dairy Young Cattle (younger than 1 year)",
                ["3.B.1.C.d.POL-iii"],
                4,
            ],
            ["\\C-POL\\ Non-dairy Young Cattle (1-2 years)", ["3.B.1.C.d.POL-iv"], 4],
            ["\\C-POL\\ Dairy Cattle", ["3.B.1.C.d.POL-v"], 4],
            ["\\C-POL\\ Non-dairy Cattle", ["3.B.1.C.d.POL-vi"], 4],
            ["\\C-SVN\\ Non-dairy cattle", ["3.B.1.B.d.SVN-i"], 4],
            ["\\C-SVN\\ Other cows", ["3.B.1.B.d.SVN-ii"], 4],
            ["\\C-CHL\\ Dairy Cattle", ["3.B.1.B.d.CHL-i"], 4],
            ["\\C-CHL\\ Beef cattle", ["3.B.1.B.d.CHL-ii"], 4],
            ["\\C-CHL\\ Heifer", ["3.B.1.B.d.CHL-iii"], 4],
            ["\\C-CHL\\ Beef cattle (> 2 yr)", ["3.B.1.B.d.CHL-iv"], 4],
            ["\\C-CHL\\ Beef cattle (1 - 2 yr)", ["3.B.1.B.d.CHL-v"], 4],
            ["\\C-CHL\\ Calves", ["3.B.1.B.d.CHL-vi"], 4],
            [
                "\\C-COL\\ 3.B.1.a.i. High production dairy cattle",
                ["3.B.1.B.d.COL-i"],
                4,
            ],
            [
                "\\C-COL\\ 3.B.1.a.ii. Low production dairy cattle.",
                ["3.B.1.B.d.COL-ii"],
                4,
            ],
            ["\\C-COL\\ 3.B.1.a.iii. Beef cattle", ["3.B.1.B.d.COL-iii"], 4],
            ["\\C-COL\\ 3.B.1.a.iv. Breeding bulls.", ["3.B.1.B.d.COL-iv"], 4],
            ["\\C-COL\\ 3.B.1.a.v. Pre-weaning calves", ["3.B.1.B.d.COL-v"], 4],
            ["\\C-COL\\ 3.B.1.a.vi. Replacement heifers.", ["3.B.1.B.d.COL-vi"], 4],
            [
                "\\C-COL\\ 3.B.1.a.vii. Beef cattle o Feedlot cattle",
                ["3.B.1.B.d.COL-vii"],
                4,
            ],
            # error in panama tables. Young calves present twice, others shifted
            # ["\\C-PAN\\ High production dairy cows", ["3.B.1.B.d.PAN-i"], 4],
            # ["\\C-PAN\\ Low-yielding dairy cows", ["3.B.1.B.d.PAN-i"], 4],
            # ["\\C-PAN\\ Dairy cattle (doble próposito)", ["3.B.1.B.d.PAN-ii"], 4],
            # ["\\C-PAN\\ Young male bull (Novillos)", ["3.B.1.B.d.PAN-iii"], 4],
            # ["\\C-PAN\\ Young calves (terneros)", ["3.B.1.B.d.PAN-iv"], 4],
            # ["\\C-PAN\\ Bull", ["3.B.1.B.d.PAN-v"], 4],
            ["\\C-PAN\\ High production dairy cows", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Low-yielding dairy cows", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Dairy cattle (doble próposito)", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Young male bull (Novillos)", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Young calves (terneros)", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Bull", ["\\IGNORE"], 4],
            ["\\C-USA\\ Dairy cattle", ["3.B.1.B.d.USA-i"], 4],
            ["\\C-USA\\ Non-dairy cattle", ["3.B.1.B.d.USA-ii"], 4],
            ["\\C-USA\\ Dairy cows", ["3.B.1.B.d.USA-iii"], 4],
            ["\\C-USA\\ Heifer feedlot", ["3.B.1.B.d.USA-iv"], 4],
            ["\\C-USA\\ Steer feedlot", ["3.B.1.B.d.USA-v"], 4],
            ["\\C-USA\\ Beef replacements", ["3.B.1.B.d.USA-vi"], 4],
            ["\\C-USA\\ Dairy replacements", ["3.B.1.B.d.USA-vii"], 4],
            ["\\C-USA\\ Beef cows", ["3.B.1.B.d.USA-viii"], 4],
            ["\\C-USA\\ Heifer stocker", ["3.B.1.B.d.USA-ix"], 4],
            ["\\C-USA\\ Steer stocker", ["3.B.1.B.d.USA-x"], 4],
            ["\\C-USA\\ Bulls", ["3.B.1.B.d.USA-xi"], 4],
            ["\\C-USA\\ Dairy calves", ["3.B.1.B.d.USA-xii"], 4],
            ["\\C-USA\\ Beef calves", ["3.B.1.B.d.USA-xiii"], 4],
            ["3.B.2. Sheep", ["3.B.2"], 0],
            ["3.B.2.a. Other (please specify)", ["3.B.2.a"], 1],
            ["\\C-AUS-ITA\\ Sheep", ["\\IGNORE"], 2],
            ["\\C-ARG\\ All sheep", ["\\IGNORE"], 2],
            ["\\C-GHA-CHN\\ sheep", ["\\IGNORE"], 2],
            [
                "\\C-CHL-COL-PAN-SRB-AUT-BLR-CHE-CZE-DNK-ESP-EST-FIN-GRC-HRV-JPN-KAZ-"
                "LIE-LTU-LVA-NLD-NOR-NZL-PRT-SVN-SWE-UKR\\ Sheep",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-BEL\\ Sheep unspecified", ["\\IGNORE"], 2],
            ["\\C-CAN\\ Sheep and Lamb", ["\\IGNORE"], 2],
            ["\\C-BRA\\ 3.B.2. Sheep", ["\\IGNORE"], 2],
            ["\\C-COL\\ 3.B.2.a.i. Sheep", ["\\IGNORE"], 2],
            ["\\C-ITA-NLD\\ Sheep (3)", ["\\IGNORE"], 2],
            ["\\C-NLD\\ Sheep (8)", ["\\IGNORE"], 2],
            [
                "\\C-AZE-BTN-BRN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-URY-"
                "UZB-FRA\\ All sheep [IPCC Software 3.A.2.c]",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 2],
            ["\\C-MLT\\ Growing Lambs", ["3.B.2.a.MLT-i"], 2],
            ["\\C-MLT\\ Other Mature Ewes", ["3.B.2.a.MLT-ii"], 2],
            ["\\C-MLT\\ Mature Ewes", ["3.B.2.a.MLT-iii"], 2],
            ["\\C-SVK\\ Mature ewes", ["3.B.2.a.SVK-i"], 2],
            ["\\C-SVK\\ Growing lambs", ["3.B.2.a.SVK-ii"], 2],
            ["\\C-SVK\\ Other mature sheeps", ["3.B.2.a.SVK-iii"], 2],
            ["\\C-TUR\\ Domestic sheep", ["3.B.2.a.TUR-i"], 2],
            ["\\C-TUR\\ Merino sheep", ["3.B.2.a.TUR-ii"], 2],
            ["\\C-DZA\\ dairy Sheep", ["3.B.2.a.DZA-i"], 2],
            ["\\C-DZA\\ Other Sheep", ["3.B.2.a.DZA-ii"], 2],
            ["\\C-IRL\\ Ewes Lowland", ["3.B.2.a.IRL-i"], 2],
            ["\\C-IRL\\ Ewes Upland", ["3.B.2.a.IRL-ii"], 2],
            ["\\C-IRL\\ Lambs Lowland", ["3.B.2.a.IRL-iii"], 2],
            ["\\C-IRL\\ Lambs Upland", ["3.B.2.a.IRL-iv"], 2],
            ["\\C-IRL\\ Other Sheep>1yr Lowland", ["3.B.2.a.IRL-v"], 2],
            ["\\C-IRL\\ Other Sheep>1yr Upland", ["3.B.2.a.IRL-vi"], 2],
            ["\\C-IRL\\ Rams Lowland", ["3.B.2.a.IRL-vii"], 2],
            ["\\C-IRL\\ Rams Upland", ["3.B.2.a.IRL-viii"], 2],
            ["\\C-ISL\\ Mature ewes", ["3.B.2.a.ISL-i"], 2],
            ["\\C-ISL\\ Animal for replacement", ["3.B.2.a.ISL-ii"], 2],
            ["\\C-ISL\\ Other mature sheep", ["3.B.2.a.ISL-iii"], 2],
            ["\\C-ISL\\ Lambs", ["3.B.2.a.ISL-iv"], 2],
            ["\\C-USA\\ Sheep", ["3.B.2.a.USA-i"], 2],
            ["\\C-USA\\ Sheep on feed", ["3.B.2.a.USA-ii"], 2],
            ["\\C-USA\\ Sheep not on feed", ["3.B.2.a.USA-iii"], 2],
            ["3.B.3. Swine", ["3.B.3"], 0],
            ["3.B.3.a. Other (please specify)", ["3.B.3.a"], 1],
            ["\\C-AUS-ITA-CAN\\ Swine", ["\\IGNORE"], 2],
            ["\\C-NZL\\ Pigs", ["\\IGNORE"], 2],
            ["\\C-ARG\\ All swine", ["\\IGNORE"], 2],
            [
                "\\C-GHA-PAN-SRB-AUT-BLR-CHE-CZE-EST-FIN-GRC-JPN-KAZ-LIE-LTU-LVA-NLD-"
                "NOR-PRT-SVN-SWE-TUR-UKR-CHN\\ Swine",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-BEL\\ Swine unspecified", ["\\IGNORE"], 2],
            ["\\C-ITA-NLD\\ Swine (2)", ["\\IGNORE"], 2],
            ["\\C-BRA\\ 3.B.3. Swine", ["\\IGNORE"], 2],
            ["\\C-NLD\\ Swine (7)", ["\\IGNORE"], 2],
            [
                "\\C-AZE-BTN-BRN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-URY-"
                "UZB-FRA\\ All swine [IPCC Software 3.A.2.h]",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 2],
            ["\\C-ESP\\ White swine (finishing/fattening pigs)", ["3.B.3.a.ESP-i"], 2],
            ["\\C-ESP\\ White swine (sows)", ["3.B.3.a.ESP-ii"], 2],
            [
                "\\C-ESP\\ Iberian swine (finishing/fattening pigs)",
                ["3.B.3.a.ESP-iii"],
                2,
            ],
            ["\\C-ESP\\ Iberian swine (sows)", ["3.B.3.a.ESP-iv"], 2],
            ["\\C-MLT\\ Breeding boars", ["3.B.3.a.MLT-i"], 2],
            ["\\C-MLT\\ Breeding females - gilts", ["3.B.3.a.MLT-ii"], 2],
            ["\\C-MLT\\ Breeding female - sows", ["3.B.3.a.MLT-iii"], 2],
            ["\\C-MLT\\ Fattening pigs more than 50kg", ["3.B.3.a.MLT-iv"], 2],
            ["\\C-MLT\\ Young pigs 20-50kg", ["3.B.3.a.MLT-v"], 2],
            ["\\C-MLT\\ Piglets less than 20kg", ["3.B.3.a.MLT-vi"], 2],
            ["\\C-SVK-HRV\\ Breeding swine", ["3.B.3.a.SVK-i"], 2],
            ["\\C-SVK-HRV\\ Market swine", ["3.B.3.a.SVK-ii"], 2],
            ["\\C-CHL\\ Pigs", ["3.B.3.a.CHL-i"], 2],
            ["\\C-CHL\\ Boars", ["3.B.3.a.CHL-ii"], 2],
            ["\\C-CHL\\ Juvenile pigs", ["3.B.3.a.CHL-iii"], 2],
            ["\\C-COL\\ 3.B.3.a.i. swine < 6 months", ["3.B.3.a.COL-i"], 2],
            ["\\C-COL\\ 3.B.3.a.ii. Swine > 6 months", ["3.B.3.a.COL-ii"], 2],
            ["\\C-COL\\ 3.B.3.a.iii. Low productivity swine", ["3.B.3.a.COL-iii"], 2],
            ["\\C-DNK\\ Sows", ["3.B.3.a.DNK-i"], 2],
            ["\\C-DNK\\ Fattening pigs", ["3.B.3.a.DNK-ii"], 2],
            ["\\C-DNK\\ Weaners", ["3.B.3.a.DNK-iii"], 2],
            ["\\C-IRL\\ Boars", ["3.B.3.a.IRL-i"], 2],
            ["\\C-IRL\\ Sows in Pig", ["3.B.3.a.IRL-ii"], 2],
            ["\\C-IRL\\ Gilts in Pig", ["3.B.3.a.IRL-iii"], 2],
            ["\\C-IRL\\ Pigs > 20kg", ["3.B.3.a.IRL-iv"], 2],
            ["\\C-IRL\\ Pigs < 20kg", ["3.B.3.a.IRL-v"], 2],
            ["\\C-IRL\\ Other Sows for Breeding", ["3.B.3.a.IRL-vi"], 2],
            ["\\C-IRL\\ Gilts not yet Served", ["3.B.3.a.IRL-vii"], 2],
            ["\\C-ISL\\ Piglets", ["3.B.3.a.ISL-i"], 2],
            ["\\C-ISL\\ Sows", ["3.B.3.a.ISL-ii"], 2],
            ["\\C-USA\\ Swine", ["3.B.3.a.USA-i"], 2],
            ["\\C-USA\\ Market swine less than 50 lb", ["3.B.3.a.USA-ii"], 2],
            ["\\C-USA\\ Market swine 50-119 lb", ["3.B.3.a.USA-iii"], 2],
            ["\\C-USA\\ Market swine 120-179 lb", ["3.B.3.a.USA-iv"], 2],
            ["\\C-USA\\ Market swine greater than 180 lb", ["3.B.3.a.USA-v"], 2],
            ["\\C-USA\\ Breeding swine", ["3.B.3.a.USA-vi"], 2],
            # other livestock
            # ["\\C!-AUS-CHL\\ 3.B.4. Other livestock(4)", ["3.B.4"], 0],
            # ["\\C-AUS-ARG-AZE-\\ 3.B.4. Other livestock (4)", ["3.B.4"], 0],
            # ["\\C-CHL\\ 3.B.4. Other livestock (please specify) (4)", ["3.B.4"], 0],
            ["3.B.4. Other livestock (6)", ["3.B.4"], 0],
            ["\\C-AUS-CHL\\ Drop-down list", ["\\IGNORE"], 1],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 1],
            ["3.B.4.a. Buffalo", ["3.B.4.a"], 1],
            ["3.B.4.b. Camels", ["3.B.4.b"], 1],
            ["3.B.4.c. Deer", ["3.B.4.c"], 1],
            ["3.B.4.d. Goats", ["3.B.4.d"], 1],
            ["3.B.4.e. Horses", ["3.B.4.e"], 1],
            ["3.B.4.f. Mules and asses", ["3.B.4.f"], 1],
            ["3.B.4.g. Poultry", ["3.B.4.g"], 1],
            ["\\C!-CHL\\ 3.B.4.h. Other", ["3.B.4.h"], 1],
            ["\\C-CHL\\ 3.B.4.h. Other (please specify)", ["3.B.4.h"], 1],
            ["\\C-AUS\\ Drop-down list:", ["\\IGNORE"], 2],
            ["3.B.4.h.i. Rabbit", ["3.B.4.h.i"], 2],
            ["3.B.4.h.ii. Reindeer", ["3.B.4.h.ii"], 2],
            ["3.B.4.h.iii. Ostrich", ["3.B.4.h.iii"], 2],
            ["3.B.4.h.iv Fur-bearing animals (7)", ["3.B.4.h.iv"], 2],
            ["\\C!-CHL\\ 3.B.4.h.v. Other (please specify)", ["3.B.4.h.v"], 2],
            ["\\C-CHL\\ 3.B.4.h.v. Other (please specity)", ["3.B.4.h.v"], 2],
            ["\\C-AUS\\ Alpacas", ["3.B.4.h.v.1"], 3],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " Alpacas [IPCC Software 3.A.2.j]",
                ["3.B.4.h.v.1"],
                3,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " Llamas [IPCC Software 3.A.2.j]",
                ["3.B.4.h.v.2"],
                3,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " All other species [IPCC Software 3.A.2.j]",
                ["3.B.4.h.v.10"],
                3,
            ],
            ["\\C-SGP\\ Quail", ["3.B.4.h.v.3"], 3],
            ["\\C-ESP\\ Ducks and other poultry", ["3.B.4.h.v.4"], 3],
            ["\\C-ESP\\ Turkeys", ["3.B.4.h.v.5"], 3],
            ["\\C-ESP\\ Broilers", ["3.B.4.h.v.6"], 3],
            ["\\C-CHE\\ Livestock outside agriculture", ["3.B.4.h.v.11"], 3],
            ["\\C-COL\\ 3.B.4.g.i. Laying hens", ["3.B.4.h.v.12"], 3],
            ["\\C-COL\\ 3.B.4.g.ii. broiler chicken", ["3.B.4.h.v.13"], 3],
            ["\\C-CAN\\ Wild Boar", ["3.B.4.h.v.14"], 3],
            ["\\C-CHL\\ Wild boars", ["3.B.4.h.v.14"], 3],
            ["\\C-DNK\\ Pheasants", ["3.B.4.h.v.15"], 3],
            ["\\C-LTU\\ Nutria", ["3.B.4.h.v.16"], 3],
            ["\\C-USA\\ American bison", ["3.B.4.h.v.17"], 3],
            ["\\C-CHL\\ Llamas, alpacas, huarizos", ["3.B.4.h.v.18"], 3],
        ],
        "entity_mapping": {
            "EMISSIONS N2O Direct Nitrogen leaching and run-off": "N2O",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    # TODO: tables 3.A and 3.B for livestock details as they are not contained in table3
    "Table3.C": {  # rice cultivation details
        "status": "tested",
        "table": {
            "firstrow": 7,
            "lastrow": 25,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Harvested area (2)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Organic amendments added (3)",
                "IMPLIED EMISSION FACTOR (1) CH4",
            ],
            "stop_cats": [
                "",
                "nan",
                "(1) The IEF implicitly takes account of all relevant corrections for "
                "continuously flooded fields without organic amendments, the correction"
                " for organic amendments and the effect of different soil "
                "characteristics, if considered in the calculation of CH4 emissions.",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["3.C.1. Irrigated", ["3.C.1"]],
            ["3.C.1.a. Continuously flooded", ["3.C.1.a"]],
            ["3.C.1.b. Intermittently flooded", ["3.C.1.b"]],
            ["3.C.1.b.i. Single aeration", ["3.C.1.b.i"]],
            ["3.C.1.b.ii.Multiple aeration", ["3.C.1.b.ii"]],
            ["3.C.2. Rain-fed", ["3.C.2"]],
            ["3.C.2.a. Flood-prone", ["3.C.2.a"]],
            ["3.C.2.b. Drought-prone", ["3.C.2.b"]],
            ["3.C.3. Deep water", ["3.C.3"]],
            ["3.C.3.a. Water depth 50–100 cm", ["3.C.3.a"]],  # noqa: RUF001
            ["3.C.3.b. Water depth > 100 cm", ["3.C.3.b"]],
            ["3.C.4. Other (please specify)", ["3.C.4"]],
            ["\\C-AUS-BRA-CHL-SGP\\ NA", ["\\IGNORE"]],
            ["\\C-COL\\ 3.C.4. Other", ["3.C.4.a"]],
            ["\\C-EST\\ Other non-specified", ["3.C.4.a"]],
            ["\\C-LTU\\ Other", ["3.C.4.a"]],
            ["\\C-GHA\\ Upland", ["3.C.4.b"]],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-"
                "URY-UZB-FRA\\ Other rice ecosystems [IPCC Software 3.C.7]",
                ["3.C.4.a"],
            ],
            ["\\C-CHN\\ 3.C.4.a. Water-logged in fallow season", ["3.C.4.c"]],
            # ignore as just for comparison
            ["Upland rice(4)", ["\\IGNORE"]],
            ["Total(4)", ["\\IGNORE"]],
        ],
        "entity_mapping": {
            "EMISSIONS CH4": "CH4",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table3.D": {  # direct and indirect N2O from soils
        "status": "tested",
        "table": {
            "firstrow": 7,
            "lastrow": 24,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Description",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Value",
                "IMPLIED EMISSION FACTORS Value",
                # "Fraction (a) FracGASF",
                # "Description Fraction of synthetic fertilizer N applied to soils that "
                # "volatilises as NH3 and NOX",
                # "Value 0.11",
            ],
            "stop_cats": [
                "",
                "nan",
                "(1) To convert from N2O–N to N2O emissions, multiply by 44/28.",  # noqa: RUF001
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["3.D.1. Direct N2O emissions from managed soils", ["3.D.a"]],
            ["3.D.1.a. Inorganic N fertilizers (3)", ["3.D.a.1"]],
            ["3.D.1.b. Organic N fertilizers (3)", ["3.D.a.2"]],
            ["3.D.1.b.i. Animal manure applied to soils", ["3.D.a.2.a"]],
            ["3.D.1.b.ii. Sewage sludge applied to soils", ["3.D.a.2.b"]],
            ["3.D.1.b.iii. Other organic fertilizers applied to soils", ["3.D.a.2.c"]],
            ["3.D.1.c. Urine and dung deposited by grazing animals", ["3.D.a.3"]],
            ["3.D.1.d. Crop residues", ["3.D.a.4"]],
            [
                "3.D.1.e. Mineralization/immobilization associated with loss/gain of "
                "soil organic matter (4,5)",
                ["3.D.a.5"],
            ],
            ["3.D.1.f. Cultivation of organic soils (i.e. histosols) (2)", ["3.D.a.6"]],
            ["3.D.1.g. Other", ["3.D.a.7"]],
            ["3.D.2. Indirect N2O Emissions from managed soils", ["3.D.b"]],
            ["3.D.2.a. Atmospheric deposition (6)", ["3.D.b.1"]],
            ["3.D.2.b. Nitrogen leaching and run-off", ["3.D.b.2"]],
        ],
        "entity_mapping": {
            "EMISSIONS N2O": "N2O",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table3.E": {  # savanna burning details
        "status": "TODO",  # actually done but empty and crashes
        "table": {
            "firstrow": 7,
            "lastrow": 13,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Area of savannah burned",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Average above-ground biomass density",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Biomass burned",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Fraction of savannah "
                "burned",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen fraction in biomass",
                "IMPLIED EMISSION FACTORS CH4",
                "IMPLIED EMISSION FACTORS N2O",
            ],
            "stop_cats": ["", ".", "nan"],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["3.E.1. Forest land (specify ecological zone) (2)", ["3.E.1"], 0],
            ["NA", ["\\IGNORE"], 1],
            ["3.E.2. Grassland (specify ecological zone) (2)", ["3.E.2"], 0],
            ["NA", ["\\IGNORE"], 1],
        ],
        "entity_mapping": {
            "EMISSIONS (2) CH4": "CH4",
            "EMISSIONS (2) N2O": "N2O",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # TODO
    "Table3.F": {  # field burning details
        "status": "TODO",
        "table": {
            "firstrow": 7,
            "lastrow": 29,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": ["", "nan"],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [],
        "entity_mapping": [],
        "coords_defaults": {
            "class": "Total",
        },
    },  # TODO
    "Table3.G-I": {  # liming, urea, carbon containing fertilizer
        "status": "TODO",
        "table": {
            "firstrow": 5,
            "lastrow": 13,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": ["", "nan"],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [],
        "entity_mapping": [],
        "coords_defaults": {
            "class": "Total",
        },
    },  # TODO
    "Table4": {  # LULUCF overview
        "status": "tested",
        "table": {
            "firstrow": 8,
            "lastrow": 33,
            "header": ["entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": ["", ".", "nan"],
            "unit_info": unit_info["industry"],
        },
        "sector_mapping": [
            ["4. Total LULUCF", ["4"]],
            ["4.A. Forest land", ["4.A"]],
            ["4.A.1. Forest land remaining forest land", ["4.A.1"]],
            ["4.A.2. Land converted to forest land", ["4.A.2"]],
            ["4.B. Cropland", ["4.B"]],
            ["4.B.1. Cropland remaining cropland", ["4.B.1"]],
            ["4.B.2. Land converted to cropland", ["4.B.2"]],
            ["4.C. Grassland", ["4.C"]],
            ["4.C.1. Grassland remaining grassland", ["4.C.1"]],
            ["4.C.2. Land converted to grassland", ["4.C.2"]],
            ["4.D. Wetlands (5)", ["4.D"]],
            ["4.D.1. Wetlands remaining wetlands", ["4.D.1"]],
            ["4.D.2. Land converted to wetlands", ["4.D.2"]],
            ["4.E. Settlements", ["4.E"]],
            ["4.E.1. Settlements remaining settlements", ["4.E.1"]],
            ["4.E.2. Land converted to settlements", ["4.E.2"]],
            ["4.F. Other land (6)", ["4.F"]],
            ["4.F.1. Other land remaining other land", ["4.F.1"]],
            ["4.F.2. Land converted to other land", ["4.F.2"]],
            ["4.G. Harvested wood products (7)", ["4.G"]],
            ["4.H. Other (please specify)", ["4.H"]],
            # coomented to find out where they come from
            # ["Land converted to Settlement", ["4.H.1"]],
            ["\\C-FRA\\ Biogenic NMVOCs from managed forest", ["4.H.4"]],
            ["\\C-FRA\\ Reservoir of Petit-Saut in French Guiana", ["4.H.5"]],
            ["\\C-AUS-ECU\\ Aquaculture", ["4.H.10"]],
            ["\\C-AUS-ECU\\ Seagrass", ["4.H.11"]],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-"
                "URY-UZB\\ N2O emissions from aquaculture [IPCC Software 3.C.12]",
                ["4.H.6"],
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-URY-"
                "UZB-\\ Other emissions from LULUCF [IPCC Software 3.D.2]",
                ["4.H.9"],
            ],
            ["\\C-SGP-NZL-LTU\\ Other", ["4.H.9"]],
            ["\\C-COL-HRV\\ 4.H. Other", ["4.H.9"]],
            ["\\C-BRA\\ Total", ["4.H.9"]],
            ["\\C-JPN\\ Concrete using Biochar", ["4.H.10"]],
            ["\\C-CHN\\ Trees outside forests", ["4.H.11"]],
            ["\\C-CHL\\ NA", ["\\IGNORE"]],
            # currently ignoring memo item
        ],
        "entity_mapping": {
            "CH4(2)": "CH4",
            "N2O(2)": "N2O",
            "Net CO2 emissions/removals (1,2)": "CO2",
            "Total GHG emissions/removals (3)": f"KYOTOGHG ({gwp_to_use})",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    # TODO: all other LULUCF tables
    "Table5": {  # Waste overview
        "status": "tested",
        "table": {
            "firstrow": 8,
            "lastrow": 31,
            "header": ["entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": [
                "",
                "nan",
                '(1) "Total GHG emissions" does not include NOX, CO, NMVOC and SOX.',
            ],
            "unit_info": unit_info["industry"],
        },
        "sector_mapping": [
            ["5. Total waste", ["5"]],
            ["5.A. Solid waste disposal", ["5.A"]],
            ["5.A.1. Managed waste disposal sites", ["5.A.1"]],
            ["5.A.2. Unmanaged waste disposal sites", ["5.A.2"]],
            ["5.A.3. Uncategorized waste disposal sites", ["5.A.3"]],
            ["5.B. Biological treatment of solid waste", ["5.B"]],
            ["5.B.1. Composting", ["5.B.1"]],
            ["5.B.2. Anaerobic digestion at biogas facilities", ["5.B.2"]],
            ["5.C. Incineration and open burning of waste", ["5.C"]],
            ["5.C.1. Waste incineration", ["5.C.1"]],
            ["5.C.2. Open burning of waste", ["5.C.2"]],
            ["5.D. Wastewater treatment and discharge", ["5.D"]],
            ["5.D.1. Domestic wastewater", ["5.D.1"]],
            ["5.D.2. Industrial wastewater", ["5.D.2"]],
            ["5.D.3. Other", ["5.D.3"]],
            ["5.E. Other (please specify)", ["5.E"]],
            ["Accidential fires at Solid Waste Disposal Sites", ["5.E.9"]],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB\\ CH₄ and N₂O emissions from methane flaring at waste facilities "
                "[IPCC Software 4.E]",
                ["5.E.6"],
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB-FRA\\ "
                "Other waste emissions [IPCC Software 4.E, SO₂ from 4.A-4.D]",
                ["5.E.5"],
            ],
            ["\\C-CZE\\ Other waste", ["5.E.5"]],
            ["\\C-FIN-LTU\\ Other", ["5.E.5"]],
            ["\\C-COL\\ 5.E. Other", ["5.E.5"]],
            ["\\C-SGP-BRA-CHL\\ NA", ["\\IGNORE"]],
            ["\\C-ECU\\ NO", ["\\IGNORE"]],
            ["\\C-CHE\\ Car shredding", ["5.E.10"]],
            ["\\C-DNK\\ Accidental fires", ["5.E.3"]],
            ["\\C-ESP\\ Accidental combustion", ["5.E.3"]],
            ["\\C-ESP\\ Sludge spreading", ["5.E.7"]],
            ["\\C-JPN\\ Decomposition of fossil-fuel derived surfactants", ["5.E.4"]],
            ["\\C-PRT\\ Biogas burning without energy recovery", ["5.E.6"]],
            ["\\C-CAN\\ Fossil CO2 from Industrial wastewater", ["5.E.8"]],
            ["Memo item: (3)", ["\\IGNORE"]],
            ["5.F.1. Long-term storage of C in waste disposal sites", ["M.Memo.LTSW"]],
            [
                "\\C!-CHL-ECU\\ 5.F.2. Annual change in total long-term C storage",
                ["M.Memo.ACLT"],
            ],
            [
                "\\C-CHL-ECU\\ 5.F.1.a. Annual change in total long-term C storage",
                ["M.Memo.ACLT"],
            ],
            [
                "\\C!-CHL-ECU\\ "
                "5.F.3. Annual change in total long-term C storage in HWP waste (4)",
                ["M.Memo.ACLTHWP"],
            ],
            [
                "\\C-CHL-ECU\\ "
                "5.F.1.b. Annual change in total long-term C storage in HWP waste (4)",
                ["M.Memo.ACLTHWP"],
            ],
        ],
        "entity_mapping": {
            # "CO2(1)": "CO2",
            "Total GHG emissions (1)": f"KYOTOGHG ({gwp_to_use})",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    # TODO 5.A-D
    "Summary1": {  # Summary 1
        "status": "tested",
        "table": {
            "firstrow": 8,
            "lastrow": 74,
            "header": ["entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": [
                "(1) The emissions of HFCs, PFCs, unspecified mix of HFCs and PFCs and "
                "other F-gases are to be expressed as CO2 eq. emissions. Data on "
                "disaggregated emissions of HFCs and PFCs are to be provided in "
                "table 2(II) of this common reporting format."
            ],
            "unit_info": unit_info["summary"],
        },
        "sector_mapping": [
            ["Total national emissions and removals", ["0"]],
            ["1. Energy", ["1"]],
            ["1.A. Fuel combustion", ["1.A"]],
            ["1.A.1. Energy industries", ["1.A.1"]],
            ["1.A.2. Manufacturing industries and construction", ["1.A.2"]],
            ["1.A.3. Transport", ["1.A.3"]],
            ["1.A.4. Other sectors", ["1.A.4"]],
            ["1.A.5. Other", ["1.A.5"]],
            ["1.B. Fugitive emissions from fuels", ["1.B"]],
            ["1.B.1. Solid fuels", ["1.B.1"]],
            [
                "1.B.2. Oil and natural gas and other emissions from energy production",
                ["1.B.2"],
            ],
            ["1.C. CO2 Transport and storage", ["1.C"]],
            ["2. Industrial processes and product use", ["2"]],
            ["2.A. Mineral industry", ["2.A"]],
            ["2.B. Chemical industry", ["2.B"]],
            ["2.C. Metal industry", ["2.C"]],
            ["2.D. Non-energy products from fuels and solvent use", ["2.D"]],
            ["2.E. Electronic industry", ["2.E"]],
            ["2.F. Product uses as substitutes for ODS", ["2.F"]],
            ["2.G. Other product manufacture and use", ["2.G"]],
            ["2.H. Other (4)", ["2.H"]],
            ["3. Agriculture", ["3"]],
            ["3.A. Enteric fermentation", ["3.A"]],
            ["3.B. Manure management", ["3.B"]],
            ["3.C. Rice cultivation", ["3.C"]],
            ["3.D. Agricultural soils", ["3.D"]],
            ["3.E. Prescribed burning of savannahs", ["3.E"]],
            ["3.F. Field burning of agricultural residues", ["3.F"]],
            ["3.G. Liming", ["3.G"]],
            ["3.H. Urea application", ["3.H"]],
            ["3.I. Other carbon-containing fertilizers", ["3.I"]],
            ["3.J. Other", ["3.J"]],
            ["4. Land use, land-use change and forestry (5)", ["4"]],
            ["4.A. Forest land (5)", ["4.A"]],
            ["4.B. Cropland (5)", ["4.B"]],
            ["4.C. Grassland (5)", ["4.C"]],
            ["4.D. Wetlands (5)", ["4.D"]],
            ["4.E. Settlements (5)", ["4.E"]],
            ["4.F. Other land (5)", ["4.F"]],
            ["4.G. Harvested wood products (5)", ["4.G"]],
            ["4.H. Other (5)", ["4.H"]],
            ["5. Waste", ["5"]],
            ["5.A. Solid waste disposal (6)", ["5.A"]],
            ["5.B. Biological treatment of solid waste", ["5.B"]],
            ["5.C. Incineration and open burning of waste (6)", ["5.C"]],
            ["5.D. Wastewater treatment and discharge", ["5.D"]],
            ["5.E. Other (6)", ["5.E"]],
            ["6. Other (please specify) (7)", ["6"]],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PRY-URY-UZB\\"
                " Other sources of emissions/removals [IPCC Software 5.C]",
                ["6.A"],
            ],
            ["\\C-CHE\\ Other non-specified", ["6.A"]],
            ["\\C-JPN\\ Smoking", ["6.B"]],
            ["\\C-NZL\\ 6. Tokelau_1. Energy", ["6.NZL-A"]],
            [
                "\\C-NZL\\ 6. Tokelau_2. Industrial Processes and Product Use",
                ["6.NZL-B"],
            ],
            ["\\C-NZL\\ 6. Tokelau_3. Agriculture", ["6.NZL-C"]],
            ["\\C-NZL\\ 6. Tokelau_5. Waste", ["6.NZL-D"]],
            ["\\C-AUS-BRA-CHL-ECU-SGP\\ NA", ["\\IGNORE"]],
            ["\\C-COL-LTU\\ Other", ["6.A"]],
            ["\\C-GHA\\ Aquaculture", ["6.B"]],
            ["", ["\\IGNORE"]],
            ["nan", ["\\IGNORE"]],
            ["Memo items: (8)", ["\\IGNORE"]],
            ["1.D.1. International bunkers", ["M.Memo.Int"]],
            ["1.D.1.a. Aviation", ["M.Memo.Int.Avi"]],
            ["1.D.1.b. Navigation", ["M.Memo.Int.Mar"]],
            ["1.D.2. Multilateral operations", ["M.Memo.Mult"]],
            ["1.D.3. CO2 emissions from biomass", ["M.Memo.Bio"]],
            ["1.D.4. CO2 captured", ["M.Memo.CO2Cap"]],
            ["5.F.1. Long-term storage of C in waste disposal sites", ["M.Memo.LTSW"]],
            ["Indirect N2O", ["M.Memo.IndN2O"]],
            ["Indirect CO2", ["M.Memo.IndCO2"]],
        ],
        "entity_mapping": {
            "NOX": "NOx",
            "Net CO2 emissions/ removals": "CO2",
            "HFCs (1)": f"HFCS ({gwp_to_use})",
            "PFCs (1)": f"PFCS ({gwp_to_use})",
            "Unspecified mix of HFCs and PFCs (1)": f"UnspMixOfHFCsPFCs ({gwp_to_use})",
            "Total GHG emissions/removals (2)": f"KYOTOGHG ({gwp_to_use})",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
}
